import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_localizations/flutter_localizations.dart';
import 'package:intl/intl.dart' as intl;

import 'app_localizations_ca.dart';
import 'app_localizations_cs.dart';
import 'app_localizations_de.dart';
import 'app_localizations_en.dart';
import 'app_localizations_eu.dart';
import 'app_localizations_fr.dart';
import 'app_localizations_gl.dart';
import 'app_localizations_it.dart';
import 'app_localizations_ja.dart';
import 'app_localizations_pl.dart';
import 'app_localizations_ru.dart';
import 'app_localizations_th.dart';

// ignore_for_file: type=lint

/// Callers can lookup localized strings with an instance of AppLocalizations
/// returned by `AppLocalizations.of(context)`.
///
/// Applications need to include `AppLocalizations.delegate()` in their app's
/// `localizationDelegates` list, and the locales they support in the app's
/// `supportedLocales` list. For example:
///
/// ```dart
/// import 'gen_l10n/app_localizations.dart';
///
/// return MaterialApp(
///   localizationsDelegates: AppLocalizations.localizationsDelegates,
///   supportedLocales: AppLocalizations.supportedLocales,
///   home: MyApplicationHome(),
/// );
/// ```
///
/// ## Update pubspec.yaml
///
/// Please make sure to update your pubspec.yaml to include the following
/// packages:
///
/// ```yaml
/// dependencies:
///   # Internationalization support.
///   flutter_localizations:
///     sdk: flutter
///   intl: any # Use the pinned version from flutter_localizations
///
///   # Rest of dependencies
/// ```
///
/// ## iOS Applications
///
/// iOS applications define key application metadata, including supported
/// locales, in an Info.plist file that is built into the application bundle.
/// To configure the locales supported by your app, you’ll need to edit this
/// file.
///
/// First, open your project’s ios/Runner.xcworkspace Xcode workspace file.
/// Then, in the Project Navigator, open the Info.plist file under the Runner
/// project’s Runner folder.
///
/// Next, select the Information Property List item, select Add Item from the
/// Editor menu, then select Localizations from the pop-up menu.
///
/// Select and expand the newly-created Localizations item then, for each
/// locale your application supports, add a new item and select the locale
/// you wish to add from the pop-up menu in the Value field. This list should
/// be consistent with the languages listed in the AppLocalizations.supportedLocales
/// property.
abstract class AppLocalizations {
  AppLocalizations(String locale) : localeName = intl.Intl.canonicalizedLocale(locale.toString());

  final String localeName;

  static AppLocalizations? of(BuildContext context) {
    return Localizations.of<AppLocalizations>(context, AppLocalizations);
  }

  static const LocalizationsDelegate<AppLocalizations> delegate = _AppLocalizationsDelegate();

  /// A list of this localizations delegate along with the default localizations
  /// delegates.
  ///
  /// Returns a list of localizations delegates containing this delegate along with
  /// GlobalMaterialLocalizations.delegate, GlobalCupertinoLocalizations.delegate,
  /// and GlobalWidgetsLocalizations.delegate.
  ///
  /// Additional delegates can be added by appending to this list in
  /// MaterialApp. This list does not have to be used at all if a custom list
  /// of delegates is preferred or required.
  static const List<LocalizationsDelegate<dynamic>> localizationsDelegates = <LocalizationsDelegate<dynamic>>[
    delegate,
    GlobalMaterialLocalizations.delegate,
    GlobalCupertinoLocalizations.delegate,
    GlobalWidgetsLocalizations.delegate,
  ];

  /// A list of this localizations delegate's supported locales.
  static const List<Locale> supportedLocales = <Locale>[
    Locale('ca'),
    Locale('cs'),
    Locale('de'),
    Locale('en'),
    Locale('eu'),
    Locale('fr'),
    Locale('gl'),
    Locale('it'),
    Locale('ja'),
    Locale('pl'),
    Locale('ru'),
    Locale('th')
  ];

  /// No description provided for @abkhazian.
  ///
  /// In en, this message translates to:
  /// **'Abkhazian'**
  String get abkhazian;

  /// No description provided for @about.
  ///
  /// In en, this message translates to:
  /// **'About'**
  String get about;

  /// No description provided for @aboutInstanceName.
  ///
  /// In en, this message translates to:
  /// **'About {instanceName}'**
  String aboutInstanceName(String instanceName);

  /// No description provided for @aboutPeertube.
  ///
  /// In en, this message translates to:
  /// **'About PeerTube'**
  String get aboutPeertube;

  /// No description provided for @accessAccountSettings.
  ///
  /// In en, this message translates to:
  /// **'Access account settings'**
  String get accessAccountSettings;

  /// No description provided for @accountManagement.
  ///
  /// In en, this message translates to:
  /// **'Account management'**
  String get accountManagement;

  /// No description provided for @accountsDescription.
  ///
  /// In en, this message translates to:
  /// **'You can also connect to your platform. Connected accounts allow you to synchronise with other devices and the web, ensuring consistent access to your content. What\'s more, you can connect to a platform and benefit from other features, such as subscription management and the ability to leave comments.'**
  String get accountsDescription;

  /// No description provided for @activeAccount.
  ///
  /// In en, this message translates to:
  /// **'Active account'**
  String get activeAccount;

  /// No description provided for @activePlatform.
  ///
  /// In en, this message translates to:
  /// **'Active platform'**
  String get activePlatform;

  /// No description provided for @activism.
  ///
  /// In en, this message translates to:
  /// **'Activism'**
  String get activism;

  /// No description provided for @addAnotherPlatform.
  ///
  /// In en, this message translates to:
  /// **'Add another platform'**
  String get addAnotherPlatform;

  /// No description provided for @addAPlatform.
  ///
  /// In en, this message translates to:
  /// **'Add a platform'**
  String get addAPlatform;

  /// No description provided for @addAPlatformWithItsUrl.
  ///
  /// In en, this message translates to:
  /// **'Add a platform with its URL'**
  String get addAPlatformWithItsUrl;

  /// No description provided for @afar.
  ///
  /// In en, this message translates to:
  /// **'Afar'**
  String get afar;

  /// No description provided for @afrikaans.
  ///
  /// In en, this message translates to:
  /// **'Afrikaans'**
  String get afrikaans;

  /// No description provided for @akan.
  ///
  /// In en, this message translates to:
  /// **'Akan'**
  String get akan;

  /// No description provided for @albanian.
  ///
  /// In en, this message translates to:
  /// **'Albanian'**
  String get albanian;

  /// No description provided for @americanSignLanguage.
  ///
  /// In en, this message translates to:
  /// **'American Sign Language'**
  String get americanSignLanguage;

  /// No description provided for @amharic.
  ///
  /// In en, this message translates to:
  /// **'Amharic'**
  String get amharic;

  /// No description provided for @animals.
  ///
  /// In en, this message translates to:
  /// **'Animals'**
  String get animals;

  /// No description provided for @apply.
  ///
  /// In en, this message translates to:
  /// **'Apply'**
  String get apply;

  /// No description provided for @arabic.
  ///
  /// In en, this message translates to:
  /// **'Arabic'**
  String get arabic;

  /// No description provided for @aragonese.
  ///
  /// In en, this message translates to:
  /// **'Aragonese'**
  String get aragonese;

  /// No description provided for @armenian.
  ///
  /// In en, this message translates to:
  /// **'Armenian'**
  String get armenian;

  /// No description provided for @art.
  ///
  /// In en, this message translates to:
  /// **'Art'**
  String get art;

  /// No description provided for @assamese.
  ///
  /// In en, this message translates to:
  /// **'Assamese'**
  String get assamese;

  /// No description provided for @austrianSignLanguage.
  ///
  /// In en, this message translates to:
  /// **'Austrian Sign Language'**
  String get austrianSignLanguage;

  /// No description provided for @avaric.
  ///
  /// In en, this message translates to:
  /// **'Avaric'**
  String get avaric;

  /// No description provided for @aymara.
  ///
  /// In en, this message translates to:
  /// **'Aymara'**
  String get aymara;

  /// No description provided for @azerbaijani.
  ///
  /// In en, this message translates to:
  /// **'Azerbaijani'**
  String get azerbaijani;

  /// No description provided for @back.
  ///
  /// In en, this message translates to:
  /// **'Back'**
  String get back;

  /// No description provided for @bambara.
  ///
  /// In en, this message translates to:
  /// **'Bambara'**
  String get bambara;

  /// No description provided for @bashkir.
  ///
  /// In en, this message translates to:
  /// **'Bashkir'**
  String get bashkir;

  /// No description provided for @basque.
  ///
  /// In en, this message translates to:
  /// **'Basque'**
  String get basque;

  /// No description provided for @belarusian.
  ///
  /// In en, this message translates to:
  /// **'Belarusian'**
  String get belarusian;

  /// No description provided for @bengali.
  ///
  /// In en, this message translates to:
  /// **'Bengali'**
  String get bengali;

  /// No description provided for @bestMatch.
  ///
  /// In en, this message translates to:
  /// **'Best Match'**
  String get bestMatch;

  /// No description provided for @bislama.
  ///
  /// In en, this message translates to:
  /// **'Bislama'**
  String get bislama;

  /// No description provided for @bookmarkedPlatforms.
  ///
  /// In en, this message translates to:
  /// **'Bookmarked platforms'**
  String get bookmarkedPlatforms;

  /// No description provided for @bosnian.
  ///
  /// In en, this message translates to:
  /// **'Bosnian'**
  String get bosnian;

  /// No description provided for @brazilianSignLanguage.
  ///
  /// In en, this message translates to:
  /// **'Brazilian Sign Language'**
  String get brazilianSignLanguage;

  /// No description provided for @breaksServerRules.
  ///
  /// In en, this message translates to:
  /// **'Breaks server rules'**
  String get breaksServerRules;

  /// No description provided for @breaksServerRulesDescription.
  ///
  /// In en, this message translates to:
  /// **'Anything not included in the above that breaks the terms of service, code of conduct, or general rules in place on the server.'**
  String get breaksServerRulesDescription;

  /// No description provided for @breton.
  ///
  /// In en, this message translates to:
  /// **'Breton'**
  String get breton;

  /// No description provided for @britishSignLanguage.
  ///
  /// In en, this message translates to:
  /// **'British Sign Language'**
  String get britishSignLanguage;

  /// No description provided for @bulgarian.
  ///
  /// In en, this message translates to:
  /// **'Bulgarian'**
  String get bulgarian;

  /// No description provided for @burmese.
  ///
  /// In en, this message translates to:
  /// **'Burmese'**
  String get burmese;

  /// No description provided for @cancel.
  ///
  /// In en, this message translates to:
  /// **'Cancel'**
  String get cancel;

  /// No description provided for @captionReportDescription.
  ///
  /// In en, this message translates to:
  /// **'The above can only be seen in captions (please describe which).'**
  String get captionReportDescription;

  /// No description provided for @captions.
  ///
  /// In en, this message translates to:
  /// **'Captions'**
  String get captions;

  /// No description provided for @catalan.
  ///
  /// In en, this message translates to:
  /// **'Catalan'**
  String get catalan;

  /// No description provided for @categories.
  ///
  /// In en, this message translates to:
  /// **'Categories'**
  String get categories;

  /// No description provided for @chamorro.
  ///
  /// In en, this message translates to:
  /// **'Chamorro'**
  String get chamorro;

  /// No description provided for @channelName.
  ///
  /// In en, this message translates to:
  /// **'Channel name'**
  String get channelName;

  /// No description provided for @channels.
  ///
  /// In en, this message translates to:
  /// **'Channels'**
  String get channels;

  /// No description provided for @chechen.
  ///
  /// In en, this message translates to:
  /// **'Chechen'**
  String get chechen;

  /// No description provided for @chinese.
  ///
  /// In en, this message translates to:
  /// **'Chinese'**
  String get chinese;

  /// No description provided for @chineseSignLanguage.
  ///
  /// In en, this message translates to:
  /// **'Chinese Sign Language'**
  String get chineseSignLanguage;

  /// No description provided for @chooseAnInstance.
  ///
  /// In en, this message translates to:
  /// **'Choose an Instance'**
  String get chooseAnInstance;

  /// No description provided for @chuvash.
  ///
  /// In en, this message translates to:
  /// **'Chuvash'**
  String get chuvash;

  /// No description provided for @closeVideo.
  ///
  /// In en, this message translates to:
  /// **'Close video'**
  String get closeVideo;

  /// No description provided for @comedy.
  ///
  /// In en, this message translates to:
  /// **'Comedy'**
  String get comedy;

  /// No description provided for @comments.
  ///
  /// In en, this message translates to:
  /// **'Comments'**
  String get comments;

  /// No description provided for @confirm.
  ///
  /// In en, this message translates to:
  /// **'Confirm'**
  String get confirm;

  /// No description provided for @confirmation.
  ///
  /// In en, this message translates to:
  /// **'Confirmation'**
  String get confirmation;

  /// No description provided for @connect.
  ///
  /// In en, this message translates to:
  /// **'Connect'**
  String get connect;

  /// No description provided for @connected.
  ///
  /// In en, this message translates to:
  /// **'Connected: '**
  String get connected;

  /// No description provided for @content.
  ///
  /// In en, this message translates to:
  /// **'Content'**
  String get content;

  /// No description provided for @contentLanguages.
  ///
  /// In en, this message translates to:
  /// **'Content languages'**
  String get contentLanguages;

  /// No description provided for @copyright.
  ///
  /// In en, this message translates to:
  /// **'Copyright'**
  String get copyright;

  /// No description provided for @copyrightDescription.
  ///
  /// In en, this message translates to:
  /// **'Infringes your copyright wrt. the regional laws with which the server must comply.'**
  String get copyrightDescription;

  /// No description provided for @cornish.
  ///
  /// In en, this message translates to:
  /// **'Cornish'**
  String get cornish;

  /// No description provided for @corsican.
  ///
  /// In en, this message translates to:
  /// **'Corsican'**
  String get corsican;

  /// No description provided for @cree.
  ///
  /// In en, this message translates to:
  /// **'Cree'**
  String get cree;

  /// No description provided for @croatian.
  ///
  /// In en, this message translates to:
  /// **'Croatian'**
  String get croatian;

  /// No description provided for @currentLives.
  ///
  /// In en, this message translates to:
  /// **'Current lives'**
  String get currentLives;

  /// No description provided for @czech.
  ///
  /// In en, this message translates to:
  /// **'Czech'**
  String get czech;

  /// No description provided for @czechSignLanguage.
  ///
  /// In en, this message translates to:
  /// **'Czech Sign Language'**
  String get czechSignLanguage;

  /// No description provided for @danish.
  ///
  /// In en, this message translates to:
  /// **'Danish'**
  String get danish;

  /// No description provided for @danishSignLanguage.
  ///
  /// In en, this message translates to:
  /// **'Danish Sign Language'**
  String get danishSignLanguage;

  /// No description provided for @darkTheme.
  ///
  /// In en, this message translates to:
  /// **'Dark'**
  String get darkTheme;

  /// No description provided for @daysAgo.
  ///
  /// In en, this message translates to:
  /// **'{number} days ago'**
  String daysAgo(int number);

  /// No description provided for @defineMyInterests.
  ///
  /// In en, this message translates to:
  /// **'Define my interests'**
  String get defineMyInterests;

  /// No description provided for @delete.
  ///
  /// In en, this message translates to:
  /// **'Delete'**
  String get delete;

  /// No description provided for @deleteAll.
  ///
  /// In en, this message translates to:
  /// **'Delete all?'**
  String get deleteAll;

  /// No description provided for @deleteAllConfirmation.
  ///
  /// In en, this message translates to:
  /// **'Do you really want to delete all the elements?'**
  String get deleteAllConfirmation;

  /// No description provided for @deleteElement.
  ///
  /// In en, this message translates to:
  /// **'Delete {elementName}?'**
  String deleteElement(String elementName);

  /// No description provided for @deleteElementConfirmation.
  ///
  /// In en, this message translates to:
  /// **'Do you really want to remove this element?'**
  String get deleteElementConfirmation;

  /// No description provided for @descriptionIsRequired.
  ///
  /// In en, this message translates to:
  /// **'Description is required'**
  String get descriptionIsRequired;

  /// No description provided for @deselectAll.
  ///
  /// In en, this message translates to:
  /// **'Deselect All'**
  String get deselectAll;

  /// No description provided for @dhivehi.
  ///
  /// In en, this message translates to:
  /// **'Dhivehi'**
  String get dhivehi;

  /// No description provided for @discoverContent.
  ///
  /// In en, this message translates to:
  /// **'Discover content'**
  String get discoverContent;

  /// No description provided for @display.
  ///
  /// In en, this message translates to:
  /// **'Display'**
  String get display;

  /// No description provided for @displayOnly.
  ///
  /// In en, this message translates to:
  /// **'Display only:'**
  String get displayOnly;

  /// No description provided for @duration.
  ///
  /// In en, this message translates to:
  /// **'Duration'**
  String get duration;

  /// No description provided for @dutch.
  ///
  /// In en, this message translates to:
  /// **'Dutch'**
  String get dutch;

  /// No description provided for @dzongkha.
  ///
  /// In en, this message translates to:
  /// **'Dzongkha'**
  String get dzongkha;

  /// No description provided for @edit.
  ///
  /// In en, this message translates to:
  /// **'Edit'**
  String get edit;

  /// No description provided for @education.
  ///
  /// In en, this message translates to:
  /// **'Education'**
  String get education;

  /// No description provided for @email.
  ///
  /// In en, this message translates to:
  /// **'Email'**
  String get email;

  /// No description provided for @enableClosedCaptions.
  ///
  /// In en, this message translates to:
  /// **'Enable closed captions'**
  String get enableClosedCaptions;

  /// No description provided for @english.
  ///
  /// In en, this message translates to:
  /// **'English'**
  String get english;

  /// No description provided for @enterAUrl.
  ///
  /// In en, this message translates to:
  /// **'Enter a URL (e.g. https://peertube.example.com)'**
  String get enterAUrl;

  /// No description provided for @enterFullScreen.
  ///
  /// In en, this message translates to:
  /// **'Enter full screen'**
  String get enterFullScreen;

  /// No description provided for @entertainment.
  ///
  /// In en, this message translates to:
  /// **'Entertainment'**
  String get entertainment;

  /// No description provided for @entitynameFederatedFromThisPlatform.
  ///
  /// In en, this message translates to:
  /// **'{entityname} federated from this platform:'**
  String entitynameFederatedFromThisPlatform(String entityname);

  /// No description provided for @esperanto.
  ///
  /// In en, this message translates to:
  /// **'Esperanto'**
  String get esperanto;

  /// No description provided for @estonian.
  ///
  /// In en, this message translates to:
  /// **'Estonian'**
  String get estonian;

  /// No description provided for @ewe.
  ///
  /// In en, this message translates to:
  /// **'Ewe'**
  String get ewe;

  /// No description provided for @exitFullScreen.
  ///
  /// In en, this message translates to:
  /// **'Exit full screen'**
  String get exitFullScreen;

  /// No description provided for @explore.
  ///
  /// In en, this message translates to:
  /// **'Explore'**
  String get explore;

  /// No description provided for @explorePeertube.
  ///
  /// In en, this message translates to:
  /// **'Explore PeerTube'**
  String get explorePeertube;

  /// No description provided for @faroese.
  ///
  /// In en, this message translates to:
  /// **'Faroese'**
  String get faroese;

  /// No description provided for @featuresFoundOnThisPlatform.
  ///
  /// In en, this message translates to:
  /// **'Features found on this platform'**
  String get featuresFoundOnThisPlatform;

  /// No description provided for @federationInformationDescription.
  ///
  /// In en, this message translates to:
  /// **'This {entityname} is federated from another platform ({instanceName1} within the PeerTube network. Its content is shared across the federated platforms, making it accessible on the current instance, {instanceName2}, while respecting the principles of decentralisation.'**
  String federationInformationDescription(String entityname, String instanceName1, String instanceName2);

  /// No description provided for @federationInformationTitle.
  ///
  /// In en, this message translates to:
  /// **'Federation information'**
  String get federationInformationTitle;

  /// No description provided for @fewestLikes.
  ///
  /// In en, this message translates to:
  /// **'Fewest Likes'**
  String get fewestLikes;

  /// No description provided for @fewestViews.
  ///
  /// In en, this message translates to:
  /// **'Fewest Views'**
  String get fewestViews;

  /// No description provided for @fieldRequired.
  ///
  /// In en, this message translates to:
  /// **'This field is required'**
  String get fieldRequired;

  /// No description provided for @fijian.
  ///
  /// In en, this message translates to:
  /// **'Fijian'**
  String get fijian;

  /// No description provided for @films.
  ///
  /// In en, this message translates to:
  /// **'Films'**
  String get films;

  /// No description provided for @filterByMyInterests.
  ///
  /// In en, this message translates to:
  /// **'Filter by \"my interests\"'**
  String get filterByMyInterests;

  /// No description provided for @finnish.
  ///
  /// In en, this message translates to:
  /// **'Finnish'**
  String get finnish;

  /// No description provided for @finnishSignLanguage.
  ///
  /// In en, this message translates to:
  /// **'Finnish Sign Language'**
  String get finnishSignLanguage;

  /// No description provided for @food.
  ///
  /// In en, this message translates to:
  /// **'Food'**
  String get food;

  /// No description provided for @forgotMyPassword.
  ///
  /// In en, this message translates to:
  /// **'I\'ve forgotten my password'**
  String get forgotMyPassword;

  /// No description provided for @french.
  ///
  /// In en, this message translates to:
  /// **'French'**
  String get french;

  /// No description provided for @frenchSignLanguage.
  ///
  /// In en, this message translates to:
  /// **'French Sign Language'**
  String get frenchSignLanguage;

  /// No description provided for @fulah.
  ///
  /// In en, this message translates to:
  /// **'Fulah'**
  String get fulah;

  /// No description provided for @galician.
  ///
  /// In en, this message translates to:
  /// **'Galician'**
  String get galician;

  /// No description provided for @gaming.
  ///
  /// In en, this message translates to:
  /// **'Gaming'**
  String get gaming;

  /// No description provided for @ganda.
  ///
  /// In en, this message translates to:
  /// **'Ganda'**
  String get ganda;

  /// No description provided for @georgian.
  ///
  /// In en, this message translates to:
  /// **'Georgian'**
  String get georgian;

  /// No description provided for @german.
  ///
  /// In en, this message translates to:
  /// **'German'**
  String get german;

  /// No description provided for @germanSignLanguage.
  ///
  /// In en, this message translates to:
  /// **'German Sign Language'**
  String get germanSignLanguage;

  /// No description provided for @giveMyOpinion.
  ///
  /// In en, this message translates to:
  /// **'I give my opinion about the application'**
  String get giveMyOpinion;

  /// No description provided for @goToThisPlatform.
  ///
  /// In en, this message translates to:
  /// **'Go to this platform'**
  String get goToThisPlatform;

  /// No description provided for @greek.
  ///
  /// In en, this message translates to:
  /// **'Greek'**
  String get greek;

  /// No description provided for @guadeloupeanCreoleFrench.
  ///
  /// In en, this message translates to:
  /// **'Guadeloupean Creole French'**
  String get guadeloupeanCreoleFrench;

  /// No description provided for @guarani.
  ///
  /// In en, this message translates to:
  /// **'Guarani'**
  String get guarani;

  /// No description provided for @gujarati.
  ///
  /// In en, this message translates to:
  /// **'Gujarati'**
  String get gujarati;

  /// No description provided for @haitian.
  ///
  /// In en, this message translates to:
  /// **'Haitian'**
  String get haitian;

  /// No description provided for @hatefulOrAbusive.
  ///
  /// In en, this message translates to:
  /// **'Hateful or abusive'**
  String get hatefulOrAbusive;

  /// No description provided for @hatefulOrAbusiveDescription.
  ///
  /// In en, this message translates to:
  /// **'Contains abusive, racist or sexist language or iconography.'**
  String get hatefulOrAbusiveDescription;

  /// No description provided for @hausa.
  ///
  /// In en, this message translates to:
  /// **'Hausa'**
  String get hausa;

  /// No description provided for @hebrew.
  ///
  /// In en, this message translates to:
  /// **'Hebrew'**
  String get hebrew;

  /// No description provided for @helperTextLogin.
  ///
  /// In en, this message translates to:
  /// **'Or e-mail address. Example: mail@exemple.fr'**
  String get helperTextLogin;

  /// No description provided for @herero.
  ///
  /// In en, this message translates to:
  /// **'Herero'**
  String get herero;

  /// No description provided for @hide.
  ///
  /// In en, this message translates to:
  /// **'Hide'**
  String get hide;

  /// No description provided for @hindi.
  ///
  /// In en, this message translates to:
  /// **'Hindi'**
  String get hindi;

  /// No description provided for @hiriMotu.
  ///
  /// In en, this message translates to:
  /// **'Hiri Motu'**
  String get hiriMotu;

  /// No description provided for @history.
  ///
  /// In en, this message translates to:
  /// **'History'**
  String get history;

  /// No description provided for @hoursAgo.
  ///
  /// In en, this message translates to:
  /// **'{number} hours ago'**
  String hoursAgo(int number);

  /// No description provided for @howTo.
  ///
  /// In en, this message translates to:
  /// **'How To'**
  String get howTo;

  /// No description provided for @hungarian.
  ///
  /// In en, this message translates to:
  /// **'Hungarian'**
  String get hungarian;

  /// No description provided for @icelandic.
  ///
  /// In en, this message translates to:
  /// **'Icelandic'**
  String get icelandic;

  /// No description provided for @igbo.
  ///
  /// In en, this message translates to:
  /// **'Igbo'**
  String get igbo;

  /// No description provided for @iKnowWhereToGo.
  ///
  /// In en, this message translates to:
  /// **'I know where to go'**
  String get iKnowWhereToGo;

  /// No description provided for @indonesian.
  ///
  /// In en, this message translates to:
  /// **'Indonesian'**
  String get indonesian;

  /// No description provided for @infiniteScrollingDescription1.
  ///
  /// In en, this message translates to:
  /// **'We\'ve chosen not to use infinite scrolling in our app because we believe in providing a transparent and respectful user experience. Infinite scrolling is considered a dark pattern - a design technique that manipulates users into consuming more content than intended.'**
  String get infiniteScrollingDescription1;

  /// No description provided for @infiniteScrollingDescription2.
  ///
  /// In en, this message translates to:
  /// **'Clear pagination puts you in control of your browsing experience, allowing you to explore content at your own pace. This approach encourages mindful use and helps you manage your time better.'**
  String get infiniteScrollingDescription2;

  /// No description provided for @infiniteScrollingTitle.
  ///
  /// In en, this message translates to:
  /// **'Why our app doesn’t use infinite scrolling'**
  String get infiniteScrollingTitle;

  /// No description provided for @inuktitut.
  ///
  /// In en, this message translates to:
  /// **'Inuktitut'**
  String get inuktitut;

  /// No description provided for @inupiaq.
  ///
  /// In en, this message translates to:
  /// **'Inupiaq'**
  String get inupiaq;

  /// No description provided for @irish.
  ///
  /// In en, this message translates to:
  /// **'Irish'**
  String get irish;

  /// No description provided for @italian.
  ///
  /// In en, this message translates to:
  /// **'Italian'**
  String get italian;

  /// No description provided for @japanese.
  ///
  /// In en, this message translates to:
  /// **'Japanese'**
  String get japanese;

  /// No description provided for @japaneseSignLanguage.
  ///
  /// In en, this message translates to:
  /// **'Japanese Sign Language'**
  String get japaneseSignLanguage;

  /// No description provided for @javanese.
  ///
  /// In en, this message translates to:
  /// **'Javanese'**
  String get javanese;

  /// No description provided for @justNow.
  ///
  /// In en, this message translates to:
  /// **'just now'**
  String get justNow;

  /// No description provided for @kabyle.
  ///
  /// In en, this message translates to:
  /// **'Kabyle'**
  String get kabyle;

  /// No description provided for @kalaallisut.
  ///
  /// In en, this message translates to:
  /// **'Kalaallisut'**
  String get kalaallisut;

  /// No description provided for @kannada.
  ///
  /// In en, this message translates to:
  /// **'Kannada'**
  String get kannada;

  /// No description provided for @kanuri.
  ///
  /// In en, this message translates to:
  /// **'Kanuri'**
  String get kanuri;

  /// No description provided for @kashmiri.
  ///
  /// In en, this message translates to:
  /// **'Kashmiri'**
  String get kashmiri;

  /// No description provided for @kazakh.
  ///
  /// In en, this message translates to:
  /// **'Kazakh'**
  String get kazakh;

  /// No description provided for @khmer.
  ///
  /// In en, this message translates to:
  /// **'Khmer'**
  String get khmer;

  /// No description provided for @kids.
  ///
  /// In en, this message translates to:
  /// **'Kids'**
  String get kids;

  /// No description provided for @kikuyu.
  ///
  /// In en, this message translates to:
  /// **'Kikuyu'**
  String get kikuyu;

  /// No description provided for @kinyarwanda.
  ///
  /// In en, this message translates to:
  /// **'Kinyarwanda'**
  String get kinyarwanda;

  /// No description provided for @kirghiz.
  ///
  /// In en, this message translates to:
  /// **'Kirghiz'**
  String get kirghiz;

  /// No description provided for @klingon.
  ///
  /// In en, this message translates to:
  /// **'Klingon'**
  String get klingon;

  /// No description provided for @komi.
  ///
  /// In en, this message translates to:
  /// **'Komi'**
  String get komi;

  /// No description provided for @kongo.
  ///
  /// In en, this message translates to:
  /// **'Kongo'**
  String get kongo;

  /// No description provided for @korean.
  ///
  /// In en, this message translates to:
  /// **'Korean'**
  String get korean;

  /// No description provided for @kotava.
  ///
  /// In en, this message translates to:
  /// **'Kotava'**
  String get kotava;

  /// No description provided for @kuanyama.
  ///
  /// In en, this message translates to:
  /// **'Kuanyama'**
  String get kuanyama;

  /// No description provided for @kurdish.
  ///
  /// In en, this message translates to:
  /// **'Kurdish'**
  String get kurdish;

  /// No description provided for @language.
  ///
  /// In en, this message translates to:
  /// **'English'**
  String get language;

  /// No description provided for @languagesSettings.
  ///
  /// In en, this message translates to:
  /// **'Languages settings'**
  String get languagesSettings;

  /// No description provided for @lao.
  ///
  /// In en, this message translates to:
  /// **'Lao'**
  String get lao;

  /// No description provided for @latin.
  ///
  /// In en, this message translates to:
  /// **'Latin'**
  String get latin;

  /// No description provided for @latvian.
  ///
  /// In en, this message translates to:
  /// **'Latvian'**
  String get latvian;

  /// No description provided for @leastRecent.
  ///
  /// In en, this message translates to:
  /// **'Least Recent'**
  String get leastRecent;

  /// No description provided for @library.
  ///
  /// In en, this message translates to:
  /// **'Library'**
  String get library;

  /// No description provided for @lightTheme.
  ///
  /// In en, this message translates to:
  /// **'Light'**
  String get lightTheme;

  /// No description provided for @limburgan.
  ///
  /// In en, this message translates to:
  /// **'Limburgan'**
  String get limburgan;

  /// No description provided for @lingala.
  ///
  /// In en, this message translates to:
  /// **'Lingala'**
  String get lingala;

  /// No description provided for @linkedToAccountAccountName.
  ///
  /// In en, this message translates to:
  /// **'Linked to account : {accountName}'**
  String linkedToAccountAccountName(String accountName);

  /// No description provided for @lithuanian.
  ///
  /// In en, this message translates to:
  /// **'Lithuanian'**
  String get lithuanian;

  /// No description provided for @live.
  ///
  /// In en, this message translates to:
  /// **'Live'**
  String get live;

  /// No description provided for @liveVideos.
  ///
  /// In en, this message translates to:
  /// **'Live videos'**
  String get liveVideos;

  /// No description provided for @localAccount.
  ///
  /// In en, this message translates to:
  /// **'Local account'**
  String get localAccount;

  /// No description provided for @localAccountDescription.
  ///
  /// In en, this message translates to:
  /// **'By default, a local account is created for you, which stores data only on your phone. This local account allows you to discover content and gives you access to features such as viewing history and the Watch Later playlist.'**
  String get localAccountDescription;

  /// No description provided for @localAccountShortDescription.
  ///
  /// In en, this message translates to:
  /// **'Your local account lets you manage your history and your ‘watch later’ playlist from your phone.'**
  String get localAccountShortDescription;

  /// No description provided for @localVideos.
  ///
  /// In en, this message translates to:
  /// **'Local videos'**
  String get localVideos;

  /// No description provided for @login.
  ///
  /// In en, this message translates to:
  /// **'Login'**
  String get login;

  /// No description provided for @lojban.
  ///
  /// In en, this message translates to:
  /// **'Lojban'**
  String get lojban;

  /// No description provided for @longestDuration.
  ///
  /// In en, this message translates to:
  /// **'Longest Duration'**
  String get longestDuration;

  /// No description provided for @lubaKatanga.
  ///
  /// In en, this message translates to:
  /// **'Luba-Katanga'**
  String get lubaKatanga;

  /// No description provided for @luxembourgish.
  ///
  /// In en, this message translates to:
  /// **'Luxembourgish'**
  String get luxembourgish;

  /// No description provided for @macedonian.
  ///
  /// In en, this message translates to:
  /// **'Macedonian'**
  String get macedonian;

  /// No description provided for @malagasy.
  ///
  /// In en, this message translates to:
  /// **'Malagasy'**
  String get malagasy;

  /// No description provided for @malayalam.
  ///
  /// In en, this message translates to:
  /// **'Malayalam'**
  String get malayalam;

  /// No description provided for @malaymacrolanguage.
  ///
  /// In en, this message translates to:
  /// **'Malay (macrolanguage)'**
  String get malaymacrolanguage;

  /// No description provided for @maltese.
  ///
  /// In en, this message translates to:
  /// **'Maltese'**
  String get maltese;

  /// No description provided for @manageAccounts.
  ///
  /// In en, this message translates to:
  /// **'Manage accounts'**
  String get manageAccounts;

  /// No description provided for @manx.
  ///
  /// In en, this message translates to:
  /// **'Manx'**
  String get manx;

  /// No description provided for @maori.
  ///
  /// In en, this message translates to:
  /// **'Maori'**
  String get maori;

  /// No description provided for @marathi.
  ///
  /// In en, this message translates to:
  /// **'Marathi'**
  String get marathi;

  /// No description provided for @marshallese.
  ///
  /// In en, this message translates to:
  /// **'Marshallese'**
  String get marshallese;

  /// No description provided for @minAgo.
  ///
  /// In en, this message translates to:
  /// **'{number} min ago'**
  String minAgo(int number);

  /// No description provided for @mongolian.
  ///
  /// In en, this message translates to:
  /// **'Mongolian'**
  String get mongolian;

  /// No description provided for @monthsAgo.
  ///
  /// In en, this message translates to:
  /// **'{number} months ago'**
  String monthsAgo(int number);

  /// No description provided for @moreFilters.
  ///
  /// In en, this message translates to:
  /// **'More filters'**
  String get moreFilters;

  /// No description provided for @mostLikes.
  ///
  /// In en, this message translates to:
  /// **'Most Likes'**
  String get mostLikes;

  /// No description provided for @mostRecent.
  ///
  /// In en, this message translates to:
  /// **'Most Recent'**
  String get mostRecent;

  /// No description provided for @mostViews.
  ///
  /// In en, this message translates to:
  /// **'Most Views'**
  String get mostViews;

  /// No description provided for @music.
  ///
  /// In en, this message translates to:
  /// **'Music'**
  String get music;

  /// No description provided for @myAccounts.
  ///
  /// In en, this message translates to:
  /// **'My accounts'**
  String get myAccounts;

  /// No description provided for @myInterests.
  ///
  /// In en, this message translates to:
  /// **'My interests'**
  String get myInterests;

  /// No description provided for @myOtherPlatforms.
  ///
  /// In en, this message translates to:
  /// **'My other platforms'**
  String get myOtherPlatforms;

  /// No description provided for @myPlatforms.
  ///
  /// In en, this message translates to:
  /// **'My platforms'**
  String get myPlatforms;

  /// No description provided for @myPlaylists.
  ///
  /// In en, this message translates to:
  /// **'My playlists'**
  String get myPlaylists;

  /// No description provided for @name.
  ///
  /// In en, this message translates to:
  /// **'Name'**
  String get name;

  /// No description provided for @nameAZ.
  ///
  /// In en, this message translates to:
  /// **'Name (A-Z)'**
  String get nameAZ;

  /// No description provided for @nameZA.
  ///
  /// In en, this message translates to:
  /// **'Name (Z-A)'**
  String get nameZA;

  /// No description provided for @nauru.
  ///
  /// In en, this message translates to:
  /// **'Nauru'**
  String get nauru;

  /// No description provided for @navajo.
  ///
  /// In en, this message translates to:
  /// **'Navajo'**
  String get navajo;

  /// No description provided for @navigateToAccount.
  ///
  /// In en, this message translates to:
  /// **'Navigate to account'**
  String get navigateToAccount;

  /// No description provided for @navigateToChannel.
  ///
  /// In en, this message translates to:
  /// **'Navigate to channel'**
  String get navigateToChannel;

  /// No description provided for @ndonga.
  ///
  /// In en, this message translates to:
  /// **'Ndonga'**
  String get ndonga;

  /// No description provided for @nepalimacrolanguage.
  ///
  /// In en, this message translates to:
  /// **'Nepali (macrolanguage)'**
  String get nepalimacrolanguage;

  /// No description provided for @newest.
  ///
  /// In en, this message translates to:
  /// **'Newest'**
  String get newest;

  /// No description provided for @newsPolitics.
  ///
  /// In en, this message translates to:
  /// **'News & Politics'**
  String get newsPolitics;

  /// No description provided for @next.
  ///
  /// In en, this message translates to:
  /// **'Next'**
  String get next;

  /// No description provided for @nolinguisticcontent.
  ///
  /// In en, this message translates to:
  /// **'No linguistic content'**
  String get nolinguisticcontent;

  /// No description provided for @noPlatformsFound.
  ///
  /// In en, this message translates to:
  /// **'No platforms found'**
  String get noPlatformsFound;

  /// No description provided for @northernSami.
  ///
  /// In en, this message translates to:
  /// **'Northern Sami'**
  String get northernSami;

  /// No description provided for @northNdebele.
  ///
  /// In en, this message translates to:
  /// **'North Ndebele'**
  String get northNdebele;

  /// No description provided for @norwegian.
  ///
  /// In en, this message translates to:
  /// **'Norwegian'**
  String get norwegian;

  /// No description provided for @norwegianBokmal.
  ///
  /// In en, this message translates to:
  /// **'Norwegian Bokmål'**
  String get norwegianBokmal;

  /// No description provided for @norwegianNynorsk.
  ///
  /// In en, this message translates to:
  /// **'Norwegian Nynorsk'**
  String get norwegianNynorsk;

  /// No description provided for @notNow.
  ///
  /// In en, this message translates to:
  /// **'Not now'**
  String get notNow;

  /// No description provided for @noVideosInHistoryYet.
  ///
  /// In en, this message translates to:
  /// **'No videos in history yet'**
  String get noVideosInHistoryYet;

  /// No description provided for @noVideosInWatchLaterPlaylist.
  ///
  /// In en, this message translates to:
  /// **'No videos in Watch Later playlist'**
  String get noVideosInWatchLaterPlaylist;

  /// No description provided for @nyanja.
  ///
  /// In en, this message translates to:
  /// **'Nyanja'**
  String get nyanja;

  /// No description provided for @occitan.
  ///
  /// In en, this message translates to:
  /// **'Occitan'**
  String get occitan;

  /// No description provided for @ojibwa.
  ///
  /// In en, this message translates to:
  /// **'Ojibwa'**
  String get ojibwa;

  /// No description provided for @oldest.
  ///
  /// In en, this message translates to:
  /// **'Oldest'**
  String get oldest;

  /// No description provided for @onDate.
  ///
  /// In en, this message translates to:
  /// **'On {date}'**
  String onDate(String date);

  /// No description provided for @oneDayAgo.
  ///
  /// In en, this message translates to:
  /// **'1 day ago'**
  String get oneDayAgo;

  /// No description provided for @oneHourAgo.
  ///
  /// In en, this message translates to:
  /// **'1 hour ago'**
  String get oneHourAgo;

  /// No description provided for @oneMonthAgo.
  ///
  /// In en, this message translates to:
  /// **'1 month ago'**
  String get oneMonthAgo;

  /// No description provided for @oneWeekAgo.
  ///
  /// In en, this message translates to:
  /// **'1 week ago'**
  String get oneWeekAgo;

  /// No description provided for @oneYearAgo.
  ///
  /// In en, this message translates to:
  /// **'1 year ago'**
  String get oneYearAgo;

  /// No description provided for @onlineVideos.
  ///
  /// In en, this message translates to:
  /// **'Online videos'**
  String get onlineVideos;

  /// No description provided for @onlyHttpsUrls.
  ///
  /// In en, this message translates to:
  /// **'Only HTTPS URLs are allowed.'**
  String get onlyHttpsUrls;

  /// No description provided for @onThePlatform.
  ///
  /// In en, this message translates to:
  /// **'On the platform {instanceName}'**
  String onThePlatform(String instanceName);

  /// No description provided for @oriyamacrolanguage.
  ///
  /// In en, this message translates to:
  /// **'Oriya (macrolanguage)'**
  String get oriyamacrolanguage;

  /// No description provided for @oromo.
  ///
  /// In en, this message translates to:
  /// **'Oromo'**
  String get oromo;

  /// No description provided for @ossetian.
  ///
  /// In en, this message translates to:
  /// **'Ossetian'**
  String get ossetian;

  /// No description provided for @pakistanSignLanguage.
  ///
  /// In en, this message translates to:
  /// **'Pakistan Sign Language'**
  String get pakistanSignLanguage;

  /// No description provided for @panjabi.
  ///
  /// In en, this message translates to:
  /// **'Panjabi'**
  String get panjabi;

  /// No description provided for @pauseVideo.
  ///
  /// In en, this message translates to:
  /// **'Pause video'**
  String get pauseVideo;

  /// No description provided for @peertubeOnBoardingDescription.
  ///
  /// In en, this message translates to:
  /// **'PeerTube is a decentralised video sharing network where independent platforms connect and share content. This open source system allows you to keep control of your videos while offering an alternative to the big centralised platforms!'**
  String get peertubeOnBoardingDescription;

  /// No description provided for @peertubePlatforms.
  ///
  /// In en, this message translates to:
  /// **'PeerTube platforms'**
  String get peertubePlatforms;

  /// No description provided for @people.
  ///
  /// In en, this message translates to:
  /// **'People'**
  String get people;

  /// No description provided for @persian.
  ///
  /// In en, this message translates to:
  /// **'Persian'**
  String get persian;

  /// No description provided for @phoneSettings.
  ///
  /// In en, this message translates to:
  /// **'Phone settings'**
  String get phoneSettings;

  /// No description provided for @pin.
  ///
  /// In en, this message translates to:
  /// **'Pin'**
  String get pin;

  /// No description provided for @plateformsHistory.
  ///
  /// In en, this message translates to:
  /// **'Platforms history'**
  String get plateformsHistory;

  /// No description provided for @platformDeletionConfirmation.
  ///
  /// In en, this message translates to:
  /// **'Are you sure you want to remove {instanceName} from your list of platforms? To access it again, you will have to search for it manually via the application.'**
  String platformDeletionConfirmation(String instanceName);

  /// No description provided for @platformHistory.
  ///
  /// In en, this message translates to:
  /// **'Platform history'**
  String get platformHistory;

  /// No description provided for @platformInstanceName.
  ///
  /// In en, this message translates to:
  /// **'Platform {platformName}'**
  String platformInstanceName(String platformName);

  /// No description provided for @platformIsNotResponding.
  ///
  /// In en, this message translates to:
  /// **'The platform {platformName} is not responding, please try again later.'**
  String platformIsNotResponding(String platformName);

  /// No description provided for @platformKeepItInMyList.
  ///
  /// In en, this message translates to:
  /// **'No, keep it in my list'**
  String get platformKeepItInMyList;

  /// No description provided for @platformRemove.
  ///
  /// In en, this message translates to:
  /// **'Yes, remove the platform'**
  String get platformRemove;

  /// No description provided for @platforms.
  ///
  /// In en, this message translates to:
  /// **'Platforms'**
  String get platforms;

  /// No description provided for @platformUrl.
  ///
  /// In en, this message translates to:
  /// **'Platform URL'**
  String get platformUrl;

  /// No description provided for @playbackSettings.
  ///
  /// In en, this message translates to:
  /// **'Playback settings'**
  String get playbackSettings;

  /// No description provided for @playVideo.
  ///
  /// In en, this message translates to:
  /// **'Play video'**
  String get playVideo;

  /// No description provided for @pleaseDescribeTheIssue.
  ///
  /// In en, this message translates to:
  /// **'Please describe the issue...'**
  String get pleaseDescribeTheIssue;

  /// No description provided for @pleaseEnterAUrl.
  ///
  /// In en, this message translates to:
  /// **'Please enter a URL'**
  String get pleaseEnterAUrl;

  /// No description provided for @polish.
  ///
  /// In en, this message translates to:
  /// **'Polish'**
  String get polish;

  /// No description provided for @portugueseBrazilian.
  ///
  /// In en, this message translates to:
  /// **'Portuguese (Brazilian)'**
  String get portugueseBrazilian;

  /// No description provided for @portuguesePortugal.
  ///
  /// In en, this message translates to:
  /// **'Portuguese (Portugal)'**
  String get portuguesePortugal;

  /// No description provided for @presentation.
  ///
  /// In en, this message translates to:
  /// **'Presentation'**
  String get presentation;

  /// No description provided for @privacyBreachOrDoxxing.
  ///
  /// In en, this message translates to:
  /// **'Privacy breach or doxxing'**
  String get privacyBreachOrDoxxing;

  /// No description provided for @privacyBreachOrDoxxingDescription.
  ///
  /// In en, this message translates to:
  /// **'Contains personal information that could be used to track, identify, contact or impersonate someone (e.g. name, address, phone number, email, or credit card details).'**
  String get privacyBreachOrDoxxingDescription;

  /// No description provided for @pushto.
  ///
  /// In en, this message translates to:
  /// **'Pushto'**
  String get pushto;

  /// No description provided for @quechua.
  ///
  /// In en, this message translates to:
  /// **'Quechua'**
  String get quechua;

  /// No description provided for @recentlyAdded.
  ///
  /// In en, this message translates to:
  /// **'Recently added'**
  String get recentlyAdded;

  /// No description provided for @redirection.
  ///
  /// In en, this message translates to:
  /// **'Accessing {platformName} Platform'**
  String redirection(String platformName);

  /// No description provided for @redirectionPlatform.
  ///
  /// In en, this message translates to:
  /// **'You will access the {platformName} platform page and exit Explore.'**
  String redirectionPlatform(String platformName);

  /// No description provided for @refreshList.
  ///
  /// In en, this message translates to:
  /// **'Refresh list'**
  String get refreshList;

  /// No description provided for @removeInstanceDialog.
  ///
  /// In en, this message translates to:
  /// **'Are you sure you want to remove {instanceName} from your list of platforms? It will still appear in your history.'**
  String removeInstanceDialog(String instanceName);

  /// No description provided for @removeInstanceDialogCancel.
  ///
  /// In en, this message translates to:
  /// **'Cancel and return to my list'**
  String get removeInstanceDialogCancel;

  /// No description provided for @removeInstanceDialogConfirm.
  ///
  /// In en, this message translates to:
  /// **'Yes, remove the platform'**
  String get removeInstanceDialogConfirm;

  /// No description provided for @removeInstanceDialogHeader.
  ///
  /// In en, this message translates to:
  /// **'Confirmation'**
  String get removeInstanceDialogHeader;

  /// No description provided for @report.
  ///
  /// In en, this message translates to:
  /// **'Report'**
  String get report;

  /// No description provided for @reportAComment.
  ///
  /// In en, this message translates to:
  /// **'Report a comment'**
  String get reportAComment;

  /// No description provided for @reportAnAccount.
  ///
  /// In en, this message translates to:
  /// **'Report an account'**
  String get reportAnAccount;

  /// No description provided for @reportAVideo.
  ///
  /// In en, this message translates to:
  /// **'Report a video'**
  String get reportAVideo;

  /// No description provided for @reportBug.
  ///
  /// In en, this message translates to:
  /// **'Report a bug'**
  String get reportBug;

  /// No description provided for @reportVideo.
  ///
  /// In en, this message translates to:
  /// **'Report video \"{videoName}\"'**
  String reportVideo(String videoName);

  /// No description provided for @reset.
  ///
  /// In en, this message translates to:
  /// **'Reset'**
  String get reset;

  /// No description provided for @resetFilters.
  ///
  /// In en, this message translates to:
  /// **'Reset filters'**
  String get resetFilters;

  /// No description provided for @returnToHome.
  ///
  /// In en, this message translates to:
  /// **'Return to Home'**
  String get returnToHome;

  /// No description provided for @romanian.
  ///
  /// In en, this message translates to:
  /// **'Romanian'**
  String get romanian;

  /// No description provided for @romansh.
  ///
  /// In en, this message translates to:
  /// **'Romansh'**
  String get romansh;

  /// No description provided for @rundi.
  ///
  /// In en, this message translates to:
  /// **'Rundi'**
  String get rundi;

  /// No description provided for @runningPlatform.
  ///
  /// In en, this message translates to:
  /// **'Running platform'**
  String get runningPlatform;

  /// No description provided for @russian.
  ///
  /// In en, this message translates to:
  /// **'Russian'**
  String get russian;

  /// No description provided for @russianSignLanguage.
  ///
  /// In en, this message translates to:
  /// **'Russian Sign Language'**
  String get russianSignLanguage;

  /// No description provided for @samoan.
  ///
  /// In en, this message translates to:
  /// **'Samoan'**
  String get samoan;

  /// No description provided for @sango.
  ///
  /// In en, this message translates to:
  /// **'Sango'**
  String get sango;

  /// No description provided for @sardinian.
  ///
  /// In en, this message translates to:
  /// **'Sardinian'**
  String get sardinian;

  /// No description provided for @saudiArabianSignLanguage.
  ///
  /// In en, this message translates to:
  /// **'Saudi Arabian Sign Language'**
  String get saudiArabianSignLanguage;

  /// No description provided for @scienceTechnology.
  ///
  /// In en, this message translates to:
  /// **'Science & Technology'**
  String get scienceTechnology;

  /// No description provided for @scottishGaelic.
  ///
  /// In en, this message translates to:
  /// **'Scottish Gaelic'**
  String get scottishGaelic;

  /// No description provided for @searchPeertubeContent.
  ///
  /// In en, this message translates to:
  /// **'Search PeerTube content'**
  String get searchPeertubeContent;

  /// No description provided for @searchPeertubePlatforms.
  ///
  /// In en, this message translates to:
  /// **'Search PeerTube platforms'**
  String get searchPeertubePlatforms;

  /// No description provided for @selectAll.
  ///
  /// In en, this message translates to:
  /// **'Select all'**
  String get selectAll;

  /// No description provided for @selectAnInstance.
  ///
  /// In en, this message translates to:
  /// **'Select an instance:'**
  String get selectAnInstance;

  /// No description provided for @selectContentLanguages.
  ///
  /// In en, this message translates to:
  /// **'Select content languages'**
  String get selectContentLanguages;

  /// No description provided for @selectionOfPopularContent.
  ///
  /// In en, this message translates to:
  /// **'Here\'s a selection of popular content from various PeerTube platforms.'**
  String get selectionOfPopularContent;

  /// No description provided for @selectLanguage.
  ///
  /// In en, this message translates to:
  /// **'Select Language'**
  String get selectLanguage;

  /// No description provided for @selectTheme.
  ///
  /// In en, this message translates to:
  /// **'Select theme'**
  String get selectTheme;

  /// No description provided for @sentryIsNotActivatedPleaseTryAgainLater.
  ///
  /// In en, this message translates to:
  /// **'Sentry is not activated. Please try again later.'**
  String get sentryIsNotActivatedPleaseTryAgainLater;

  /// No description provided for @sepiaDefeated.
  ///
  /// In en, this message translates to:
  /// **'Sepia defeated'**
  String get sepiaDefeated;

  /// No description provided for @sepiaPeertubeMascot.
  ///
  /// In en, this message translates to:
  /// **'Sepia, PeerTube\'s mascot'**
  String get sepiaPeertubeMascot;

  /// No description provided for @sepiaPointing.
  ///
  /// In en, this message translates to:
  /// **'Peertube\'s mascott, Sepia, pointing'**
  String get sepiaPointing;

  /// No description provided for @serbian.
  ///
  /// In en, this message translates to:
  /// **'Serbian'**
  String get serbian;

  /// No description provided for @serboCroatian.
  ///
  /// In en, this message translates to:
  /// **'Serbo-Croatian'**
  String get serboCroatian;

  /// No description provided for @settings.
  ///
  /// In en, this message translates to:
  /// **'Settings'**
  String get settings;

  /// No description provided for @setYourPreferences.
  ///
  /// In en, this message translates to:
  /// **'Set your preferences to display content that suits your tastes!'**
  String get setYourPreferences;

  /// No description provided for @share.
  ///
  /// In en, this message translates to:
  /// **'Share'**
  String get share;

  /// No description provided for @shona.
  ///
  /// In en, this message translates to:
  /// **'Shona'**
  String get shona;

  /// No description provided for @shortestDuration.
  ///
  /// In en, this message translates to:
  /// **'Shortest Duration'**
  String get shortestDuration;

  /// No description provided for @showFullHistory.
  ///
  /// In en, this message translates to:
  /// **'Show full history'**
  String get showFullHistory;

  /// No description provided for @showInformation.
  ///
  /// In en, this message translates to:
  /// **'Show information'**
  String get showInformation;

  /// No description provided for @showMorePlatforms.
  ///
  /// In en, this message translates to:
  /// **'Show more platforms'**
  String get showMorePlatforms;

  /// No description provided for @showMoreVideos.
  ///
  /// In en, this message translates to:
  /// **'Show more videos'**
  String get showMoreVideos;

  /// No description provided for @showPlatformFeatures.
  ///
  /// In en, this message translates to:
  /// **'Show platform features'**
  String get showPlatformFeatures;

  /// No description provided for @sichuanYi.
  ///
  /// In en, this message translates to:
  /// **'Sichuan Yi'**
  String get sichuanYi;

  /// No description provided for @similarVideos.
  ///
  /// In en, this message translates to:
  /// **'Similar videos'**
  String get similarVideos;

  /// No description provided for @simplifiedChinese.
  ///
  /// In en, this message translates to:
  /// **'Simplified Chinese'**
  String get simplifiedChinese;

  /// No description provided for @sindhi.
  ///
  /// In en, this message translates to:
  /// **'Sindhi'**
  String get sindhi;

  /// No description provided for @sinhala.
  ///
  /// In en, this message translates to:
  /// **'Sinhala'**
  String get sinhala;

  /// No description provided for @slovak.
  ///
  /// In en, this message translates to:
  /// **'Slovak'**
  String get slovak;

  /// No description provided for @slovenian.
  ///
  /// In en, this message translates to:
  /// **'Slovenian'**
  String get slovenian;

  /// No description provided for @somali.
  ///
  /// In en, this message translates to:
  /// **'Somali'**
  String get somali;

  /// No description provided for @southAfricanSignLanguage.
  ///
  /// In en, this message translates to:
  /// **'South African Sign Language'**
  String get southAfricanSignLanguage;

  /// No description provided for @southernSotho.
  ///
  /// In en, this message translates to:
  /// **'Southern Sotho'**
  String get southernSotho;

  /// No description provided for @southNdebele.
  ///
  /// In en, this message translates to:
  /// **'South Ndebele'**
  String get southNdebele;

  /// No description provided for @spamAdOrFalseNews.
  ///
  /// In en, this message translates to:
  /// **'Spam, ad or false news'**
  String get spamAdOrFalseNews;

  /// No description provided for @spamAdOrFalseNewsDescription.
  ///
  /// In en, this message translates to:
  /// **'Contains marketing, spam, purposefully deceitful news, or otherwise misleading thumbnail/text/tags. Please provide reputable sources to report hoaxes.'**
  String get spamAdOrFalseNewsDescription;

  /// No description provided for @spanishLatinAmerica.
  ///
  /// In en, this message translates to:
  /// **'Spanish (Latin America)'**
  String get spanishLatinAmerica;

  /// No description provided for @spanishSpain.
  ///
  /// In en, this message translates to:
  /// **'Spanish (Spain)'**
  String get spanishSpain;

  /// No description provided for @sports.
  ///
  /// In en, this message translates to:
  /// **'Sports'**
  String get sports;

  /// No description provided for @startAt.
  ///
  /// In en, this message translates to:
  /// **'Start at'**
  String get startAt;

  /// No description provided for @stopAt.
  ///
  /// In en, this message translates to:
  /// **'Stop at'**
  String get stopAt;

  /// No description provided for @submit.
  ///
  /// In en, this message translates to:
  /// **'Submit'**
  String get submit;

  /// No description provided for @subscribe.
  ///
  /// In en, this message translates to:
  /// **'Subscribe'**
  String get subscribe;

  /// No description provided for @sundanese.
  ///
  /// In en, this message translates to:
  /// **'Sundanese'**
  String get sundanese;

  /// No description provided for @support.
  ///
  /// In en, this message translates to:
  /// **'Support'**
  String get support;

  /// No description provided for @swahilimacrolanguage.
  ///
  /// In en, this message translates to:
  /// **'Swahili (macrolanguage)'**
  String get swahilimacrolanguage;

  /// No description provided for @swati.
  ///
  /// In en, this message translates to:
  /// **'Swati'**
  String get swati;

  /// No description provided for @swedish.
  ///
  /// In en, this message translates to:
  /// **'Swedish'**
  String get swedish;

  /// No description provided for @swedishSignLanguage.
  ///
  /// In en, this message translates to:
  /// **'Swedish Sign Language'**
  String get swedishSignLanguage;

  /// No description provided for @switchToPlatformInstanceName.
  ///
  /// In en, this message translates to:
  /// **'Switch to platform {platformName}'**
  String switchToPlatformInstanceName(String platformName);

  /// No description provided for @systemTheme.
  ///
  /// In en, this message translates to:
  /// **'System'**
  String get systemTheme;

  /// No description provided for @tagalog.
  ///
  /// In en, this message translates to:
  /// **'Tagalog'**
  String get tagalog;

  /// No description provided for @tags.
  ///
  /// In en, this message translates to:
  /// **'Tags'**
  String get tags;

  /// No description provided for @tahitian.
  ///
  /// In en, this message translates to:
  /// **'Tahitian'**
  String get tahitian;

  /// No description provided for @tajik.
  ///
  /// In en, this message translates to:
  /// **'Tajik'**
  String get tajik;

  /// No description provided for @tamil.
  ///
  /// In en, this message translates to:
  /// **'Tamil'**
  String get tamil;

  /// No description provided for @tatar.
  ///
  /// In en, this message translates to:
  /// **'Tatar'**
  String get tatar;

  /// No description provided for @telugu.
  ///
  /// In en, this message translates to:
  /// **'Telugu'**
  String get telugu;

  /// No description provided for @thai.
  ///
  /// In en, this message translates to:
  /// **'Thai'**
  String get thai;

  /// No description provided for @thankYouForYourReport.
  ///
  /// In en, this message translates to:
  /// **'Thank you for your report!'**
  String get thankYouForYourReport;

  /// No description provided for @theme.
  ///
  /// In en, this message translates to:
  /// **'Theme'**
  String get theme;

  /// No description provided for @themeMode.
  ///
  /// In en, this message translates to:
  /// **'Choose your theme'**
  String get themeMode;

  /// No description provided for @thisUrlDoesNotWork.
  ///
  /// In en, this message translates to:
  /// **'This URL does not work : {error}'**
  String thisUrlDoesNotWork(String error);

  /// No description provided for @thumbnails.
  ///
  /// In en, this message translates to:
  /// **'Thumbnails'**
  String get thumbnails;

  /// No description provided for @thumbnailsReportDescription.
  ///
  /// In en, this message translates to:
  /// **'The above can only be seen in thumbnails.'**
  String get thumbnailsReportDescription;

  /// No description provided for @tibetan.
  ///
  /// In en, this message translates to:
  /// **'Tibetan'**
  String get tibetan;

  /// No description provided for @tigrinya.
  ///
  /// In en, this message translates to:
  /// **'Tigrinya'**
  String get tigrinya;

  /// No description provided for @toInstanceName.
  ///
  /// In en, this message translates to:
  /// **'to {instanceName}'**
  String toInstanceName(String instanceName);

  /// No description provided for @tokiPona.
  ///
  /// In en, this message translates to:
  /// **'Toki Pona'**
  String get tokiPona;

  /// No description provided for @tongaTongaIslands.
  ///
  /// In en, this message translates to:
  /// **'Tonga (Tonga Islands)'**
  String get tongaTongaIslands;

  /// No description provided for @totalChannels.
  ///
  /// In en, this message translates to:
  /// **'{channelscount} channels'**
  String totalChannels(String channelscount);

  /// No description provided for @totalComments.
  ///
  /// In en, this message translates to:
  /// **'{commentsCount} Comments'**
  String totalComments(String commentsCount);

  /// No description provided for @totalFollowers.
  ///
  /// In en, this message translates to:
  /// **'{followerscount} followers'**
  String totalFollowers(String followerscount);

  /// No description provided for @totalUsers.
  ///
  /// In en, this message translates to:
  /// **'{usersCount} users'**
  String totalUsers(String usersCount);

  /// No description provided for @totalVideos.
  ///
  /// In en, this message translates to:
  /// **'{total} videos'**
  String totalVideos(String total);

  /// No description provided for @totalVideosDisplayed.
  ///
  /// In en, this message translates to:
  /// **'{totalVideos} videos displayed'**
  String totalVideosDisplayed(String totalVideos);

  /// No description provided for @totalViewers.
  ///
  /// In en, this message translates to:
  /// **'{viewers} viewers'**
  String totalViewers(String viewers);

  /// No description provided for @totalViews.
  ///
  /// In en, this message translates to:
  /// **'{viewsCount} views'**
  String totalViews(String viewsCount);

  /// No description provided for @traditionalChinese.
  ///
  /// In en, this message translates to:
  /// **'Traditional Chinese'**
  String get traditionalChinese;

  /// No description provided for @travels.
  ///
  /// In en, this message translates to:
  /// **'Travels'**
  String get travels;

  /// No description provided for @trending.
  ///
  /// In en, this message translates to:
  /// **'Trending'**
  String get trending;

  /// No description provided for @tsonga.
  ///
  /// In en, this message translates to:
  /// **'Tsonga'**
  String get tsonga;

  /// No description provided for @tswana.
  ///
  /// In en, this message translates to:
  /// **'Tswana'**
  String get tswana;

  /// No description provided for @turkish.
  ///
  /// In en, this message translates to:
  /// **'Turkish'**
  String get turkish;

  /// No description provided for @turkmen.
  ///
  /// In en, this message translates to:
  /// **'Turkmen'**
  String get turkmen;

  /// No description provided for @twi.
  ///
  /// In en, this message translates to:
  /// **'Twi'**
  String get twi;

  /// No description provided for @uighur.
  ///
  /// In en, this message translates to:
  /// **'Uighur'**
  String get uighur;

  /// No description provided for @ukrainian.
  ///
  /// In en, this message translates to:
  /// **'Ukrainian'**
  String get ukrainian;

  /// No description provided for @unableToConnect.
  ///
  /// In en, this message translates to:
  /// **'Unable to connect'**
  String get unableToConnect;

  /// No description provided for @unbookmarkedPlatforms.
  ///
  /// In en, this message translates to:
  /// **'Unbookmarked platforms'**
  String get unbookmarkedPlatforms;

  /// No description provided for @unknownLanguage.
  ///
  /// In en, this message translates to:
  /// **'Unknown language'**
  String get unknownLanguage;

  /// No description provided for @unknownVersion.
  ///
  /// In en, this message translates to:
  /// **'Unknown version'**
  String get unknownVersion;

  /// No description provided for @unpin.
  ///
  /// In en, this message translates to:
  /// **'Unpin'**
  String get unpin;

  /// No description provided for @updateMyInterests.
  ///
  /// In en, this message translates to:
  /// **'Update my interests'**
  String get updateMyInterests;

  /// No description provided for @urdu.
  ///
  /// In en, this message translates to:
  /// **'Urdu'**
  String get urdu;

  /// No description provided for @username.
  ///
  /// In en, this message translates to:
  /// **'Username'**
  String get username;

  /// No description provided for @uzbek.
  ///
  /// In en, this message translates to:
  /// **'Uzbek'**
  String get uzbek;

  /// No description provided for @valencian.
  ///
  /// In en, this message translates to:
  /// **'Valencian'**
  String get valencian;

  /// No description provided for @vehicles.
  ///
  /// In en, this message translates to:
  /// **'Vehicles'**
  String get vehicles;

  /// No description provided for @venda.
  ///
  /// In en, this message translates to:
  /// **'Venda'**
  String get venda;

  /// No description provided for @version.
  ///
  /// In en, this message translates to:
  /// **'Version'**
  String get version;

  /// No description provided for @versionTooOld.
  ///
  /// In en, this message translates to:
  /// **'The version of this platform is too old.'**
  String get versionTooOld;

  /// No description provided for @videoChannelBanner.
  ///
  /// In en, this message translates to:
  /// **'Video channel banner'**
  String get videoChannelBanner;

  /// No description provided for @videochannelFollowersCount.
  ///
  /// In en, this message translates to:
  /// **'{followersCount} followers'**
  String videochannelFollowersCount(String followersCount);

  /// No description provided for @videoChannelManagedBy.
  ///
  /// In en, this message translates to:
  /// **'Video channel managed by'**
  String get videoChannelManagedBy;

  /// No description provided for @videoFilters.
  ///
  /// In en, this message translates to:
  /// **'Video Filters'**
  String get videoFilters;

  /// No description provided for @videoItem.
  ///
  /// In en, this message translates to:
  /// **'Video item'**
  String get videoItem;

  /// No description provided for @videoList.
  ///
  /// In en, this message translates to:
  /// **'Video list'**
  String get videoList;

  /// No description provided for @videos.
  ///
  /// In en, this message translates to:
  /// **'Videos'**
  String get videos;

  /// No description provided for @videoSettings.
  ///
  /// In en, this message translates to:
  /// **'Video settings'**
  String get videoSettings;

  /// No description provided for @vietnamese.
  ///
  /// In en, this message translates to:
  /// **'Vietnamese'**
  String get vietnamese;

  /// No description provided for @views.
  ///
  /// In en, this message translates to:
  /// **'views'**
  String get views;

  /// No description provided for @violentOrRepulsive.
  ///
  /// In en, this message translates to:
  /// **'Violent or repulsive'**
  String get violentOrRepulsive;

  /// No description provided for @violentOrRepulsiveDescription.
  ///
  /// In en, this message translates to:
  /// **'Contains offensive, violent, or coarse language or iconography.'**
  String get violentOrRepulsiveDescription;

  /// No description provided for @vodVideos.
  ///
  /// In en, this message translates to:
  /// **'VOD videos'**
  String get vodVideos;

  /// No description provided for @walloon.
  ///
  /// In en, this message translates to:
  /// **'Walloon'**
  String get walloon;

  /// No description provided for @watchLater.
  ///
  /// In en, this message translates to:
  /// **'Watch later'**
  String get watchLater;

  /// No description provided for @watchThisVideo.
  ///
  /// In en, this message translates to:
  /// **'Watch this video'**
  String get watchThisVideo;

  /// No description provided for @weeksAgo.
  ///
  /// In en, this message translates to:
  /// **'{number} weeks ago'**
  String weeksAgo(int number);

  /// No description provided for @welcomeOnPeertube.
  ///
  /// In en, this message translates to:
  /// **'Welcome on PeerTube!'**
  String get welcomeOnPeertube;

  /// No description provided for @welsh.
  ///
  /// In en, this message translates to:
  /// **'Welsh'**
  String get welsh;

  /// No description provided for @westernFrisian.
  ///
  /// In en, this message translates to:
  /// **'Western Frisian'**
  String get westernFrisian;

  /// No description provided for @wolof.
  ///
  /// In en, this message translates to:
  /// **'Wolof'**
  String get wolof;

  /// No description provided for @wordSeparator.
  ///
  /// In en, this message translates to:
  /// **' '**
  String get wordSeparator;

  /// No description provided for @worstMatch.
  ///
  /// In en, this message translates to:
  /// **'Worst Match'**
  String get worstMatch;

  /// No description provided for @xhosa.
  ///
  /// In en, this message translates to:
  /// **'Xhosa'**
  String get xhosa;

  /// No description provided for @yearsAgo.
  ///
  /// In en, this message translates to:
  /// **'{number} years ago'**
  String yearsAgo(int number);

  /// No description provided for @yiddish.
  ///
  /// In en, this message translates to:
  /// **'Yiddish'**
  String get yiddish;

  /// No description provided for @yoruba.
  ///
  /// In en, this message translates to:
  /// **'Yoruba'**
  String get yoruba;

  /// No description provided for @yourReportWillBeSentToModeratorsOfCurrenthost.
  ///
  /// In en, this message translates to:
  /// **'Your report will be sent to moderators of {currenthost}.'**
  String yourReportWillBeSentToModeratorsOfCurrenthost(String currenthost);

  /// No description provided for @yourReportWillBeSentToModeratorsOfCurrenthostAndWillBeForwardedToTheVideoOriginVideodetailsAccountHostToo.
  ///
  /// In en, this message translates to:
  /// **'Your report will be sent to moderators of {currenthost} and will be forwarded to the video origin ({otherHost}) too.'**
  String yourReportWillBeSentToModeratorsOfCurrenthostAndWillBeForwardedToTheVideoOriginVideodetailsAccountHostToo(String currenthost, String otherHost);

  /// No description provided for @zhuang.
  ///
  /// In en, this message translates to:
  /// **'Zhuang'**
  String get zhuang;

  /// No description provided for @zulu.
  ///
  /// In en, this message translates to:
  /// **'Zulu'**
  String get zulu;
}

class _AppLocalizationsDelegate extends LocalizationsDelegate<AppLocalizations> {
  const _AppLocalizationsDelegate();

  @override
  Future<AppLocalizations> load(Locale locale) {
    return SynchronousFuture<AppLocalizations>(lookupAppLocalizations(locale));
  }

  @override
  bool isSupported(Locale locale) => <String>['ca', 'cs', 'de', 'en', 'eu', 'fr', 'gl', 'it', 'ja', 'pl', 'ru', 'th'].contains(locale.languageCode);

  @override
  bool shouldReload(_AppLocalizationsDelegate old) => false;
}

AppLocalizations lookupAppLocalizations(Locale locale) {


  // Lookup logic when only language code is specified.
  switch (locale.languageCode) {
    case 'ca': return AppLocalizationsCa();
    case 'cs': return AppLocalizationsCs();
    case 'de': return AppLocalizationsDe();
    case 'en': return AppLocalizationsEn();
    case 'eu': return AppLocalizationsEu();
    case 'fr': return AppLocalizationsFr();
    case 'gl': return AppLocalizationsGl();
    case 'it': return AppLocalizationsIt();
    case 'ja': return AppLocalizationsJa();
    case 'pl': return AppLocalizationsPl();
    case 'ru': return AppLocalizationsRu();
    case 'th': return AppLocalizationsTh();
  }

  throw FlutterError(
    'AppLocalizations.delegate failed to load unsupported locale "$locale". This is likely '
    'an issue with the localizations generation tool. Please file an issue '
    'on GitHub with a reproducible sample app and the gen-l10n configuration '
    'that was used.'
  );
}
