import 'dart:io';

import 'package:peertube_mobile/features/account/account_model.dart';
import 'package:peertube_mobile/features/video/channel/channel_model.dart';
import 'package:peertube_mobile/shared/current_platform/current_platform_models.dart';
import 'package:peertube_mobile/shared/filters/account/account_params_model.dart';
import 'package:peertube_mobile/shared/network/http_service.dart';

class AccountDatasource {
  final CurrentPlatform currentPlatform;
  final HttpService httpService;

  AccountDatasource({
    required this.currentPlatform,
    required this.httpService,
  });

  Future<AccountDetails> fetchAccount(String name) async {
    final response = await httpService.get(
      path: currentPlatform.getApiBaseUrl('/accounts/$name'),
      expectedStatusCode: HttpStatus.ok,
    );

    try {
      return AccountDetails.fromJson(response.data);
    } catch (e) {
      throw Exception('Error parsing account: $e');
    }
  }

  Future<List<VideoChannelDetails>> fetchVideoChannels(
    String name, {
    AccountParams? commonParams,
  }) async {
    final AccountParams params = commonParams ?? const AccountParams();
    final Map<String, dynamic> queryParams = params.toJson();

    final response = await httpService.get(
      path: currentPlatform.getApiBaseUrl('/accounts/$name/video-channels'),
      queryParameters: queryParams,
      expectedStatusCode: HttpStatus.ok,
    );

    return response.data['data'].map<VideoChannelDetails>((json) {
      try {
        return VideoChannelDetails.fromJson(json);
      } catch (e) {
        throw Exception('Error parsing video: $e');
      }
    }).toList();
  }

  Future<int> getTotalVideoChannels(
    String name,
  ) async {
    const AccountParams params = AccountParams(count: 0);
    final Map<String, dynamic> queryParams = params.toJson();

    final response = await httpService.get(
      path: currentPlatform.getApiBaseUrl('/accounts/$name/video-channels'),
      queryParameters: queryParams,
      expectedStatusCode: HttpStatus.ok,
    );

    return response.data['total'];
  }
}
