import 'package:sqflite/sqflite.dart';

import 'package:peertube_mobile/features/account/connected_account/connected_account_model.dart';
import 'package:peertube_mobile/shared/preferences/user_preferences.dart';

class ConnectedAccountService {
  final SharedUtility sharedUtility;
  final Database database;

  ConnectedAccountService({
    required this.sharedUtility,
    required this.database,
  });

  Future<ConnectedAccountSQL?> getFavoriteAccount() async {
    final List<Map<String, dynamic>> result = await database.query(
      'ConnectedAccount',
      where: 'isFavorite = ?',
      whereArgs: [1],
    );

    if (result.isNotEmpty) {
      return ConnectedAccountSQL.fromMap(result.first);
    }

    return null;
  }

  Future<ConnectedAccountSQL> getAccountByUsernameAndHost(
    String username,
    String host,
  ) async {
    final result = await database.query(
      'ConnectedAccount',
      where: 'username = ? AND host = ?',
      whereArgs: [username, host],
    );

    if (result.isNotEmpty) {
      return ConnectedAccountSQL.fromMap(result.first);
    }
    throw (Exception('Did not find any account with this userWithHost field'));
  }

  Future<ConnectedAccountSQL> getLocalAccount() async {
    return await getAccountByUsernameAndHost(
      'sepia',
      'localhost',
    );
  }
}
