import 'package:flutter_riverpod/flutter_riverpod.dart';

import 'package:peertube_mobile/features/account/connected_account/local_account/local_account_model.dart';
import 'package:peertube_mobile/features/account/connected_account/local_account/local_account_providers.dart';
import 'package:peertube_mobile/features/video/video_model.dart';

class AsyncLocalHistoryNotifier
    extends AsyncNotifier<List<LocalHistoryElementSQL>> {
  Future<List<LocalHistoryElementSQL>> _fetchHistory() async {
    return await ref.read(localAccountServiceProvider).getHistory();
  }

  @override
  Future<List<LocalHistoryElementSQL>> build() async {
    return await _fetchHistory();
  }

  Future<void> addToHistory(
    VideoAbstract video,
    String domain,
    int currentPosition,
  ) async {
    state = await AsyncValue.guard(() async {
      await ref.read(localAccountServiceProvider).addVideoToHistory(
            domain: domain,
            video: video,
            currentPosition: currentPosition,
          );
      return _fetchHistory();
    });
  }

  Future<void> removeFromHistory(
    LocalHistoryElementSQL element,
  ) async {
    state = await AsyncValue.guard(() async {
      await ref.read(localAccountServiceProvider).removeFromHistory(
            element: element,
          );
      return _fetchHistory();
    });
  }

  Future<void> clearHistory() async {
    state = await AsyncValue.guard(() async {
      await ref.read(localAccountServiceProvider).deleleAllHistory();
      return _fetchHistory();
    });
  }

  Future<void> updateCurrentPosition(
    String videoUuid,
    int newPosition,
  ) async {
    state = await AsyncValue.guard(() async {
      await ref.read(localAccountServiceProvider).updateCurrentPosition(
            videoUuid: videoUuid,
            currentPosition: newPosition,
          );
      return _fetchHistory();
    });
  }
}
