import 'package:flutter_riverpod/flutter_riverpod.dart';

import 'package:peertube_mobile/features/account/connected_account/local_account/local_account_model.dart';
import 'package:peertube_mobile/features/account/connected_account/local_account/local_account_providers.dart';
import 'package:peertube_mobile/features/video/video_model.dart';

class AsyncWatchLaterListNotifier
    extends AsyncNotifier<List<LocalWatchLaterPlaylistElementSQL>> {
  Future<List<LocalWatchLaterPlaylistElementSQL>> _fetchWatchLater() async {
    return await ref.read(localAccountServiceProvider).getWatchLater();
  }

  @override
  Future<List<LocalWatchLaterPlaylistElementSQL>> build() async {
    return await _fetchWatchLater();
  }

  Future<void> addToWatchLater(String domain, VideoAbstract video) async {
    state = await AsyncValue.guard(() async {
      await ref.read(localAccountServiceProvider).addToWatchLater(
            domain: domain,
            video: video,
          );
      return _fetchWatchLater();
    });
  }

  Future<void> removeFromWatchLater(
    String videoUuid,
  ) async {
    state = await AsyncValue.guard(() async {
      await ref.read(localAccountServiceProvider).removeFromWatchLater(
            videoUuid: videoUuid,
          );
      return _fetchWatchLater();
    });
  }

  Future<void> clearWatchLater() async {
    state = await AsyncValue.guard(() async {
      await ref.read(localAccountServiceProvider).deleteAllWatchLater();
      return _fetchWatchLater();
    });
  }

  Future<void> reorderWatchLater({
    required int oldIndex,
    required int newIndex,
  }) async {
    state = await AsyncValue.guard(() async {
      await ref.read(localAccountServiceProvider).reorderWatchLaterElements(
            oldIndex: oldIndex,
            newIndex: newIndex,
          );
      return _fetchWatchLater();
    });
  }

  Future<bool> isInWatchLater(String videoUuid) async {
    final watchLaterElements = state.value;
    if (watchLaterElements == null) {
      return false;
    }
    return watchLaterElements.any((element) => element.videoUuid == videoUuid);
  }
}
