import 'dart:io';

import 'package:dio/dio.dart';

import 'package:peertube_mobile/features/moderation/predefined_reasons_enum.dart';
import 'package:peertube_mobile/shared/current_platform/current_platform_models.dart';
import 'package:peertube_mobile/shared/network/http_service.dart';

class AbuseDatasource {
  final CurrentPlatform currentPlatform;
  final HttpService httpService;

  AbuseDatasource({
    required this.currentPlatform,
    required this.httpService,
  });
  Future<int> reportAbuse({
    required String reason,
    int? videoId,
    int? videoStartAt,
    int? videoEndAt,
    int? accountId,
    int? commentId,
    List<PredefinedReasons>? predefinedReasons,
  }) async {
    try {
      final Map<String, dynamic> formData = {
        'reason': reason,
        'predefinedReasons':
            predefinedReasons?.map((e) => e.toString()).toList() ?? [],
        'video': {
          'id': videoId,
          'startAt': videoStartAt,
          'endAt': videoEndAt,
        },
        'comment': {
          'id': commentId,
        },
        'account': {
          'id': accountId,
        },
      };

      formData.removeWhere((key, value) => value == null);

      final response = await httpService.post(
        path: currentPlatform.getApiBaseUrl('/abuses'),
        body: FormData.fromMap(formData),
      );

      if (response.statusCode == HttpStatus.ok) {
        return response.data['abuse']['id'];
      } else {
        throw Exception(response.data['error']);
      }
    } catch (e) {
      throw Exception('An error has occurred : $e');
    }
  }
}
