import 'package:flutter_riverpod/flutter_riverpod.dart';

import 'package:peertube_mobile/features/account/connected_account/connected_account_model.dart';
import 'package:peertube_mobile/features/account/connected_account/connected_account_providers.dart';
import 'package:peertube_mobile/features/platform/history/platform_history_model.dart';
import 'package:peertube_mobile/features/platform/history/platform_history_providers.dart';

class AsyncPlatformHistoryNotifier
    extends AsyncNotifier<List<PlatformHistoryElementSQL>> {
  Future<void> addBookmark(
    PlatformHistoryElementSQL platform,
  ) async {
    final account = await ref.read(currentConnectedAccountProvider.future);

    state = await AsyncValue.guard(() async {
      await ref.read(platformHistoryServiceProvider).addToBookmarks(platform);
      return _fetchHistory(account);
    });
  }

  Future<void> addPlatform({
    required String domain,
    required String name,
    String? avatarUrl,
  }) async {
    final account = await ref.read(currentConnectedAccountProvider.future);

    state = await AsyncValue.guard(() async {
      await ref.read(platformHistoryServiceProvider).addPlatformToHistory(
            domain: domain,
            name: name,
            account: account,
            avatarUrl: avatarUrl,
          );
      return _fetchHistory(account);
    });
  }

  @override
  Future<List<PlatformHistoryElementSQL>> build() async {
    final account = await ref.read(currentConnectedAccountProvider.future);
    return await _fetchHistory(account);
  }

  Future<void> delete(
    PlatformHistoryElementSQL platform,
  ) async {
    final account = await ref.read(currentConnectedAccountProvider.future);
    if (platform.id != null) {
      state = await AsyncValue.guard(() async {
        await ref.read(platformHistoryServiceProvider).delete(platform.id!);
        return _fetchHistory(account);
      });
    }
  }

  Future<void> removeBookmark(
    PlatformHistoryElementSQL platform,
  ) async {
    final account = await ref.read(currentConnectedAccountProvider.future);

    state = await AsyncValue.guard(() async {
      await ref
          .read(platformHistoryServiceProvider)
          .removeFromBookmarks(platform);
      return _fetchHistory(account);
    });
  }

  Future<List<PlatformHistoryElementSQL>> _fetchHistory(
    ConnectedAccountSQL account,
  ) async {
    return ref.read(platformHistoryServiceProvider).getPlatforms(account);
  }
}
