import 'package:flutter/material.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:go_router/go_router.dart';
import 'package:lucide_icons/lucide_icons.dart';

import 'package:peertube_mobile/features/account/connected_account/connected_account_providers.dart';
import 'package:peertube_mobile/features/platform/history/platform_history_providers.dart';
import 'package:peertube_mobile/features/platform/history/widgets/platform_history_carousel_item.dart';
import 'package:peertube_mobile/features/platform/history/widgets/platform_history_modal.dart';
import 'package:peertube_mobile/features/platform/platform_miniature.dart';
import 'package:peertube_mobile/shared/current_platform/current_platform_providers.dart';
import 'package:peertube_mobile/shared/utils/translate.dart';
import 'package:peertube_mobile/shared/widgets/async_value.dart';

class PlatformHistoryCarousel extends ConsumerWidget {
  const PlatformHistoryCarousel({super.key});

  @override
  Widget build(context, ref) {
    ColorScheme colorScheme = Theme.of(context).colorScheme;
    return SizedBox(
      height: 58,
      child: AsyncValueWidget(
        value: ref.watch(platformHistoryProvider),
        dataBuilder: (platforms) {
          final currentPlatform = platforms.firstWhere(
            (platform) =>
                platform.domain ==
                ref.read(currentPlatformNonNullableProvider).domain,
          );
          return ListView(
            scrollDirection: Axis.horizontal,
            children: [
              PlatformHistoryCarouselItem(
                domain: currentPlatform.domain,
                name: currentPlatform.name,
                isCurrentPlatform: true,
                bookmarked: currentPlatform.bookmarked,
                avatarUrl: currentPlatform.avatarUrl,
                onTap: () {},
                onLongPress: () {},
                onTapHint: t(context)!.pin,
              ),
              ...platforms.map((platform) {
                if (platform.domain != currentPlatform.domain) {
                  return Opacity(
                    opacity: 0.6,
                    child: PlatformHistoryCarouselItem(
                      domain: platform.domain,
                      name: platform.name,
                      isCurrentPlatform: false,
                      bookmarked: platform.bookmarked,
                      avatarUrl: platform.avatarUrl,
                      onTapHint: t(context)!
                          .switchToPlatformInstanceName(platform.name),
                      onTap: () => {
                        ref.read(currentConnectedAccountProvider).maybeWhen(
                              data: (account) async {
                                final success = await ref
                                    .read(currentPlatformServiceProvider)
                                    .updateCurrentPlatform(
                                      ref,
                                      platform.domain,
                                      account,
                                    );
                                if (context.mounted) {
                                  if (success) {
                                    ref.invalidate(platformHistoryProvider);
                                    GoRouter.of(context).pushReplacement('/');
                                  } else {
                                    await showPlatformNotRespondingDialog(
                                      context,
                                      platform.name,
                                    );
                                  }
                                }
                              },
                              orElse: () => false,
                            ),
                      },
                      onLongPress: () {},
                    ),
                  );
                } else {
                  return const SizedBox.shrink();
                }
              }),
              Padding(
                padding: const EdgeInsets.all(4.0),
                child: SizedBox(
                  height: 50,
                  width: 50,
                  child: IconButton(
                    style: ButtonStyle(
                      side: WidgetStateProperty.all(
                        BorderSide(
                          color: colorScheme.surfaceContainerHighest,
                          width: 2,
                        ),
                      ),
                      shape: WidgetStateProperty.all(
                        RoundedRectangleBorder(
                          borderRadius: BorderRadius.circular(
                            12.0,
                          ),
                        ),
                      ),
                    ),
                    onPressed: () =>
                        GoRouter.of(context).push('/explore/platforms'),
                    icon: Icon(
                      semanticLabel: t(context)!.addAPlatform,
                      LucideIcons.plus,
                      size: 24.0,
                    ),
                  ),
                ),
              ),
              IconButton(
                onPressed: () => showModalBottomSheet(
                  context: context,
                  isScrollControlled: true,
                  builder: (BuildContext context) {
                    return const PlatformHistoryModal();
                  },
                ),
                icon: Icon(
                  semanticLabel: t(context)!.showFullHistory,
                  LucideIcons.moreVertical,
                  size: 24.0,
                ),
              ),
            ],
          );
        },
      ),
    );
  }
}
