import 'package:flutter/material.dart';

import 'package:lucide_icons/lucide_icons.dart';

import 'package:peertube_mobile/shared/widgets/avatar_builder.dart';

class PlatformHistoryCarouselItem extends StatelessWidget {
  final String domain;
  final String name;
  final bool isCurrentPlatform;
  final bool bookmarked;
  final String? avatarUrl;
  final VoidCallback onTap;
  final VoidCallback onLongPress;
  final String onTapHint;
  final String? onLongPressHint;

  const PlatformHistoryCarouselItem({
    super.key,
    required this.domain,
    required this.name,
    this.isCurrentPlatform = false,
    this.bookmarked = false,
    this.avatarUrl,
    required this.onTap,
    required this.onLongPress,
    required this.onTapHint,
    this.onLongPressHint,
  });

  @override
  Widget build(BuildContext context) {
    final colorScheme = Theme.of(context).colorScheme;
    return Padding(
      padding: const EdgeInsets.symmetric(horizontal: 4.0),
      child: Semantics(
        label: name,
        onTapHint: onTapHint,
        onLongPressHint: onLongPressHint,
        child: GestureDetector(
          onTap: onTap,
          onLongPress: onLongPress,
          child: Container(
            decoration: BoxDecoration(
              border: Border.all(
                width: 2,
                color: isCurrentPlatform
                    ? colorScheme.primary
                    : Colors.transparent,
              ),
              borderRadius: BorderRadius.circular(16),
            ),
            child: Center(
              child: Stack(
                children: [
                  AvatarBuilder(
                    domain: domain,
                    name: name,
                    avatarUrl: avatarUrl,
                    size: 54,
                    borderRadius: 16,
                    borderWidth: 3,
                  ),
                  if (bookmarked)
                    Positioned(
                      right: 3,
                      bottom: 3,
                      child: Container(
                        width: 17,
                        height: 17,
                        decoration: BoxDecoration(
                          color: colorScheme.surface,
                          borderRadius: const BorderRadius.only(
                            bottomRight: Radius.circular(12.0),
                            topLeft: Radius.circular(4.0),
                          ),
                          border: Border.all(
                            width: 1.2,
                            color: colorScheme.surface,
                          ),
                        ),
                        child: const Icon(
                          LucideIcons.pin,
                          size: 9,
                        ),
                      ),
                    ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}
