import 'package:flutter/material.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:grouped_list/grouped_list.dart';

import 'package:peertube_mobile/features/account/connected_account/connected_account_providers.dart';
import 'package:peertube_mobile/features/platform/history/platform_history_model.dart';
import 'package:peertube_mobile/features/platform/history/platform_history_providers.dart';
import 'package:peertube_mobile/features/platform/history/widgets/platform_history_modal_items.dart';
import 'package:peertube_mobile/features/platform/platform_miniature.dart';
import 'package:peertube_mobile/shared/current_platform/current_platform_providers.dart';
import 'package:peertube_mobile/shared/utils/translate.dart';
import 'package:peertube_mobile/shared/widgets/async_value.dart';

class PlatformHistoryModal extends ConsumerWidget {
  const PlatformHistoryModal({
    super.key,
  });

  @override
  Widget build(context, ref) {
    final colorsScheme = Theme.of(context).colorScheme;
    return DraggableScrollableSheet(
      expand: false,
      snap: true,
      initialChildSize: 0.9,
      maxChildSize: 1,
      snapSizes: const <double>[0.9],
      builder: (BuildContext context, ScrollController scrollController) {
        return Container(
          color: colorsScheme.secondary,
          child: Column(
            children: <Widget>[
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  SingleChildScrollView(
                    controller: scrollController,
                    child: Align(
                      alignment: Alignment.topCenter,
                      child: Container(
                        margin: const EdgeInsets.symmetric(vertical: 25),
                        height: 4.0,
                        width: 32.0,
                        decoration: BoxDecoration(
                          color: colorsScheme.onSecondary,
                          borderRadius: BorderRadius.circular(10.0),
                        ),
                      ),
                    ),
                  ),
                  const SizedBox(height: 16),
                  Padding(
                    padding: const EdgeInsets.symmetric(horizontal: 24),
                    child: Text(
                      t(context)!.plateformsHistory,
                      style: const TextStyle(
                        fontSize: 20,
                        fontWeight: FontWeight.bold,
                      ),
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.symmetric(horizontal: 24),
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: <Widget>[
                        const SizedBox(height: 20.0),
                        AsyncValueWidget(
                          value: ref.read(currentConnectedAccountProvider),
                          dataBuilder: (account) => Text(
                            t(context)!.linkedToAccountAccountName(
                              account.displayName,
                            ),
                          ),
                        ),
                      ],
                    ),
                  ),
                  const SizedBox(height: 16),
                ],
              ),
              Expanded(
                child: AsyncValueWidget(
                  value: ref.watch(platformHistoryProvider),
                  dataBuilder: (platforms) {
                    final currentPlatform = platforms.firstWhere(
                      (platform) =>
                          platform.domain ==
                          ref.read(currentPlatformNonNullableProvider).domain,
                    );
                    return GroupedListView<PlatformHistoryElementSQL, String>(
                      elements: platforms,
                      groupBy: (platform) => platform.bookmarked
                          ? t(context)!.bookmarkedPlatforms
                          : t(context)!.unbookmarkedPlatforms,
                      groupSeparatorBuilder: (String groupByValue) => Container(
                        width: double.infinity,
                        padding: const EdgeInsets.symmetric(
                          horizontal: 24.0,
                          vertical: 4.0,
                        ),
                        color: colorsScheme.secondary,
                        child: Text(
                          groupByValue,
                          style: const TextStyle(
                            fontSize: 20,
                            fontWeight: FontWeight.bold,
                          ),
                          textAlign: TextAlign.left,
                        ),
                      ),
                      itemBuilder:
                          (context, PlatformHistoryElementSQL platform) =>
                              PlatformHistoryModalItem(
                        platform: platform,
                        isCurrentPlatform: currentPlatform == platform,
                        onTap: () async {
                          if (currentPlatform == platform) {
                            Navigator.of(context).pop();
                          } else {
                            ref.read(currentConnectedAccountProvider).maybeWhen(
                                  data: (account) async {
                                    final success = await ref
                                        .read(
                                          currentPlatformServiceProvider,
                                        )
                                        .updateCurrentPlatform(
                                          ref,
                                          platform.domain,
                                          account,
                                        );
                                    if (context.mounted) {
                                      if (success) {
                                        ref.invalidate(platformHistoryProvider);
                                        if (context.mounted) {
                                          Navigator.of(context).pop();
                                        }
                                      } else {
                                        await showPlatformNotRespondingDialog(
                                          context,
                                          platform.name,
                                        );
                                      }
                                    }
                                  },
                                  orElse: () => false,
                                );
                          }
                        },
                      ),
                      useStickyGroupSeparators: true,
                      floatingHeader: true,
                      order: GroupedListOrder.ASC,
                    );
                  },
                ),
              ),
            ],
          ),
        );
      },
    );
  }
}
