import 'package:flutter/material.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';

import 'package:peertube_mobile/features/platform/joinpeertube/joinpeertube_models.dart';
import 'package:peertube_mobile/features/platform/joinpeertube/joinpeertube_providers.dart';
import 'package:peertube_mobile/features/platform/platform_miniature.dart';
import 'package:peertube_mobile/shared/filters/filters_providers.dart';
import 'package:peertube_mobile/shared/filters/platform/platform_params_model.dart';
import 'package:peertube_mobile/shared/filters/platform/platform_params_notifier.dart';

class PlatformJPTListHorizontal extends ConsumerWidget {
  final StateProvider? counterProvider;
  const PlatformJPTListHorizontal({
    this.counterProvider,
    super.key,
  });

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final platformDatasource = ref.watch(joinpeertubeDatasourceProvider);

    return FutureBuilder<List<PlatformJPT>>(
      future: platformDatasource.listPlatforms(
        ref.watch(explorePlatformFilterProvider).copyWith(count: 5),
      ),
      builder: (context, snapshot) {
        if (snapshot.connectionState == ConnectionState.waiting) {
          return const Center(child: CircularProgressIndicator());
        }

        if (snapshot.hasError) {
          return Center(child: Text('Error: ${snapshot.error}'));
        }

        final platforms = snapshot.data ?? [];

        if (counterProvider != null) {
          WidgetsBinding.instance.addPostFrameCallback((_) {
            ref.read(counterProvider!.notifier).state = platforms.length;
          });
        }

        return ListView.builder(
          scrollDirection: Axis.horizontal,
          itemCount: platforms.length,
          itemBuilder: (context, index) {
            final item = platforms[index];

            return PlatformMiniature(
              platformJPT: item,
            );
          },
        );
      },
    );
  }
}

class PlatformFilterChipsWidget extends ConsumerWidget {
  final PlatformParams params;
  final PlatformParamsNotifier paramsNotifier;

  const PlatformFilterChipsWidget({
    required this.params,
    required this.paramsNotifier,
    super.key,
  });

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    return SizedBox(
      height: 48,
      child: ListView(
        scrollDirection: Axis.horizontal,
        children: [
          Row(
            children: [
              Padding(
                padding: const EdgeInsets.symmetric(horizontal: 8.0),
                child: FilterChip(
                  label: Text(
                    getPlatformSortCriteriaString(
                      context,
                      PlatformSortCriteria.totalUsersDesc,
                    ),
                  ),
                  selected: params.sort == PlatformSortCriteria.totalUsersDesc,
                  onSelected: (isSelected) {
                    paramsNotifier.update(
                      sort: PlatformSortCriteria.totalUsersDesc,
                    );
                  },
                ),
              ),
              Padding(
                padding: const EdgeInsets.symmetric(horizontal: 8.0),
                child: FilterChip(
                  label: Text(
                    getPlatformSortCriteriaString(
                      context,
                      PlatformSortCriteria.totalLocalVideosDesc,
                    ),
                  ),
                  selected:
                      params.sort == PlatformSortCriteria.totalLocalVideosDesc,
                  onSelected: (isSelected) {
                    paramsNotifier.update(
                      sort: PlatformSortCriteria.totalLocalVideosDesc,
                    );
                  },
                ),
              ),
              // const SizedBox(width: 8),
              // UnderlinedTextButton(
              //   onPressed: () {
              //     GoRouter.of(context).push('/explore/filters/contents');
              //   },
              //   text: 'More Filters',
              //   textStyle: Theme.of(context)
              //       .textTheme
              //       .displaySmall!
              //       .copyWith(color: Theme.of(context).colorScheme.onSecondary),
              // ),
            ],
          ),
        ],
      ),
    );
  }
}
