import 'dart:io';

import 'package:flutter/material.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:go_router/go_router.dart';
import 'package:infinite_scroll_pagination/infinite_scroll_pagination.dart';

import 'package:peertube_mobile/features/platform/joinpeertube/joinpeertube_models.dart';
import 'package:peertube_mobile/features/platform/joinpeertube/joinpeertube_providers.dart';
import 'package:peertube_mobile/features/platform/platform_banner.dart';
import 'package:peertube_mobile/shared/filters/platform/platform_params_model.dart';
import 'package:peertube_mobile/shared/utils/translate.dart';
import 'package:peertube_mobile/shared/widgets/button.dart';

class PlatformListView extends ConsumerStatefulWidget {
  final PlatformParams params;
  final bool isNested;
  final StateProvider? counterProvider;

  const PlatformListView({
    super.key,
    required this.params,
    this.isNested = true,
    this.counterProvider,
  });

  @override
  ConsumerState<PlatformListView> createState() => _InstanceListViewState();
}

class _InstanceListViewState extends ConsumerState<PlatformListView> {
  static const _pageSize = 20;

  final PagingController<int, PlatformJPT> _pagingController =
      PagingController(firstPageKey: 0);

  @override
  Widget build(BuildContext context) {
    return PagedListView<int, PlatformJPT>(
      pagingController: _pagingController,
      physics: widget.isNested ? const NeverScrollableScrollPhysics() : null,
      shrinkWrap: widget.isNested,
      builderDelegate: PagedChildBuilderDelegate<PlatformJPT>(
        itemBuilder: (context, item, index) => PlatformBannerFromJPT(
          platformJPT: item,
        ),
        noItemsFoundIndicatorBuilder: (context) => Platform.isIOS
            ? const SizedBox.shrink()
            : Column(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  const SizedBox(height: 32),
                  Text(
                    t(context)!.noPlatformsFound,
                    style: const TextStyle(fontSize: 16),
                  ),
                  const SizedBox(height: 32),
                  CustomElevatedButton(
                    onPressed: () =>
                        GoRouter.of(context).push('/explore/platforms/add'),
                    child: Text(t(context)!.addAPlatformWithItsUrl),
                  ),
                ],
              ),
      ),
    );
  }

  @override
  void didUpdateWidget(PlatformListView oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.params != widget.params) {
      _pagingController.refresh();
    }
  }

  @override
  void dispose() {
    _pagingController.dispose();
    super.dispose();
  }

  @override
  void initState() {
    _pagingController.addPageRequestListener((pageKey) {
      _fetchPage(pageKey);
    });
    super.initState();
  }

  Future<void> _fetchPage(int pageKey) async {
    try {
      final newItems =
          await ref.read(joinpeertubeDatasourceProvider).listPlatforms(
                widget.params.copyWith(start: pageKey, count: _pageSize),
              );
      if (!mounted) {
        return;
      }
      final isLastPage = newItems.length < _pageSize;
      if (isLastPage) {
        _pagingController.appendLastPage(newItems);
      } else {
        final nextPageKey = pageKey + newItems.length;
        _pagingController.appendPage(newItems, nextPageKey);
      }
    } catch (error) {
      _pagingController.error = error;
    }
  }
}
