import 'package:json_annotation/json_annotation.dart';

import 'package:peertube_mobile/features/account/account_model.dart';
import 'package:peertube_mobile/shared/actor/actor_image_model.dart';
import 'package:peertube_mobile/shared/actor/actor_model.dart';

part 'channel_model.g.dart';

@JsonSerializable()
class VideoChannel implements Actor {
  @override
  final int id;
  @override
  final String url;
  @override
  final String name;
  @override
  final String host;
  @override
  final String displayName;
  @override
  final List<ActorImage> avatars;

  VideoChannel({
    required this.id,
    required this.url,
    required this.name,
    required this.host,
    required this.displayName,
    required this.avatars,
  });

  factory VideoChannel.fromJson(Map<String, dynamic> json) =>
      _$VideoChannelFromJson(json);
  Map<String, dynamic> toJson() => _$VideoChannelToJson(this);
}

@JsonSerializable()
class VideoChannelDetails implements Actor {
  @override
  final int id;
  @override
  final String url;
  @override
  final String name;
  @override
  final String host;
  final bool? hostRedundancyAllowed;
  final int followingCount;
  final int followersCount;
  final DateTime createdAt;
  @override
  final String displayName;
  final DateTime updatedAt;
  @override
  final List<ActorImage> avatars;
  final List<ActorImage> banners;
  final String? description;
  final String? support;
  final bool isLocal;
  final AccountDetails ownerAccount;

  VideoChannelDetails({
    required this.id,
    required this.url,
    required this.name,
    required this.host,
    this.hostRedundancyAllowed,
    required this.followingCount,
    required this.followersCount,
    required this.createdAt,
    required this.displayName,
    required this.updatedAt,
    required this.avatars,
    required this.banners,
    this.description,
    this.support,
    required this.isLocal,
    required this.ownerAccount,
  });

  factory VideoChannelDetails.fromJson(Map<String, dynamic> json) =>
      _$VideoChannelDetailsFromJson(json);
  Map<String, dynamic> toJson() => _$VideoChannelDetailsToJson(this);
}
