import 'dart:io';

import 'package:peertube_mobile/features/video/comments/comment_model.dart';
import 'package:peertube_mobile/shared/current_platform/current_platform_models.dart';
import 'package:peertube_mobile/shared/filters/comment/comment_params_model.dart';
import 'package:peertube_mobile/shared/network/http_service.dart';

class VideoCommentDatasource {
  final CurrentPlatform currentPlatform;
  final HttpService httpService;

  VideoCommentDatasource({
    required this.currentPlatform,
    required this.httpService,
  });

  Future<List<VideoCommentThread>> fetchThreads(
    String videoUuid, {
    CommentParams? commonParams,
  }) async {
    final CommentParams params = commonParams ?? const CommentParams();
    final Map<String, dynamic> queryParams = params.toJson();

    final response = await httpService.get(
      path:
          currentPlatform.getApiBaseUrl('/videos/$videoUuid/comment-threads/'),
      queryParameters: queryParams,
      expectedStatusCode: HttpStatus.ok,
    );

    return response.data['data'].map<VideoCommentThread>((json) {
      try {
        return VideoCommentThread.fromJson(json);
      } catch (e) {
        throw Exception('Error parsing video: $e');
      }
    }).toList();
  }

  Future<int> getTotalNotDeletedComments(
    String videoUuid,
  ) async {
    const params = CommentParams(count: 0);
    final Map<String, dynamic> queryParams = params.toJson();

    final response = await httpService.get(
      path:
          currentPlatform.getApiBaseUrl('/videos/$videoUuid/comment-threads/'),
      queryParameters: queryParams,
      expectedStatusCode: HttpStatus.ok,
    );

    return response.data['totalNotDeletedComments'];
  }

  Future<VideoCommentThreadTree> fetchThread(
    int videoId,
    int threadId,
  ) async {
    final response = await httpService.get(
      path: currentPlatform
          .getApiBaseUrl('/videos/$videoId/comment-threads/$threadId'),
      expectedStatusCode: HttpStatus.ok,
    );

    try {
      return VideoCommentThreadTree.fromJson(response.data);
    } catch (e) {
      throw Exception('Error parsing video comment thread tree: $e');
    }
  }
}
