import 'package:flutter/material.dart';

import 'package:lucide_icons/lucide_icons.dart';

import 'package:peertube_mobile/features/video/comments/comment_model.dart';
import 'package:peertube_mobile/features/video/comments/comment_tile.dart';

class CommentThreadModal extends StatelessWidget {
  final VideoCommentThreadTree threadTree;
  final bool isLocalAccount;

  const CommentThreadModal({
    super.key,
    required this.threadTree,
    required this.isLocalAccount,
  });

  @override
  Widget build(BuildContext context) {
    final colorScheme = Theme.of(context).colorScheme;
    return DraggableScrollableSheet(
      initialChildSize: 0.5,
      minChildSize: 0.3,
      maxChildSize: 0.9,
      expand: false,
      builder: (context, scrollController) {
        return ListView(
          controller: scrollController,
          children: [
            Padding(
              padding: const EdgeInsets.symmetric(
                horizontal: 12.0,
                vertical: 4.0,
              ),
              child: Stack(
                children: [
                  IconButton(
                    icon: const Icon(LucideIcons.arrowLeft),
                    onPressed: () => Navigator.pop(context),
                  ),
                  Center(
                    child: Container(
                      width: 40,
                      height: 4,
                      margin: const EdgeInsets.symmetric(vertical: 18.0),
                      decoration: BoxDecoration(
                        color: colorScheme.onTertiary,
                        borderRadius: BorderRadius.circular(2),
                      ),
                    ),
                  ),
                ],
              ),
            ),
            CommentTile(
              commentThread: threadTree.comment,
              isLocalAccount: isLocalAccount,
              index: 1,
              isParent: true,
            ),
            ...threadTree.children.map(
              (child) => Padding(
                padding: const EdgeInsets.only(left: 16.0),
                child: CommentTile(
                  commentThread: child,
                  isLocalAccount: isLocalAccount,
                  index: 0,
                ),
              ),
            ),
          ],
        );
      },
    );
  }
}
