import 'dart:io';

import 'package:dio/dio.dart';

import 'package:peertube_mobile/features/video/video_model.dart';
import 'package:peertube_mobile/shared/current_platform/current_platform_models.dart';
import 'package:peertube_mobile/shared/filters/history/history_params_model.dart';
import 'package:peertube_mobile/shared/network/http_service.dart';

class HistoryDatasource {
  final CurrentPlatform currentPlatform;
  final HttpService httpService;

  HistoryDatasource({
    required this.currentPlatform,
    required this.httpService,
  });

  Future<List<Video>> fetchHistory({
    HistoryParams? commonParams,
  }) async {
    final HistoryParams params = commonParams ?? const HistoryParams();
    final Map<String, dynamic> queryParams = params.toJson();

    final response = await httpService.get(
      path: currentPlatform.getApiBaseUrl('/users/me/history/videos'),
      queryParameters: queryParams,
      expectedStatusCode: HttpStatus.ok,
    );

    return response.data['data'].map<Video>((json) {
      try {
        return Video.fromJson(json);
      } catch (e) {
        throw Exception('Error parsing video: $e');
      }
    }).toList();
  }

  Future<void> deleteHistoryElement(
    int videoId,
  ) async =>
      await httpService.delete(
        path: currentPlatform.getApiBaseUrl(
          'users/me/history/videos/$videoId',
        ),
        expectedStatusCode: 204,
      );

  Future<void> clearHistory({
    DateTime? beforeDate,
  }) async {
    final formData = {
      if (beforeDate != null) 'beforeDate': beforeDate,
    };

    await httpService.post(
      path: currentPlatform.getApiBaseUrl('/users/me/history/videos/remove'),
      body: FormData.fromMap(formData),
      expectedStatusCode: 204,
    );
  }
}
