import 'package:flutter/material.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:go_router/go_router.dart';
import 'package:lucide_icons/lucide_icons.dart';
import 'package:video_player/video_player.dart';
import 'package:wakelock_plus/wakelock_plus.dart';

import 'package:peertube_mobile/features/account/connected_account/local_account/local_account_providers.dart';
import 'package:peertube_mobile/features/video/captions/captions_providers.dart';
import 'package:peertube_mobile/features/video/chapters/chapters_providers.dart';
import 'package:peertube_mobile/features/video/miniplayer/widgets/play_button.dart';
import 'package:peertube_mobile/features/video/player/video_player.dart';
import 'package:peertube_mobile/features/video/player/video_progress_indicator.dart';
import 'package:peertube_mobile/features/video/storyboards/storyboards_providers.dart';
import 'package:peertube_mobile/features/video/video_model.dart';
import 'package:peertube_mobile/features/video/video_providers.dart';
import 'package:peertube_mobile/routes/utils/scaffold_with_navbar.dart';
import 'package:peertube_mobile/shared/current_platform/current_platform_providers.dart';
import 'package:peertube_mobile/shared/utils/translate.dart';
import 'package:peertube_mobile/shared/widgets/image.dart';

class PeerTubeMiniPlayer extends ConsumerWidget {
  const PeerTubeMiniPlayer({super.key});

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final VideoDetails? selectedVideo = ref.watch(selectedVideoProvider);
    final VideoPlayerController? videoPlayerController =
        ref.watch(videoPlayerControllerProvider);

    if (selectedVideo == null) {
      return const SizedBox.shrink();
    } else {
      return GestureDetector(
        onTap: () => GoRouter.of(context).push('/video/${selectedVideo.uuid}'),
        child: Container(
          color: Theme.of(context).scaffoldBackgroundColor,
          child: Column(
            children: <Widget>[
              Row(
                children: <Widget>[
                  Stack(
                    alignment: Alignment.center,
                    children: [
                      if (videoPlayerController != null) ...[
                        SizedBox(
                          height: 50,
                          child: PeerTubeVideoPlayer(
                            videoPlayerController: videoPlayerController,
                            showControls: false,
                          ),
                        ),
                        PlayButton(
                          videoPlayerController: videoPlayerController,
                          backgroundColor: Colors.black.withValues(alpha: 0.2),
                        ),
                      ] else ...[
                        CustomCachedNetworkImage(
                          imageUrl: Uri.parse(
                            ref
                                .watch(
                                  currentPlatformNonNullableProvider,
                                )
                                .domain,
                          )
                              .resolve(
                                selectedVideo.thumbnailPath ?? '',
                              )
                              .toString(),
                          height: playerMinHeight - 4.0,
                          width: 120.0,
                        ),
                      ],
                    ],
                  ),
                  Expanded(
                    child: Padding(
                      padding: const EdgeInsets.all(8.0),
                      child: Column(
                        crossAxisAlignment: CrossAxisAlignment.start,
                        mainAxisSize: MainAxisSize.min,
                        children: <Widget>[
                          Flexible(
                            child: Text(
                              selectedVideo.name,
                              overflow: TextOverflow.ellipsis,
                              style: Theme.of(context)
                                  .textTheme
                                  .bodySmall!
                                  .copyWith(
                                    fontWeight: FontWeight.bold,
                                  ),
                            ),
                          ),
                          Flexible(
                            child: Text(
                              selectedVideo.channel.name,
                              overflow: TextOverflow.ellipsis,
                              style: Theme.of(context)
                                  .textTheme
                                  .bodySmall!
                                  .copyWith(fontWeight: FontWeight.w500),
                            ),
                          ),
                        ],
                      ),
                    ),
                  ),
                  IconButton(
                    icon: Icon(
                      LucideIcons.x,
                      semanticLabel: t(context)!.closeVideo,
                    ),
                    onPressed: () async {
                      if (videoPlayerController != null) {
                        final String? currentId =
                            ref.read(selectedVideoProvider)?.uuid;
                        if (currentId != null) {
                          await ref
                              .read(localHistoryProvider.notifier)
                              .updateCurrentPosition(
                                currentId,
                                videoPlayerController.value.position.inSeconds,
                              );
                        }
                        videoPlayerController.dispose();
                      }
                      ref.invalidate(videoPlayerControllerProvider);
                      ref.invalidate(selectedVideoProvider);
                      ref.invalidate(currentCaptionsListProvider);
                      ref.invalidate(currentCaptionsProvider);
                      ref.invalidate(currentChapterListProvider);
                      ref.invalidate(currentStoryboardProvider);
                      if (await WakelockPlus.enabled) WakelockPlus.disable();
                    },
                  ),
                ],
              ),
              if (videoPlayerController != null)
                VideoProgressIndicator(
                  videoPlayerController,
                  allowScrubbing: false,
                  colors: videoProgressColors,
                  padding: const EdgeInsets.all(0),
                ),
            ],
          ),
        ),
      );
    }
  }
}
