import 'package:flutter/material.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:video_player/video_player.dart';

import 'package:peertube_mobile/features/video/player/controls_notifier.dart';
import 'package:peertube_mobile/shared/utils/translate.dart';

class PlayButton extends ConsumerWidget {
  final VideoPlayerController videoPlayerController;
  final double? size;
  final EdgeInsetsGeometry? padding;
  final Color backgroundColor;

  const PlayButton({
    super.key,
    required this.videoPlayerController,
    this.size,
    this.padding,
    required this.backgroundColor,
  });

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    return ValueListenableBuilder<VideoPlayerValue>(
      valueListenable: videoPlayerController,
      builder: (context, value, child) {
        final isPlaying = value.isPlaying;

        return GestureDetector(
          onTap: () {
            if (isPlaying) {
              videoPlayerController.pause();
              ref.read(showControlsProvider.notifier).showPermanently();
            } else {
              videoPlayerController.play();
              ref.read(showControlsProvider.notifier).showTemporarily();
            }
          },
          child: CircleAvatar(
            backgroundColor: backgroundColor,
            radius: size == null ? 20 : size! * 0.8,
            child: Icon(
              size: size,
              isPlaying ? Icons.pause : Icons.play_arrow,
              semanticLabel:
                  isPlaying ? t(context)!.pauseVideo : t(context)!.playVideo,
              color: Colors.white,
            ),
          ),
        );
      },
    );
  }
}
