import 'dart:async';

import 'package:flutter_riverpod/flutter_riverpod.dart';

class ShowControlsNotifier extends Notifier<bool> {
  Timer? _hideControlsTimer;

  @override
  bool build() {
    ref.onDispose(() {
      _hideControlsTimer?.cancel();
    });
    return true;
  }

  void showTemporarily({Duration duration = const Duration(seconds: 2)}) {
    state = true;
    _resetHideControlsTimer(duration);
  }

  void showPermanently() {
    _hideControlsTimer?.cancel();
    state = true;
  }

  void hide() {
    _hideControlsTimer?.cancel();
    state = false;
  }

  void _resetHideControlsTimer(Duration duration) {
    _hideControlsTimer?.cancel();
    _hideControlsTimer = Timer(duration, () {
      state = false;
    });
  }
}

final showControlsProvider = NotifierProvider<ShowControlsNotifier, bool>(
  ShowControlsNotifier.new,
);
