import 'package:flutter/material.dart';

import 'package:video_player/video_player.dart';

import 'package:peertube_mobile/shared/themes/color_schemes.dart';

class DurationDisplay extends StatelessWidget {
  const DurationDisplay({super.key, required this.controller});

  final VideoPlayerController controller;

  String formatDuration(Duration duration) {
    String twoDigits(int n) => n.toString().padLeft(2, '0');

    if (duration.inHours > 0) {
      return '${duration.inHours}:${twoDigits(duration.inMinutes.remainder(60))}:${twoDigits(duration.inSeconds.remainder(60))}';
    } else {
      return '${duration.inMinutes}:${twoDigits(duration.inSeconds.remainder(60))}';
    }
  }

  @override
  Widget build(BuildContext context) {
    final textTheme = Theme.of(context).textTheme;
    return ValueListenableBuilder(
      valueListenable: controller,
      builder: (context, VideoPlayerValue value, child) {
        final duration = controller.value.duration;
        final position = controller.value.position;

        if (!controller.value.isInitialized) {
          return const Text(
            '--:--/--:--',
            style: TextStyle(color: Colors.white),
          );
        }

        return RichText(
          text: TextSpan(
            children: [
              TextSpan(
                text: formatDuration(position),
                style: textTheme.displayLarge!.copyWith(
                  fontWeight: FontWeight.bold,
                  color: beige400,
                ),
              ),
              const TextSpan(
                text: ' / ',
                style: TextStyle(color: Colors.white),
              ),
              TextSpan(
                text: formatDuration(duration),
                style: textTheme.displayLarge!.copyWith(
                  color: beige400,
                ),
              ),
            ],
          ),
        );
      },
    );
  }
}
