import 'package:flutter/material.dart';

import 'package:video_player/video_player.dart';

import 'package:peertube_mobile/shared/themes/color_schemes.dart';

const double videoProgressIndicatorHeight = 50.0;

const videoProgressColors = VideoProgressColors(
  playedColor: orange500,
  bufferedColor: brown300,
  backgroundColor: brown400,
);

class CustomVideoProgressIndicator extends StatefulWidget {
  const CustomVideoProgressIndicator(
    this.controller, {
    super.key,
    required this.chapters,
  });

  final VideoPlayerController controller;
  final List<int> chapters;

  @override
  State<CustomVideoProgressIndicator> createState() =>
      _CustomVideoProgressIndicatorState();
}

class _CustomVideoProgressIndicatorState
    extends State<CustomVideoProgressIndicator> {
  _CustomVideoProgressIndicatorState() {
    listener = () {
      if (!mounted) {
        return;
      }
      setState(() {});
    };
  }

  late VoidCallback listener;

  VideoPlayerController get controller => widget.controller;

  @override
  void initState() {
    super.initState();
    controller.addListener(listener);
  }

  @override
  void deactivate() {
    controller.removeListener(listener);
    super.deactivate();
  }

  Color _getChapterColor(
    int chapterPosition,
    int playedPosition,
    int maxBuffered,
  ) {
    if (chapterPosition <= playedPosition) {
      return videoProgressColors.playedColor;
    } else if (chapterPosition <= maxBuffered) {
      return videoProgressColors.bufferedColor;
    } else {
      return videoProgressColors.backgroundColor;
    }
  }

  @override
  Widget build(BuildContext context) {
    Widget progressIndicator;
    if (controller.value.isInitialized) {
      final int duration = controller.value.duration.inMilliseconds;
      final int position = controller.value.position.inMilliseconds;

      int maxBuffering = 0;
      for (final DurationRange range in controller.value.buffered) {
        final int end = range.end.inMilliseconds;
        if (end > maxBuffering) {
          maxBuffering = end;
        }
      }

      final double progress = position / duration;

      final widthScreen = MediaQuery.of(context).size.width;
      progressIndicator = SizedBox(
        height: videoProgressIndicatorHeight,
        width: widthScreen,
        child: Stack(
          children: <Widget>[
            Center(
              child: SizedBox(
                height: 6,
                child: LinearProgressIndicator(
                  value: maxBuffering / duration,
                  valueColor: AlwaysStoppedAnimation<Color>(
                    videoProgressColors.bufferedColor,
                  ),
                  backgroundColor: videoProgressColors.backgroundColor,
                ),
              ),
            ),
            Center(
              child: SizedBox(
                height: 6.0,
                child: LinearProgressIndicator(
                  value: progress,
                  valueColor: AlwaysStoppedAnimation<Color>(
                    videoProgressColors.playedColor,
                  ),
                  backgroundColor: Colors.transparent,
                ),
              ),
            ),
            ...widget.chapters.map((chapter) {
              final double chapterPosition = (chapter * 1000) / duration;
              final Color chapterColor = _getChapterColor(
                chapter * 1000,
                position,
                maxBuffering,
              );

              return Positioned(
                left: widthScreen * chapterPosition - 6,
                height: videoProgressIndicatorHeight,
                child: Container(
                  width: 12.0,
                  height: 12.0,
                  decoration: BoxDecoration(
                    color: Colors.black,
                    shape: BoxShape.circle,
                    border: Border.all(
                      color: chapterColor,
                      width: 3.0,
                    ),
                  ),
                ),
              );
            }),
            Positioned(
              left: widthScreen * progress - 10,
              height: videoProgressIndicatorHeight,
              child: Container(
                width: videoProgressIndicatorHeight / 2,
                height: videoProgressIndicatorHeight / 2,
                decoration: BoxDecoration(
                  color: videoProgressColors.playedColor,
                  shape: BoxShape.circle,
                  boxShadow: [
                    BoxShadow(
                      color: videoProgressColors.playedColor
                          .withValues(alpha: 0.6),
                      spreadRadius: 3,
                      blurRadius: 10,
                      offset: const Offset(0, 0),
                    ),
                  ],
                ),
              ),
            ),
          ],
        ),
      );
    } else {
      progressIndicator = SizedBox(
        height: 6.0,
        child: LinearProgressIndicator(
          valueColor:
              AlwaysStoppedAnimation<Color>(videoProgressColors.playedColor),
          backgroundColor: videoProgressColors.backgroundColor,
        ),
      );
    }

    return progressIndicator;
  }
}
