import 'package:flutter/material.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:lucide_icons/lucide_icons.dart';

import 'package:peertube_mobile/features/account/connected_account/local_account/local_account_providers.dart';
import 'package:peertube_mobile/features/video/video_model.dart';
import 'package:peertube_mobile/shared/utils/translate.dart';
import 'package:peertube_mobile/shared/widgets/checkbox_list_tile.dart';

class WatchLaterCheckboxListTile extends ConsumerStatefulWidget {
  final String domain;
  final VideoAbstract video;

  const WatchLaterCheckboxListTile({
    required this.domain,
    required this.video,
    super.key,
  });

  @override
  ConsumerState<WatchLaterCheckboxListTile> createState() =>
      _WatchLaterCheckboxListTileState();
}

class _WatchLaterCheckboxListTileState
    extends ConsumerState<WatchLaterCheckboxListTile> {
  bool? _isInWatchLater;
  bool _isLoading = true;

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
    _loadInitialState();
  }

  Future<void> _loadInitialState() async {
    final isInWatchLater = await ref
        .watch(localWatchLaterPlaylistProvider.notifier)
        .isInWatchLater(
          widget.video.uuid,
        );
    setState(() {
      _isInWatchLater = isInWatchLater;
      _isLoading = false;
    });
  }

  @override
  Widget build(BuildContext context) {
    final notifier = ref.watch(localWatchLaterPlaylistProvider.notifier);

    if (_isLoading) {
      return const CircularProgressIndicator();
    }

    return CustomCheckboxListTile(
      value: _isInWatchLater ?? false,
      title: t(context)!.watchLater,
      icon: const Icon(LucideIcons.clock),
      onChanged: (newValue) async {
        setState(() {
          _isInWatchLater = newValue;
        });

        if (newValue == true) {
          await notifier.addToWatchLater(
            widget.domain,
            widget.video,
          );
        } else {
          await notifier.removeFromWatchLater(
            widget.video.uuid,
          );
        }
      },
    );
  }
}
