import 'package:flutter/material.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:go_router/go_router.dart';
import 'package:intl/intl.dart';

import 'package:peertube_mobile/shared/preferences/user_preferences_providers.dart';
import 'package:peertube_mobile/shared/utils/translate.dart';
import 'package:peertube_mobile/shared/widgets/image.dart';

class PlaylistMiniature extends ConsumerWidget {
  final String? thumbnailUrl;
  final String name;
  final int videoCount;

  const PlaylistMiniature({
    this.thumbnailUrl,
    required this.name,
    required this.videoCount,
    super.key,
  });

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final colorScheme = Theme.of(context).colorScheme;
    return Padding(
      padding: const EdgeInsets.only(right: 8.0),
      child: GestureDetector(
        onTap: () => GoRouter.of(context).push(
          '/library/playlists/1',
        ),
        child: SizedBox(
          height: 110,
          width: 178,
          child: Stack(
            children: [
              Positioned(
                bottom: 0,
                right: 0,
                child: Container(
                  height: 98,
                  width: 168,
                  decoration: BoxDecoration(
                    color: colorScheme.secondary,
                    border: Border.all(
                      color: colorScheme.secondaryContainer,
                    ),
                  ),
                ),
              ),
              Center(
                child: Container(
                  height: 98,
                  width: 168,
                  decoration: BoxDecoration(
                    color: colorScheme.secondary,
                    border: Border.all(
                      color: colorScheme.secondaryContainer,
                    ),
                  ),
                ),
              ),
              Positioned(
                child: SizedBox(
                  height: 98,
                  width: 168,
                  child: Stack(
                    children: [
                      thumbnailUrl == null
                          ? Container(
                              height: 98,
                              width: 168,
                              decoration: BoxDecoration(
                                color: colorScheme.secondary,
                                border: Border.all(
                                  color: colorScheme.secondaryContainer,
                                ),
                              ),
                            )
                          : CustomCachedNetworkImage(
                              imageUrl: thumbnailUrl!,
                              height: 98,
                              width: double.infinity,
                            ),
                      Align(
                        alignment: Alignment.centerRight,
                        child: Container(
                          width: 50,
                          height: 98,
                          color: colorScheme.secondary.withValues(alpha: 0.8),
                          child: Padding(
                            padding: const EdgeInsets.all(8.0),
                            child: RotatedBox(
                              quarterTurns: 3,
                              child: Column(
                                mainAxisAlignment: MainAxisAlignment.center,
                                crossAxisAlignment: CrossAxisAlignment.start,
                                children: [
                                  Text(
                                    name,
                                    style: const TextStyle(
                                      fontSize: 12,
                                      fontWeight: FontWeight.bold,
                                    ),
                                    overflow: TextOverflow.ellipsis,
                                  ),
                                  Text(
                                    t(context)!.totalVideos(
                                      NumberFormat.decimalPattern(
                                        ref.watch(localeProvider).languageCode,
                                      ).format(videoCount),
                                    ),
                                    style: const TextStyle(
                                      fontSize: 10,
                                    ),
                                  ),
                                ],
                              ),
                            ),
                          ),
                        ),
                      ),
                    ],
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
