import 'package:json_annotation/json_annotation.dart';

import 'package:peertube_mobile/features/account/account_model.dart';
import 'package:peertube_mobile/features/video/channel/channel_model.dart';
import 'package:peertube_mobile/features/video/playlist/playlist_privacy_enum.dart';
import 'package:peertube_mobile/features/video/playlist/playlist_type_enum.dart';
import 'package:peertube_mobile/features/video/video_model.dart';

part 'playlist_model.g.dart';

@JsonSerializable()
class Playlist {
  final int id;
  final String uuid;
  final String shortUUID;
  final String displayName;
  final String? description;
  final bool isLocal;
  final PlaylistType type;
  final PlaylistPrivacy privacy;
  final String thumbnailPath;
  final DateTime createdAt;
  final DateTime updatedAt;
  final int videoLength;
  final Account ownerAccount;
  final VideoChannel? videoChannel;

  Playlist({
    required this.id,
    required this.uuid,
    required this.shortUUID,
    required this.displayName,
    required this.privacy,
    required this.isLocal,
    required this.type,
    required this.thumbnailPath,
    required this.createdAt,
    required this.updatedAt,
    this.description,
    required this.videoLength,
    required this.ownerAccount,
    this.videoChannel,
  });

  factory Playlist.fromJson(Map<String, dynamic> json) =>
      _$PlaylistFromJson(json);
  Map<String, dynamic> toJson() => _$PlaylistToJson(this);
}

@JsonSerializable()
class PlaylistElement {
  final int playlistElementId;
  final int playlistId;
  final int? startTimpestamp;
  final int? stopTimpestamp;

  PlaylistElement({
    required this.playlistElementId,
    required this.playlistId,
    this.stopTimpestamp,
    this.startTimpestamp,
  });

  factory PlaylistElement.fromJson(Map<String, dynamic> json) =>
      _$PlaylistElementFromJson(json);
  Map<String, dynamic> toJson() => _$PlaylistElementToJson(this);
}

@JsonSerializable()
class VideoPlaylistElement {
  final int id;
  final int position;
  final int? startTimpestamp;
  final int? stopTimpestamp;
  final Video video;

  VideoPlaylistElement({
    required this.id,
    required this.position,
    this.stopTimpestamp,
    this.startTimpestamp,
    required this.video,
  });

  factory VideoPlaylistElement.fromJson(Map<String, dynamic> json) =>
      _$VideoPlaylistElementFromJson(json);
  Map<String, dynamic> toJson() => _$VideoPlaylistElementToJson(this);
}
