import 'dart:io';

import 'package:dio/dio.dart';

import 'package:peertube_mobile/shared/current_platform/current_platform_models.dart';

class RatingDatasource {
  final CurrentPlatform currentPlatform;
  final Dio peertubeClient;

  RatingDatasource({
    required this.currentPlatform,
    required this.peertubeClient,
  });

  Future<String> getRate(int videoId) async {
    try {
      {
        final response = await peertubeClient.get(
          currentPlatform.getApiBaseUrl('/users/me/videos/$videoId/rating'),
        );

        if (response.statusCode == HttpStatus.ok) {
          return response.data['rating'];
        } else {
          throw Exception(response.data['error']);
        }
      }
    } catch (e) {
      throw Exception('An error has occurred : $e');
    }
  }

  Future<void> rateVideo(int videoId, String rating) async {
    try {
      if ((rating == 'like' || rating == 'dislike')) {
        final formData = {
          'rating': rating,
        };

        await peertubeClient.put(
          currentPlatform.getApiBaseUrl('/videos/$videoId/rate'),
          data: FormData.fromMap(formData),
        );
      }
    } on DioException catch (e) {
      throw Exception(e);
    }
  }
}
