import 'package:flutter/material.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';

import 'package:peertube_mobile/features/video/rating/rating_providers.dart';
import 'package:peertube_mobile/features/video/video_model.dart';

class RatingActions extends ConsumerStatefulWidget {
  final VideoDetails video;
  final bool isUserLoggedIn;

  const RatingActions({
    super.key,
    required this.video,
    required this.isUserLoggedIn,
  });

  @override
  ConsumerState<RatingActions> createState() => RatingActionsState();
}

class RatingActionsState extends ConsumerState<RatingActions> {
  String rating = 'none';
  late int likeCount;
  late int dislikeCount;

  @override
  void initState() {
    super.initState();
    likeCount = widget.video.likes;
    dislikeCount = widget.video.dislikes;
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
    _loadRating();
  }

  Future<void> _loadRating() async {
    if (widget.isUserLoggedIn) {
      String newRating =
          await ref.read(ratingServiceProvider).getRate(widget.video.id);

      setState(() {
        rating = newRating;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.start,
      children: <Widget>[
        _buildAction(
          context: context,
          icon: rating == 'like' ? Icons.thumb_up : Icons.thumb_up_outlined,
          label: likeCount.toString(),
          onTap: rateVideo('like'),
        ),
        _buildAction(
          context: context,
          icon: rating == 'dislike'
              ? Icons.thumb_down
              : Icons.thumb_down_outlined,
          label: dislikeCount.toString(),
          onTap: rateVideo('dislike'),
        ),
      ],
    );
  }

  Widget _buildAction({
    required BuildContext context,
    required IconData icon,
    required String label,
    required VoidCallback onTap,
  }) {
    return Row(
      mainAxisSize: MainAxisSize.min,
      children: <Widget>[
        Container(
          decoration: BoxDecoration(
            border: Border.all(
              color: Theme.of(context).colorScheme.surfaceContainerHighest,
            ),
            shape: BoxShape.circle,
          ),
          child: IconButton(
            onPressed: onTap,
            icon: Icon(
              icon,
            ),
          ),
        ),
        const SizedBox(width: 6.0),
        Padding(
          padding: const EdgeInsets.symmetric(horizontal: 4.0),
          child: Text(
            label,
            style: Theme.of(context)
                .textTheme
                .bodySmall!
                .copyWith(color: Theme.of(context).colorScheme.onSecondary),
          ),
        ),
        const SizedBox(width: 16.0),
      ],
    );
  }

  VoidCallback rateVideo(String rating) {
    return () async {
      if (widget.isUserLoggedIn) {
        final updatedCounts = await ref.read(ratingServiceProvider).updateRate(
              videoId: widget.video.id,
              lastRating: this.rating,
              newRating: rating,
              likeCount: likeCount,
              dislikeCount: dislikeCount,
            );
        setState(() {
          likeCount = updatedCounts[0];
          likeCount = updatedCounts[1];
        });
      }
    };
  }
}
