import 'dart:io';

import 'package:dio/dio.dart';

import 'package:peertube_mobile/features/video/video_model.dart';
import 'package:peertube_mobile/shared/filters/search/search_video_params_model.dart';

class SearchDatasource {
  final Dio httpClient;

  SearchDatasource({
    required this.httpClient,
  });

  Future<List<Video>> searchVideos({
    required String path,
    required SearchVideosParams params,
  }) async {
    final queryParams = params.toJson();
    try {
      final nonNullNonEmptyQueryParams = Map.fromEntries(
        queryParams.entries.where((entry) {
          final value = entry.value;
          return value != null && value.toString().isNotEmpty;
        }),
      );
      final response = await httpClient.get(
        path,
        queryParameters: nonNullNonEmptyQueryParams,
      );
      if (response.statusCode == HttpStatus.ok) {
        return response.data['data'].map<Video>((json) {
          try {
            return Video.fromJson(json);
          } catch (e) {
            throw Exception('Error parsing video: $e');
          }
        }).toList();
      } else {
        throw Exception(response.data['error']);
      }
    } catch (e) {
      throw Exception('An error has occurred: $e');
    }
  }
}
