import 'package:peertube_mobile/features/platform/history/platform_history_model.dart';
import 'package:peertube_mobile/features/video/search/search_datasource.dart';
import 'package:peertube_mobile/features/video/video_model.dart';
import 'package:peertube_mobile/shared/environment/environment.dart';
import 'package:peertube_mobile/shared/filters/nsfw_filter_enum.dart';
import 'package:peertube_mobile/shared/filters/search/search_video_params_model.dart';

class SearchService {
  final SearchDatasource searchDatasource;

  SearchService({
    required this.searchDatasource,
  });

  Future<List<Video>> searchOnPlatform(
    String path,
    int pageKey,
    int pageSize,
    Uri platformDomain,
    SearchVideosParams params,
  ) async {
    return await searchDatasource.searchVideos(
      path: platformDomain.resolve('/api/v1/search/videos').toString(),
      params: params.copyWith(
        start: pageKey,
        count: pageSize,
        nsfw: NsfwFilter.hide,
      ),
    );
  }

  Future<List<Video>> searchOnSepia(
    int pageKey,
    int pageSize,
    SearchVideosParams params,
    List<PlatformHistoryElementSQL> platformHistory,
  ) async {
    var buildTypeString = Environment.instance.buildType;
    final filterTag = (buildTypeString == BuildType.playstore ||
            buildTypeString == BuildType.appstore)
        ? buildTypeString.toShortString()
        : null;
    return await searchDatasource.searchVideos(
      path: 'https://sepiasearch.org/api/v1/search/videos',
      params: params.copyWith(
        start: pageKey,
        count: pageSize,
        nsfw: NsfwFilter.hide,
        filterTag: filterTag,
        filterTagAdditionalHosts: platformHistory
            .map((platform) => Uri.parse(platform.domain).host)
            .toList(),
      ),
    );
  }
}
