import 'dart:io';

import 'package:peertube_mobile/features/video/captions/captions_model.dart';
import 'package:peertube_mobile/features/video/chapters/chapter_model.dart';
import 'package:peertube_mobile/features/video/storyboards/storyboard_model.dart';
import 'package:peertube_mobile/features/video/video_model.dart';
import 'package:peertube_mobile/shared/current_platform/current_platform_models.dart';
import 'package:peertube_mobile/shared/filters/video/video_params_model.dart';
import 'package:peertube_mobile/shared/network/http_service.dart';

class VideoDatasource {
  static const videoPath = '/videos';
  final CurrentPlatform currentPlatform;
  final HttpService httpService;

  VideoDatasource({
    required this.currentPlatform,
    required this.httpService,
  });

  Future<List<Video>> fetchVideos(
    String path, {
    VideoParams? commonParams,
  }) async {
    final VideoParams params = commonParams ?? const VideoParams();
    final Map<String, dynamic> queryParams = params.toJson();

    final response = await httpService.get(
      path: currentPlatform.getApiBaseUrl(path),
      queryParameters: queryParams,
      expectedStatusCode: HttpStatus.ok,
    );

    return response.data['data'].map<Video>((json) {
      try {
        return Video.fromJson(json);
      } catch (e) {
        throw Exception('Error parsing video: $e');
      }
    }).toList();
  }

  Future<int> getTotalVideos(
    String path,
  ) async {
    const VideoParams params = VideoParams(count: 0);
    final Map<String, dynamic> queryParams = params.toJson();

    final response = await httpService.get(
      path: currentPlatform.getApiBaseUrl(path),
      queryParameters: queryParams,
      expectedStatusCode: HttpStatus.ok,
    );

    return response.data['total'];
  }

  Future<VideoDetails> fetchVideo(String videoUuid) async {
    final response = await httpService.get(
      path: currentPlatform.getApiBaseUrl('$videoPath/$videoUuid'),
      expectedStatusCode: HttpStatus.ok,
    );

    return VideoDetails.fromJson(response.data);
  }

  Future<List<Captions>> fetchCaptions(String videoUuid) async {
    final response = await httpService.get(
      path: currentPlatform.getApiBaseUrl('$videoPath/$videoUuid/captions'),
      expectedStatusCode: HttpStatus.ok,
    );

    return response.data['data'].map<Captions>((json) {
      try {
        return Captions.fromJson(json);
      } catch (e) {
        throw Exception('Error parsing captions: $e');
      }
    }).toList();
  }

  Future<List<Chapter>> fetchChapters(String videoUuid) async {
    final response = await httpService.get(
      path: currentPlatform.getApiBaseUrl('$videoPath/$videoUuid/chapters'),
      expectedStatusCode: HttpStatus.ok,
    );

    return response.data['chapters'].map<Chapter>((json) {
      try {
        return Chapter.fromJson(json);
      } catch (e) {
        throw Exception('Error parsing chapter: $e');
      }
    }).toList();
  }

  Future<List<Storyboard>> fetchStoryboards(String videoUuid) async {
    final response = await httpService.get(
      path: currentPlatform.getApiBaseUrl('$videoPath/$videoUuid/storyboards'),
      expectedStatusCode: HttpStatus.ok,
    );

    return response.data['storyboards'].map<Storyboard>((json) {
      try {
        return Storyboard.fromJson(json);
      } catch (e) {
        throw Exception('Error parsing storyboard: $e');
      }
    }).toList();
  }
}
