import 'package:json_annotation/json_annotation.dart';

import 'package:peertube_mobile/features/account/account_model.dart';
import 'package:peertube_mobile/features/video/channel/channel_model.dart';
import 'package:peertube_mobile/features/video/video_privacy_enum.dart';
import 'package:peertube_mobile/features/video/video_state_enum.dart';
import 'package:peertube_mobile/shared/actor/actor_model.dart';

part 'video_model.g.dart';

abstract class VideoAbstract {
  int get id;
  String get uuid;
  String get shortUUID;
  String get name;
  VideoConstant<int?> get category;
  VideoConstant<int?> get licence;
  VideoConstant<String?> get language;
  VideoConstant<VideoPrivacy> get privacy;
  bool get nsfw;
  String? get truncatedDescription;
  String? get description;
  bool? get isLocal;
  int get duration;
  double? get aspectRatio;
  int get views;
  int get viewers;
  int get likes;
  int get dislikes;
  String? get thumbnailPath;
  String? get previewPath;
  String? get embedPath;
  DateTime get createdAt;
  DateTime get updatedAt;
  DateTime get publishedAt;
  DateTime? get originallyPublishedAt;
  bool get isLive;
  Actor get account;
  Actor get channel;
}

@JsonSerializable()
class Video implements VideoAbstract {
  @override
  final int id;
  @override
  final String uuid;
  @override
  final String shortUUID;
  @override
  final String name;
  @override
  final VideoConstant<int?> category;
  @override
  final VideoConstant<int?> licence;
  @override
  final VideoConstant<String?> language;
  @override
  final VideoConstant<VideoPrivacy> privacy;
  @override
  final bool nsfw;
  @override
  final String? truncatedDescription;
  @override
  final String? description;
  @override
  final bool? isLocal;
  @override
  final int duration;
  @override
  final double? aspectRatio;
  @override
  final int views;
  @override
  final int viewers;
  @override
  final int likes;
  @override
  final int dislikes;
  @override
  final String? thumbnailPath;
  @override
  final String? previewPath;
  @override
  final String? embedPath;
  @override
  final DateTime createdAt;
  @override
  final DateTime updatedAt;
  @override
  final DateTime publishedAt;
  @override
  final DateTime? originallyPublishedAt;
  @override
  final bool isLive;
  @override
  final Account account;
  @override
  final VideoChannel channel;

  Video({
    required this.id,
    required this.uuid,
    required this.shortUUID,
    required this.name,
    required this.category,
    required this.licence,
    required this.language,
    required this.privacy,
    required this.nsfw,
    this.truncatedDescription,
    this.description,
    this.isLocal,
    required this.duration,
    this.aspectRatio,
    required this.views,
    required this.viewers,
    required this.likes,
    required this.dislikes,
    this.thumbnailPath,
    this.previewPath,
    this.embedPath,
    required this.createdAt,
    required this.updatedAt,
    required this.publishedAt,
    this.originallyPublishedAt,
    required this.isLive,
    required this.account,
    required this.channel,
  });

  factory Video.fromJson(Map<String, dynamic> json) => _$VideoFromJson(json);
  Map<String, dynamic> toJson() => _$VideoToJson(this);
}

@JsonSerializable()
class VideoDetails implements VideoAbstract {
  @override
  final int id;
  @override
  final String uuid;
  @override
  final String shortUUID;
  @override
  final String name;
  @override
  final VideoConstant<int?> category;
  @override
  final VideoConstant<int?> licence;
  @override
  final VideoConstant<String?> language;
  @override
  final VideoConstant<VideoPrivacy> privacy;
  @override
  final bool nsfw;
  @override
  final String? truncatedDescription;
  @override
  final String? description;
  @override
  final bool isLocal;
  @override
  final int duration;
  @override
  final double? aspectRatio;
  @override
  final int views;
  @override
  final int viewers;
  @override
  final int likes;
  @override
  final int dislikes;
  @override
  final String? thumbnailPath;
  @override
  final String? previewPath;
  @override
  final String? embedPath;
  @override
  final DateTime createdAt;
  @override
  final DateTime updatedAt;
  @override
  final DateTime publishedAt;
  @override
  final DateTime? originallyPublishedAt;
  @override
  final bool isLive;
  @override
  final AccountDetails account;
  @override
  final VideoChannelDetails channel;
  final bool blacklisted;
  final String? blacklistedReason;
  final List<VideoFile> files;
  final List<VideoStreamingPlaylist> streamingPlaylists;
  final String? support;
  final List<String> tags;
  final bool commentsEnabled;
  final bool downloadEnabled;
  final bool waitTranscoding;
  final DateTime? inputFileUpdatedAt;
  final VideoConstant<VideoState> state;
  final List<Uri> trackerUrls;
  @JsonKey(name: 'userHistory.currentTime')
  final int? historyCurrentTime;

  VideoDetails({
    required this.id,
    required this.uuid,
    required this.shortUUID,
    required this.name,
    required this.category,
    required this.licence,
    required this.language,
    required this.privacy,
    required this.nsfw,
    this.truncatedDescription,
    this.description,
    required this.isLocal,
    required this.duration,
    this.aspectRatio,
    required this.views,
    required this.viewers,
    required this.likes,
    required this.dislikes,
    this.thumbnailPath,
    this.previewPath,
    this.embedPath,
    required this.createdAt,
    required this.updatedAt,
    required this.publishedAt,
    this.originallyPublishedAt,
    required this.isLive,
    required this.account,
    required this.channel,
    required this.blacklisted,
    this.blacklistedReason,
    required this.files,
    required this.streamingPlaylists,
    this.support,
    required this.tags,
    required this.commentsEnabled,
    required this.downloadEnabled,
    required this.waitTranscoding,
    this.inputFileUpdatedAt,
    required this.state,
    required this.trackerUrls,
    this.historyCurrentTime,
  });

  factory VideoDetails.fromJson(Map<String, dynamic> json) =>
      _$VideoDetailsFromJson(json);
  Map<String, dynamic> toJson() => _$VideoDetailsToJson(this);
}

@JsonSerializable()
class VideoStreamingPlaylist {
  final int id;
  final int type;
  final Uri playlistUrl;
  final Uri segmentsSha256Url;
  final List<dynamic> redundancies;
  final List<VideoFile> files;

  VideoStreamingPlaylist({
    required this.id,
    required this.type,
    required this.playlistUrl,
    required this.segmentsSha256Url,
    required this.redundancies,
    required this.files,
  });

  factory VideoStreamingPlaylist.fromJson(Map<String, dynamic> json) =>
      _$VideoStreamingPlaylistFromJson(json);
  Map<String, dynamic> toJson() => _$VideoStreamingPlaylistToJson(this);
}

@JsonSerializable()
class VideoFile {
  final int id;
  final VideoConstant<int?> resolution;
  final int size;
  final Uri torrentUrl;
  final Uri torrentDownloadUrl;
  final Uri fileUrl;
  final Uri fileDownloadUrl;
  final int fps;
  final Uri? metadataUrl;
  final Uri? magnetUri;

  VideoFile({
    required this.id,
    required this.resolution,
    required this.size,
    required this.torrentUrl,
    required this.torrentDownloadUrl,
    required this.fileUrl,
    required this.fileDownloadUrl,
    required this.fps,
    this.metadataUrl,
    this.magnetUri,
  });

  factory VideoFile.fromJson(Map<String, dynamic> json) =>
      _$VideoFileFromJson(json);
  Map<String, dynamic> toJson() => _$VideoFileToJson(this);
}

@JsonSerializable(genericArgumentFactories: true)
class VideoConstant<T> {
  final String label;
  final String? description;
  final T? id;

  VideoConstant({
    required this.label,
    this.description,
    required this.id,
  });

  factory VideoConstant.fromJson(
    Map<String, dynamic> json,
    T Function(Object? json) fromJsonT,
  ) =>
      _$VideoConstantFromJson(json, fromJsonT);

  Map<String, dynamic> toJson(Object? Function(T? value) toJsonT) =>
      _$VideoConstantToJson(this, toJsonT);
}
