import 'package:flutter_riverpod/flutter_riverpod.dart';

import 'package:peertube_mobile/features/video/selected_video_notifier.dart';
import 'package:peertube_mobile/features/video/video_datasource.dart';
import 'package:peertube_mobile/features/video/video_model.dart';
import 'package:peertube_mobile/features/video/video_service.dart';
import 'package:peertube_mobile/shared/current_platform/current_platform_providers.dart';
import 'package:peertube_mobile/shared/network/network_providers.dart';

final videoDatasourceProvider = Provider.autoDispose<VideoDatasource>(
  (ref) => VideoDatasource(
    currentPlatform: ref.watch(currentPlatformNonNullableProvider),
    httpService: ref.watch(httpServiceProvider),
  ),
  name: 'videoDatasourceProvider',
);

final videoServiceProvider = Provider.autoDispose<VideoService>(
  (ref) => VideoService(
    videoDatasource: ref.watch(videoDatasourceProvider),
  ),
  name: 'videoServiceProvider',
);

final selectedVideoProvider =
    NotifierProvider<SelectedVideoNotifier, VideoDetails?>(
  SelectedVideoNotifier.new,
  name: 'selectedVideoProvider',
);

final totalVideosProvider = FutureProvider.autoDispose.family<int, String>(
  (ref, path) async => ref.read(videoDatasourceProvider).getTotalVideos(
        path,
      ),
);
