import 'package:peertube_mobile/features/video/video_datasource.dart';
import 'package:peertube_mobile/features/video/video_model.dart';
import 'package:peertube_mobile/shared/filters/nsfw_filter_enum.dart';
import 'package:peertube_mobile/shared/filters/video/video_params_model.dart';

class VideoService {
  final VideoDatasource videoDatasource;

  VideoService({required this.videoDatasource});

  Future<List<Video>> getRecentVideos(int pageKey, int pageSize) async {
    return await videoDatasource.fetchVideos(
      VideoDatasource.videoPath,
      commonParams: VideoParams(
        start: pageKey,
        count: pageSize,
        nsfw: NsfwFilter.hide,
      ),
    );
  }

  Future<List<Video>> getLocalVideos(int pageKey, int pageSize) async {
    return await videoDatasource.fetchVideos(
      VideoDatasource.videoPath,
      commonParams: VideoParams(
        start: pageKey,
        count: pageSize,
        isLocal: true,
        nsfw: NsfwFilter.hide,
      ),
    );
  }

  Future<List<Video>> getLiveVideos(int pageKey, int pageSize) async {
    return await videoDatasource.fetchVideos(
      VideoDatasource.videoPath,
      commonParams: VideoParams(
        start: pageKey,
        count: pageSize,
        isLive: true,
        nsfw: NsfwFilter.hide,
      ),
    );
  }

  Future<List<Video>> getNonLiveVideos(int pageKey, int pageSize) async {
    return await videoDatasource.fetchVideos(
      VideoDatasource.videoPath,
      commonParams: VideoParams(
        start: pageKey,
        count: pageSize,
        isLive: false,
        nsfw: NsfwFilter.hide,
      ),
    );
  }

  Future<List<Video>> getTrendingVideos(int pageKey, int pageSize) async {
    return await videoDatasource.fetchVideos(
      VideoDatasource.videoPath,
      commonParams: VideoParams(
        start: pageKey,
        count: pageSize,
        sort: VideoSortCriteria.trendingDesc,
        nsfw: NsfwFilter.hide,
      ),
    );
  }

  Future<List<Video>> getVideoChannelVideos(
    String channelHandle,
    int pageKey,
    int pageSize,
  ) async {
    return await videoDatasource.fetchVideos(
      '/video-channels/$channelHandle/videos',
      commonParams: VideoParams(
        start: pageKey,
        count: pageSize,
        nsfw: NsfwFilter.hide,
      ),
    );
  }

  Future<List<Video>> getAccountVideos(
    String name,
    int pageKey,
    int pageSize,
  ) async {
    return await videoDatasource.fetchVideos(
      '/accounts/$name/videos',
      commonParams: VideoParams(
        start: pageKey,
        count: pageSize,
        nsfw: NsfwFilter.hide,
      ),
    );
  }
}
