import 'package:flutter/material.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';

import 'package:peertube_mobile/features/platform/platform_miniature.dart';
import 'package:peertube_mobile/shared/config/config_providers.dart';
import 'package:peertube_mobile/shared/utils/translate.dart';
import 'package:peertube_mobile/shared/widgets/button.dart';
import 'package:peertube_mobile/shared/widgets/text_field.dart';

class AddPlatformScreen extends ConsumerStatefulWidget {
  const AddPlatformScreen({super.key});

  @override
  ConsumerState<AddPlatformScreen> createState() => _AddPlatformScreenState();
}

class _AddPlatformScreenState extends ConsumerState<AddPlatformScreen> {
  final _formKey = GlobalKey<FormState>();
  final TextEditingController _urlController = TextEditingController();
  String? _errorMessage;
  bool _isLoading = false;

  Future<void> _validateAndConnect(BuildContext context) async {
    setState(() {
      _errorMessage = null;
      _isLoading = true;
    });

    final url = _urlController.text.trim();

    try {
      try {
        final config =
            await ref.read(configDatasourceProvider).config(Uri.parse(url));

        if (context.mounted) {
          onTapPlatform(
            context,
            ref,
            version: config.serverVersion,
            name: config.instance.name,
            domain: url,
            avatarUrl: config.instance.avatars == null ||
                    config.instance.avatars!.isEmpty
                ? null
                : Uri.parse(url)
                    .resolve(config.instance.avatars![0].path)
                    .toString(),
          );
        }
      } catch (e) {
        setState(() {
          _errorMessage = '';
        });
      }
    } catch (e) {
      setState(() {
        _errorMessage = t(context)!.thisUrlDoesNotWork(e.toString());
      });
    } finally {
      setState(() {
        _isLoading = false;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(t(context)!.addAPlatform),
      ),
      body: Padding(
        padding: const EdgeInsets.all(16.0),
        child: Form(
          key: _formKey,
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              const Spacer(),
              CustomTextFormField(
                controller: _urlController,
                labelText: t(context)!.platformUrl,
                hintText: t(context)!.enterAUrl,
                validator: (value) {
                  if (value == null || value.isEmpty) {
                    return t(context)!.pleaseEnterAUrl;
                  }
                  if (!value.startsWith('https://')) {
                    return t(context)!.onlyHttpsUrls;
                  }
                  return null;
                },
                keyboardType: TextInputType.url,
              ),
              const SizedBox(height: 10),
              if (_errorMessage != null)
                Text(
                  _errorMessage!,
                  style:
                      TextStyle(color: Theme.of(context).colorScheme.primary),
                ),
              if (_isLoading)
                const Center(child: CircularProgressIndicator())
              else
                CustomElevatedButton(
                  onPressed: () {
                    if (_formKey.currentState?.validate() == true) {
                      _validateAndConnect(context);
                    }
                  },
                  child: Text(t(context)!.connect),
                ),
              const Spacer(),
            ],
          ),
        ),
      ),
    );
  }
}
