import 'dart:io';

import 'package:flutter/material.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:go_router/go_router.dart';
import 'package:lucide_icons/lucide_icons.dart';

import 'package:peertube_mobile/features/platform/joinpeertube/widgets/platform_list.dart';
import 'package:peertube_mobile/features/platform/joinpeertube/widgets/platform_list_view.dart';
import 'package:peertube_mobile/shared/filters/filters_providers.dart';
import 'package:peertube_mobile/shared/utils/translate.dart';
import 'package:peertube_mobile/shared/widgets/text_field.dart';

class PlatformJPTListScreen extends ConsumerStatefulWidget {
  const PlatformJPTListScreen({super.key});

  @override
  ConsumerState<PlatformJPTListScreen> createState() =>
      _PlatformJPTListScreenState();
}

class _PlatformJPTListScreenState extends ConsumerState<PlatformJPTListScreen> {
  late TextEditingController _searchController;

  @override
  Widget build(context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(t(context)!.peertubePlatforms),
        actions: !Platform.isIOS
            ? [
                IconButton(
                  onPressed: () =>
                      GoRouter.of(context).push('/explore/platforms/add'),
                  icon: Icon(
                    LucideIcons.plusCircle,
                    semanticLabel: t(context)!.addAPlatform,
                  ),
                ),
              ]
            : null,
      ),
      body: ListView(
        children: [
          CustomTextFormField(
            controller: _searchController,
            hintText: t(context)!.searchPeertubePlatforms,
            searchTheme: true,
            maxLines: 1,
          ),
          PlatformFilterChipsWidget(
            params: ref.watch(addPlatformFilterProvider),
            paramsNotifier: ref.watch(addPlatformFilterProvider.notifier),
          ),
          PlatformListView(
            params: ref.watch(addPlatformFilterProvider),
          ),
        ],
      ),
    );
  }

  @override
  void dispose() {
    _searchController.dispose();
    super.dispose();
  }

  @override
  void initState() {
    super.initState();
    _searchController = TextEditingController();
    _searchController.addListener(() {
      ref
          .read(addPlatformFilterProvider.notifier)
          .update(search: _searchController.text);
    });
  }
}
