import 'package:flutter/material.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:go_router/go_router.dart';
import 'package:lucide_icons/lucide_icons.dart';

import 'package:peertube_mobile/features/account/connected_account/connected_account_providers.dart';
import 'package:peertube_mobile/features/account/connected_account/local_account/local_account_providers.dart';
import 'package:peertube_mobile/features/video/playlist/playlist_miniature.dart';
import 'package:peertube_mobile/shared/utils/translate.dart';
import 'package:peertube_mobile/shared/widgets/app_bar.dart';
import 'package:peertube_mobile/shared/widgets/async_value.dart';

const videoPath = '/videos';

class LibraryScreen extends ConsumerWidget {
  const LibraryScreen({super.key});

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final textTheme = Theme.of(context).textTheme;
    return Scaffold(
      appBar: AppBar(
        title: Text(
          t(context)!.library,
        ),
        actions: const [
          AccountAction(),
        ],
      ),
      body: Padding(
        padding: const EdgeInsets.all(18.0),
        child: AsyncValueWidget(
          value: ref.watch(currentConnectedAccountProvider),
          dataBuilder: (account) => Column(
            children: [
              Row(
                children: [
                  TextButton(
                    onPressed: () => GoRouter.of(context).push(
                      '/library/history',
                    ),
                    child: Padding(
                      padding: const EdgeInsets.all(6.0),
                      child: Row(
                        children: [
                          const Icon(
                            LucideIcons.history,
                            size: 24,
                          ),
                          const SizedBox(
                            width: 8,
                          ),
                          Text(
                            t(context)!.history,
                            style: textTheme.headlineMedium,
                          ),
                        ],
                      ),
                    ),
                  ),
                ],
              ),
              const SizedBox(
                height: 18,
              ),
              Row(
                children: [
                  Text(
                    t(context)!.myPlaylists,
                    style: textTheme.headlineLarge,
                  ),
                  const Spacer(),
                  if (!account.isLocal())
                    IconButton(
                      onPressed: () => {},
                      icon: const Icon(LucideIcons.moreVertical),
                    ),
                ],
              ),
              const SizedBox(
                height: 8,
              ),
              account.isLocal()
                  ? AsyncValueWidget(
                      value: ref.watch(localWatchLaterPlaylistProvider),
                      dataBuilder: (watchLaterList) {
                        return Row(
                          children: [
                            PlaylistMiniature(
                              name: 'Watch later',
                              thumbnailUrl: watchLaterList.isEmpty
                                  ? null
                                  : Uri.parse(watchLaterList[0].domain)
                                      .resolve(
                                        watchLaterList[0].previewPath ?? '',
                                      )
                                      .toString(),
                              videoCount: watchLaterList.length,
                            ),
                          ],
                        );
                      },
                    )
                  : const SizedBox.shrink(),
            ],
          ),
        ),
      ),
    );
  }
}
