import 'package:flutter/material.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:go_router/go_router.dart';
import 'package:lucide_icons/lucide_icons.dart';

import 'package:peertube_mobile/features/account/connected_account/local_account/local_account_providers.dart';
import 'package:peertube_mobile/features/account/connected_account/local_account/local_video_list_tile.dart';
import 'package:peertube_mobile/features/platform/platform_miniature.dart';
import 'package:peertube_mobile/shared/current_platform/current_platform_providers.dart';
import 'package:peertube_mobile/shared/utils/translate.dart';
import 'package:peertube_mobile/shared/widgets/async_value.dart';
import 'package:peertube_mobile/shared/widgets/dialog.dart';

class WatchLaterScreen extends ConsumerStatefulWidget {
  const WatchLaterScreen({super.key});

  @override
  ConsumerState<WatchLaterScreen> createState() => _WatchLaterScreenState();
}

class _WatchLaterScreenState extends ConsumerState<WatchLaterScreen> {
  bool _isEditing = false;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(t(context)!.watchLater),
        actions: [
          if (_isEditing)
            IconButton(
              icon: const Icon(Icons.delete_sweep),
              onPressed: () => showDialog<bool>(
                context: context,
                builder: (BuildContext context) {
                  return CustomAlertDialog(
                    title: t(context)!.deleteAll,
                    content: t(context)!.deleteAllConfirmation,
                    onConfirm: () {
                      ref
                          .read(localWatchLaterPlaylistProvider.notifier)
                          .clearWatchLater();
                    },
                  );
                },
              ),
            ),
          IconButton(
            icon: Icon(
              _isEditing ? LucideIcons.check : LucideIcons.pencil,
              semanticLabel: t(context)!.edit,
            ),
            onPressed: _toggleEditing,
          ),
        ],
      ),
      body: AsyncValueWidget(
        value: ref.watch(localWatchLaterPlaylistProvider),
        dataBuilder: (watchLaterList) {
          return watchLaterList.isEmpty
              ? Center(
                  child: Text(t(context)!.noVideosInWatchLaterPlaylist),
                )
              : ReorderableListView(
                  onReorder: (oldIndex, newIndex) async => await ref
                      .read(localWatchLaterPlaylistProvider.notifier)
                      .reorderWatchLater(
                        oldIndex: oldIndex,
                        newIndex: newIndex,
                      ),
                  children: watchLaterList
                      .asMap()
                      .map(
                        (index, element) => MapEntry(
                          index,
                          LocalVideoListTile(
                            key: ValueKey(element.videoUuid),
                            onTap: () async {
                              final success = await ref
                                  .read(currentPlatformServiceProvider)
                                  .loadPlatformFromLocalAccount(
                                    context,
                                    ref,
                                    element.domain,
                                  );
                              if (context.mounted) {
                                if (success) {
                                  GoRouter.of(context).push(
                                    '/video/${element.videoUuid}',
                                  );
                                } else {
                                  await showPlatformNotRespondingDialog(
                                    context,
                                    element.domain,
                                  );
                                }
                              }
                            },
                            imageUrl: Uri.parse(element.domain)
                                .resolve(element.previewPath ?? '')
                                .toString(),
                            title: element.name,
                            subtitle: element.channelDisplayName,
                            isEditing: _isEditing,
                            onDelete: () => ref
                                .read(
                                  localWatchLaterPlaylistProvider.notifier,
                                )
                                .removeFromWatchLater(
                                  element.videoUuid,
                                ),
                          ),
                        ),
                      )
                      .values
                      .toList(),
                );
        },
      ),
    );
  }

  void _toggleEditing() {
    setState(() {
      _isEditing = !_isEditing;
    });
  }
}
