import 'package:flutter/material.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_svg/svg.dart';
import 'package:go_router/go_router.dart';

import 'package:peertube_mobile/routes/explore/explore_screen.dart';
import 'package:peertube_mobile/shared/preferences/user_preferences_providers.dart';
import 'package:peertube_mobile/shared/utils/translate.dart';
import 'package:peertube_mobile/shared/widgets/button.dart';

class OnboardingScreen extends ConsumerWidget {
  const OnboardingScreen({super.key});

  @override
  Widget build(context, ref) {
    return SafeArea(
      child: Scaffold(
        body: Center(
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Padding(
                padding: const EdgeInsets.all(30.0),
                child: Stack(
                  children: [
                    Center(
                      child: Image.asset(
                        'assets/what-is-peertube.png',
                        width: MediaQuery.of(context).size.width * 0.6,
                      ),
                    ),
                    Column(
                      children: [
                        SizedBox(
                          height: MediaQuery.of(context).size.width * 0.4,
                        ),
                        Row(
                          mainAxisAlignment: MainAxisAlignment.end,
                          children: [
                            Transform(
                              alignment: Alignment.center,
                              transform: Matrix4.identity()
                                ..scale(
                                  -1.0,
                                  1.0,
                                )
                                ..rotateZ(
                                  6,
                                ),
                              child: Image.asset(
                                width: MediaQuery.of(context).size.width * 0.3,
                                'assets/sepia/happy.png',
                                semanticLabel: t(context)!.sepiaPeertubeMascot,
                              ),
                            ),
                          ],
                        ),
                      ],
                    ),
                  ],
                ),
              ),
              Text(
                t(context)!.welcomeOnPeertube,
                style: Theme.of(context).textTheme.titleLarge,
              ),
              const SizedBox(height: 8),
              Text(
                t(context)!.peertubeOnBoardingDescription,
                textAlign: TextAlign.center,
              ),
              const SizedBox(height: 20),
              Padding(
                padding: const EdgeInsets.symmetric(horizontal: 50.0),
                child: CustomElevatedButton(
                  onPressed: () {
                    ref.read(onboardingProvider.notifier).state = true;
                    if (context.mounted) {
                      GoRouter.of(context).go('/explore/platforms');
                    }
                  },
                  child: Text(t(context)!.iKnowWhereToGo),
                ),
              ),
              const SizedBox(height: 20),
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  SvgPicture.asset('assets/explore_selected.svg'),
                  const SizedBox(
                    width: 10,
                  ),
                  UnderlinedTextButton(
                    onPressed: () {
                      ref.read(onboardingProvider.notifier).state = true;
                      if (context.mounted) {
                        ref.read(showOnboardingDialogProvider.notifier).state =
                            true;
                        GoRouter.of(context).go('/explore');
                      }
                    },
                    text: t(context)!.discoverContent,
                    textStyle: Theme.of(context).textTheme.headlineLarge!,
                    alignment: Alignment.center,
                  ),
                ],
              ),
            ],
          ),
        ),
      ),
    );
  }
}
