import 'package:flutter/material.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:go_router/go_router.dart';

import 'package:peertube_mobile/features/platform/history/widgets/platform_history_carousel.dart';
import 'package:peertube_mobile/features/video/video_list/video_list_view.dart';
import 'package:peertube_mobile/features/video/video_providers.dart';
import 'package:peertube_mobile/shared/current_platform/current_platform_providers.dart';
import 'package:peertube_mobile/shared/utils/translate.dart';
import 'package:peertube_mobile/shared/widgets/app_bar.dart';
import 'package:peertube_mobile/shared/widgets/button.dart';
import 'package:peertube_mobile/shared/widgets/tabbed_page_scaffold.dart';

// import 'package:peertube_mobile/shared/widgets/text_field.dart';

const videoPath = '/videos';

final platformHomeScreenNumberLivesProvider = StateProvider<int>((ref) => 0);

final platformHomeScreenNumberVideosProvider = StateProvider<int>((ref) => 0);

class PlatformHomeScreen extends ConsumerWidget {
  const PlatformHomeScreen({super.key});

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final platform = ref.watch(currentPlatformNonNullableProvider);

    return TabbedPageScaffold(
      appBar: AppBar(
        title: Text(
          platform.name,
          overflow: TextOverflow.ellipsis,
        ),
        actions: const [
          AccountAction(),
        ],
      ),
      headerContent: Column(
        children: [
          const Padding(
            padding: EdgeInsets.only(left: 18.0, top: 16),
            child: PlatformHistoryCarousel(),
          ),
          Padding(
            padding: const EdgeInsets.only(
              left: 8.0,
              right: 8.0,
              top: 8.0,
              bottom: 15.0,
            ),
            child: ListTile(
              title: Text(
                platform.shortDescription,
                style: Theme.of(context).textTheme.displayMedium!.copyWith(
                      color: Theme.of(context).colorScheme.onSecondary,
                    ),
                overflow: TextOverflow.clip,
              ),
              trailing: const Icon(Icons.arrow_forward),
              onTap: () {
                GoRouter.of(context).push(
                  '/about',
                );
              },
            ),
          ),
          const Padding(
            padding: EdgeInsets.only(
              left: 8.0,
              right: 8.0,
            ),
            child: Row(
              children: [
                // Container(
                //   decoration: BoxDecoration(
                //     border: Border.all(
                //       color: Theme.of(context)
                //           .colorScheme
                //           .surfaceContainerHighest,
                //     ),
                //     shape: BoxShape.circle,
                //   ),
                //   child: IconButton(
                //     onPressed: () => {},
                //     icon: Icon(
                //       LucideIcons.settings2,
                //       semanticLabel: 'Filter',
                //     ),
                //   ),
                // ),
                // const SizedBox(
                //   width: 8.0,
                // ),
                // Expanded(
                //   child: CustomTextField(
                //     labelText: 'Search on ${instance.name}',
                //     searchTheme: true,
                //   ),
                // ),
              ],
            ),
          ),
        ],
      ),
      tabTitles: [
        t(context)!.presentation,
        // Tab(
        //   text: 'Discover',
        //   height: 48.0,
        // ),
        t(context)!.trending,
        t(context)!.recentlyAdded,
        t(context)!.localVideos,
      ],
      tabViews: [
        const PresentationScreen(),
        // Center(
        //   child: Text('Discover 🚧'),
        // ),
        VideoListView(
          fetchPage: ref.read(videoServiceProvider).getTrendingVideos,
          wantKeepAlive: true,
          domain: platform.domain,
          key: GlobalKey(),
        ),
        VideoListView(
          fetchPage: ref.read(videoServiceProvider).getRecentVideos,
          wantKeepAlive: true,
          domain: platform.domain,
          key: GlobalKey(),
        ),
        VideoListView(
          fetchPage: ref.read(videoServiceProvider).getLocalVideos,
          wantKeepAlive: true,
          domain: platform.domain,
          key: GlobalKey(),
        ),
      ],
    );
  }
}

class NoPlatformScreen extends StatelessWidget {
  const NoPlatformScreen({super.key});

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text(
          'No platform selected',
        ),
        actions: const [
          AccountAction(),
        ],
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Image.asset(
              'assets/sepia/pointing.png',
              height: 150.0,
              semanticLabel: t(context)!.sepiaPointing,
            ),
            const SizedBox(
              height: 20.0,
            ),
            const Text(
              'Please choose a platform to access its home page.',
              textAlign: TextAlign.center,
              style: TextStyle(
                fontSize: 18.0,
                fontWeight: FontWeight.w600,
              ),
            ),
            const SizedBox(
              height: 20.0,
            ),
            CustomElevatedButton(
              onPressed: () {
                GoRouter.of(context).go('/explore');
              },
              child: const Text('Back to Explore'),
            ),
          ],
        ),
      ),
    );
  }
}

class PresentationScreen extends ConsumerStatefulWidget {
  const PresentationScreen({super.key});

  @override
  ConsumerState<PresentationScreen> createState() => _PresentationScreenState();
}

class _PresentationScreenState extends ConsumerState<PresentationScreen>
    with AutomaticKeepAliveClientMixin<PresentationScreen> {
  @override
  bool get wantKeepAlive => true;

  @override
  Widget build(BuildContext context) {
    super.build(context);

    final platform = ref.watch(currentPlatformNonNullableProvider);

    return SingleChildScrollView(
      child: Column(
        children: [
          if (ref.watch(platformHomeScreenNumberLivesProvider) != 0)
            Align(
              alignment: Alignment.centerLeft,
              child: Padding(
                padding:
                    const EdgeInsets.symmetric(horizontal: 18.0, vertical: 8.0),
                child: Row(
                  children: [
                    Text(
                      t(context)!.currentLives,
                      style: Theme.of(context).textTheme.displayLarge,
                    ),
                  ],
                ),
              ),
            ),
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 16.0),
            child: VideoListView(
              fetchPage: ref.read(videoServiceProvider).getLiveVideos,
              isHorizontal: true,
              counterProvider: platformHomeScreenNumberLivesProvider,
              domain: platform.domain,
              key: GlobalKey(),
            ),
          ),
          if (ref.watch(platformHomeScreenNumberVideosProvider) != 0)
            Align(
              alignment: Alignment.centerLeft,
              child: Padding(
                padding:
                    const EdgeInsets.symmetric(horizontal: 18.0, vertical: 8.0),
                child: Row(
                  children: [
                    Text(
                      t(context)!.onlineVideos,
                      style: Theme.of(context).textTheme.displayLarge,
                    ),
                  ],
                ),
              ),
            ),
          VideoListView(
            fetchPage: ref.read(videoServiceProvider).getNonLiveVideos,
            isNested: true,
            wantKeepAlive: true,
            counterProvider: platformHomeScreenNumberVideosProvider,
            domain: platform.domain,
            key: GlobalKey(),
          ),
        ],
      ),
    );
  }
}
