import 'package:flutter/material.dart';

import 'package:sentry_flutter/sentry_flutter.dart';

import 'package:peertube_mobile/shared/utils/translate.dart';
import 'package:peertube_mobile/shared/widgets/button.dart';
import 'package:peertube_mobile/shared/widgets/text_field.dart';

class ReportBugScreen extends StatefulWidget {
  const ReportBugScreen({super.key});

  @override
  State<ReportBugScreen> createState() => _ReportBugScreenState();
}

class _ReportBugScreenState extends State<ReportBugScreen> {
  final _formKey = GlobalKey<FormState>();
  final TextEditingController _nameController = TextEditingController();
  final TextEditingController _emailController = TextEditingController();
  final TextEditingController _commentsController = TextEditingController();
  SentryId _sentryId = const SentryId.empty();

  @override
  void initState() {
    super.initState();
  }

  Future<void> _sendFeedback() async {
    if (_formKey.currentState!.validate()) {
      _sentryId = await Sentry.captureMessage('User feedback event');

      final userFeedback = SentryFeedback(
        associatedEventId: _sentryId,
        message: _commentsController.text,
        contactEmail: _emailController.text,
        name: _nameController.text,
      );

      await Sentry.captureFeedback(userFeedback);

      _nameController.clear();
      _emailController.clear();
      _commentsController.clear();
      if (mounted) {
        ScaffoldMessenger.of(context).showSnackBar(
          SnackBar(content: Text(t(context)!.thankYouForYourReport)),
        );
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(t(context)!.reportBug),
      ),
      body: Padding(
        padding: const EdgeInsets.all(16.0),
        child: Form(
          key: _formKey,
          child: Column(
            children: [
              CustomTextFormField(
                controller: _nameController,
                labelText: t(context)!.name,
                isRequired: true,
              ),
              const SizedBox(
                height: 24,
              ),
              CustomTextFormField(
                controller: _emailController,
                labelText: t(context)!.email,
                isRequired: true,
                keyboardType: TextInputType.emailAddress,
              ),
              const SizedBox(
                height: 48,
              ),
              CustomTextFormField(
                controller: _commentsController,
                labelText: t(context)!.comments,
                isRequired: true,
                maxLines: 4,
              ),
              const SizedBox(height: 20),
              CustomElevatedButton(
                onPressed: _sendFeedback,
                child: Text(t(context)!.report),
              ),
            ],
          ),
        ),
      ),
    );
  }

  @override
  void dispose() {
    _nameController.dispose();
    _emailController.dispose();
    _commentsController.dispose();
    super.dispose();
  }
}
