import 'package:flutter/material.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:lucide_icons/lucide_icons.dart';

import 'package:peertube_mobile/routes/settings/settings_screen.dart';
import 'package:peertube_mobile/shared/preferences/user_preferences.dart';
import 'package:peertube_mobile/shared/utils/translate.dart';

class PlaybackSettingsScreen extends ConsumerWidget {
  final bool isDarkTheme = false;

  const PlaybackSettingsScreen({super.key});

  @override
  Widget build(context, ref) {
    var textTheme = Theme.of(context).textTheme;
    var colorScheme = Theme.of(context).colorScheme;
    return Scaffold(
      appBar: AppBar(
        title: Text(t(context)!.playbackSettings),
      ),
      body: ListView(
        children: <Widget>[
          Padding(
            padding: const EdgeInsets.all(16.0),
            child: Text(
              t(context)!.playbackSettings,
              style: textTheme.displayMedium!
                  .copyWith(color: colorScheme.onSecondaryContainer),
            ),
          ),
          buildSettingItem(
            context,
            icon: LucideIcons.play,
            title: 'Automatically play videos',
            subtitle: 'When on a video page, directly start playing the video.',
            switchValue: ref.watch(autoPlayVideoProvider),
            onSwitchChanged: (value) =>
                ref.read(autoPlayVideoProvider.notifier).state = value,
          ),
          // buildSettingItem(
          //   context,
          //   icon: LucideIcons.listVideo,
          //   title: 'Automatically start playing the next video',
          //   subtitle:
          //       'When a video ends, follow up with the next suggested video.',
          //   switchValue: ref.watch(autoPlayNextVideoProvider),
          //   onSwitchChanged: (value) =>
          //       ref.read(autoPlayNextVideoProvider.notifier).state = value,
          // ),
        ],
      ),
    );
  }
}

final autoPlayVideoProvider = StateProvider<bool>(
  (ref) {
    SharedUtility sharedUtility = ref.watch(sharedUtilityProvider);
    bool? autoPlayVideo = sharedUtility.autoPlayVideo;

    ref.listenSelf((bool? prev, bool curr) {
      sharedUtility.setAutoPlayVideo(curr);
    });

    return autoPlayVideo ?? false;
  },
  name: 'autoPlayVideoProvider',
);

final autoPlayNextVideoProvider = StateProvider<bool>(
  (ref) {
    SharedUtility sharedUtility = ref.watch(sharedUtilityProvider);
    bool? autoPlayNextVideo = sharedUtility.autoPlayNextVideo;

    ref.listenSelf((bool? prev, bool curr) {
      sharedUtility.setAutoPlayNextVideo(curr);
    });

    return autoPlayNextVideo ?? false;
  },
  name: 'autoPlayNextVideoProvider',
);
