import 'package:dio/dio.dart';

import 'package:peertube_mobile/shared/config/config_models.dart';
import 'package:peertube_mobile/shared/current_platform/current_platform_models.dart';

class ConfigDatasource {
  static const configPath = '/config';
  static const aboutPath = '$configPath/about';

  final Dio httpClient;

  ConfigDatasource({required this.httpClient});

  Future<PlatformAPI> about(Uri domain) async {
    try {
      final Response response = await httpClient.get(
        domain.resolve('api/v1$aboutPath').toString(),
      );

      return PlatformAPI.fromJson(response.data['instance']);
    } catch (_) {
      throw PlatformUnreachableException();
    }
  }

  Future<ConfigServer> config(Uri domain) async {
    try {
      final Response response = await httpClient.get(
        domain.resolve('api/v1$configPath').toString(),
      );

      return ConfigServer.fromJson(response.data);
    } catch (_) {
      throw PlatformUnreachableException();
    }
  }
}

class PlatformUnreachableException implements Exception {
  final String message;

  PlatformUnreachableException([this.message = 'Platform unreachable']);

  @override
  String toString() => 'PlatformUnreachableException: $message';
}
