import 'package:json_annotation/json_annotation.dart';

import 'package:peertube_mobile/shared/actor/actor_image_model.dart';

part 'current_platform_models.g.dart';

@JsonSerializable()
class PlatformAPI {
  final String name;
  final String shortDescription;
  final String description;
  final String terms;
  final String codeOfConduct;
  final String hardwareInformation;
  final String creationReason;
  final String moderationInformation;
  final String administrator;
  final String maintenanceLifetime;
  final String businessModel;
  final List<String> languages;
  final List<int> categories;
  final List<ActorImage> banners;
  final List<ActorImage> avatars;

  PlatformAPI({
    required this.name,
    required this.shortDescription,
    required this.description,
    required this.terms,
    required this.codeOfConduct,
    required this.hardwareInformation,
    required this.creationReason,
    required this.moderationInformation,
    required this.administrator,
    required this.maintenanceLifetime,
    required this.businessModel,
    required this.languages,
    required this.categories,
    required this.banners,
    required this.avatars,
  });

  factory PlatformAPI.fromJson(Map<String, dynamic> json) =>
      _$PlatformAPIFromJson(json);
  Map<String, dynamic> toJson() => _$PlatformAPIToJson(this);
}

@JsonSerializable()
class CurrentPlatform extends PlatformAPI implements Platform {
  static const String apiPath = '/api/v1';

  @override
  final String domain;

  CurrentPlatform({
    required this.domain,
    required super.name,
    required super.shortDescription,
    required super.description,
    required super.terms,
    required super.codeOfConduct,
    required super.hardwareInformation,
    required super.creationReason,
    required super.moderationInformation,
    required super.administrator,
    required super.maintenanceLifetime,
    required super.businessModel,
    required super.languages,
    required super.categories,
    required super.banners,
    required super.avatars,
  });

  CurrentPlatform.fromAPI({
    required this.domain,
    required PlatformAPI platformAPI,
  }) : super(
          name: platformAPI.name,
          shortDescription: platformAPI.shortDescription,
          description: platformAPI.description,
          terms: platformAPI.terms,
          codeOfConduct: platformAPI.codeOfConduct,
          hardwareInformation: platformAPI.hardwareInformation,
          creationReason: platformAPI.creationReason,
          moderationInformation: platformAPI.moderationInformation,
          administrator: platformAPI.administrator,
          maintenanceLifetime: platformAPI.maintenanceLifetime,
          businessModel: platformAPI.businessModel,
          languages: platformAPI.languages,
          categories: platformAPI.categories,
          banners: platformAPI.banners,
          avatars: platformAPI.avatars,
        );

  factory CurrentPlatform.fromJson(Map<String, dynamic> json) =>
      _$CurrentPlatformFromJson(json);

  String getApiBaseUrl(String path) => Uri.parse(domain)
      .replace(
        path: '$apiPath$path',
      )
      .toString();

  @override
  Map<String, dynamic> toJson() => _$CurrentPlatformToJson(this);
}

abstract class Platform {
  String get domain;
  String get name;
}
