import 'package:flutter/material.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';

import 'package:peertube_mobile/features/account/connected_account/connected_account_model.dart';
import 'package:peertube_mobile/features/account/connected_account/connected_account_providers.dart';
import 'package:peertube_mobile/features/platform/history/platform_history_providers.dart';
import 'package:peertube_mobile/shared/config/config_datasource.dart';
import 'package:peertube_mobile/shared/current_platform/current_platform_providers.dart';

class CurrentPlatformService {
  CurrentPlatformService();

  Future<bool> updateCurrentPlatform(
    WidgetRef ref,
    String domain,
    ConnectedAccountSQL account,
  ) async {
    try {
      final currentPlatform = ref.read(
        currentPlatformProvider,
      );
      final newPlatform = await ref
          .read(currentPlatformProvider.notifier)
          .loadCurrentPlatform(Uri.parse(domain));

      if (newPlatform == null) return false;

      final platformHistoryNotifier =
          ref.read(platformHistoryProvider.notifier);

      if (currentPlatform != null) {
        await ref.read(platformHistoryServiceProvider).updateLastAccessByDomain(
              currentPlatform.domain.toString(),
              account,
            );
      }
      final platformInDB = await ref
          .read(platformHistoryServiceProvider)
          .getPlatformByDomain(domain, account);
      if (platformInDB != null) {
        await ref
            .read(platformHistoryServiceProvider)
            .updateLastAccess(platformInDB);
      } else {
        await platformHistoryNotifier.addPlatform(
          name: newPlatform.name,
          domain: domain,
          avatarUrl: (newPlatform.avatars.isEmpty
              ? null
              : Uri.parse(domain)
                  .resolve(
                    newPlatform.avatars[0].path,
                  )
                  .toString()),
        );
      }
      return true;
    } on PlatformUnreachableException {
      return false;
    } catch (e) {
      throw Exception('Error: $e');
    }
  }

  Future<bool> loadPlatformFromLocalAccount(
    BuildContext context,
    WidgetRef ref,
    String domain,
  ) async {
    final localAccount =
        await ref.read(connectedAccountServiceProvider).getLocalAccount();
    return await updateCurrentPlatform(
      ref,
      domain,
      localAccount,
    );
  }
}
