import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:path/path.dart';
import 'package:sqflite/sqflite.dart';

class DatabaseHelper {
  static const int _version = 1;

  static void _onConfigure(Database db) async {
    await db.execute('PRAGMA foreign_keys = ON');
  }

  static Future<String> getPath() async =>
      join(await getDatabasesPath(), 'peertube_database.db');

  static Future<Database> initializeDatabase() async {
    return openDatabase(
      await getPath(),
      version: _version,
      onConfigure: _onConfigure,
      onCreate: (db, version) async {
        await db.execute('''
        CREATE TABLE LocalWatchLaterPlaylistElement (
          id INTEGER PRIMARY KEY AUTOINCREMENT,
          videoUuid TEXT UNIQUE NOT NULL,
          domain TEXT NOT NULL,
          name TEXT NOT NULL,
          previewPath TEXT,
          duration INTEGER NOT NULL,
          channelDisplayName TEXT NOT NULL,
          positionInPlaylist INTEGER
        );
      ''');
        await db.execute('''
        CREATE TABLE LocalHistoryElement (
          id INTEGER PRIMARY KEY AUTOINCREMENT,
          videoUuid TEXT UNIQUE NOT NULL,
          domain TEXT NOT NULL,
          name TEXT NOT NULL,
          previewPath TEXT,
          duration INTEGER NOT NULL,
          channelDisplayName TEXT NOT NULL,
          currentPosition INTEGER NOT NULL,
          watchedAt INTEGER NOT NULL
        );
      ''');
        await db.execute('''
        CREATE TABLE ConnectedAccount (
          id INTEGER PRIMARY KEY AUTOINCREMENT,
          username TEXT NOT NULL,
          host TEXT NOT NULL,
          displayName TEXT NOT NULL,
          avatarUrl TEXT,
          isFavorite INTEGER NOT NULL,
          lastAccess INTEGER NOT NULL,
          UNIQUE (username, host)
        );
        ''');

        await db.insert('ConnectedAccount', {
          'username': 'sepia',
          'host': 'localhost',
          'displayName': 'Local Account',
          'avatarUrl':
              'https://www.peppercarrot.com/0_sources/0ther/framasoft/hi-res/2021-10-12_G1_Peertube_by-David-Revoy.jpg',
          'isFavorite': 0,
          'lastAccess': DateTime.now().millisecondsSinceEpoch,
        });

        await db.execute('''
        CREATE TABLE PlatformHistoryElement (
          id INTEGER PRIMARY KEY AUTOINCREMENT,
          domain TEXT NOT NULL,
          name TEXT NOT NULL,
          avatarUrl TEXT,
          bookmarked INTEGER NOT NULL,
          lastAccess INTEGER NOT NULL,
          accountId INTEGER NOT NULL,
          FOREIGN KEY (accountId) REFERENCES ConnectedAccount (id) ON DELETE CASCADE
        );
        ''');
      },
    );
  }

  static Future<void> removeDatabase() async =>
      await deleteDatabase(await getPath());
}

final databaseProvider = Provider<Database>(
  (ref) => throw UnimplementedError(),
  name: 'databaseProvider',
);
