import 'package:flutter/widgets.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';

@immutable
class Environment {
  const Environment({
    required this.envName,
    required this.sentryDSN,
    required this.logLevel,
    required this.buildType,
  });

  static const String nameEnvVar = 'envName';
  static const String sentryDSNVar = 'sentryDSN';
  static const String logLevelVar = 'logLevel';
  static const String buildTypeVar = 'buildType';

  static Environment? _instance;

  static Environment get instance {
    return _instance ??= initialize();
  }

  @visibleForTesting
  // Disable this rule to keep ability to create a const object. const objects
  // are mandatory
  // if needed to tree shake code based on environment configuration.
  // ignore: prefer_constructors_over_static_methods
  static Environment initialize() {
    const envName = String.fromEnvironment(nameEnvVar);
    const sentryDSN = String.fromEnvironment(sentryDSNVar);
    const logLevel = int.fromEnvironment(logLevelVar);
    const buildTypeString =
        String.fromEnvironment(buildTypeVar, defaultValue: 'unknown');

    final buildType = _parseBuildType(buildTypeString);

    return Environment(
      envName: envName,
      sentryDSN: sentryDSN,
      logLevel: logLevel,
      buildType: buildType,
    );
  }

  static BuildType _parseBuildType(String value) {
    switch (value) {
      case 'playstore':
        return BuildType.playstore;
      case 'appstore':
        return BuildType.appstore;
      case 'fdroid':
        return BuildType.fdroid;
      default:
        return BuildType.unknown;
    }
  }

  final String envName;
  final String sentryDSN;
  final int logLevel;
  final BuildType buildType;
}

enum BuildType {
  playstore,
  appstore,
  fdroid,
  unknown,
}

extension BuildTypeExtension on BuildType {
  String toShortString() {
    switch (this) {
      case BuildType.playstore:
        return 'play-store';
      case BuildType.appstore:
        return 'app-store';
      case BuildType.fdroid:
        return 'f-droid';
      default:
        return 'unknown';
    }
  }
}

final environmentProvider = Provider<Environment>(
  (ref) => Environment.instance,
  name: 'environmentProvider',
);
