import 'package:flutter/material.dart';

import 'package:freezed_annotation/freezed_annotation.dart';

import 'package:peertube_mobile/shared/environment/environment.dart';

part 'platform_params_model.freezed.dart';
part 'platform_params_model.g.dart';

@freezed
class PlatformParams with _$PlatformParams {
  // ignore: invalid_annotation_target
  @JsonSerializable(includeIfNull: false)
  const factory PlatformParams({
    int? start,
    int? count,
    PlatformSortCriteria? sort,
    bool? signup,
    bool? healthy,
    String? nsfwPolicy,
    String? search,
    List<String>? categoriesOr,
    List<String>? languagesOr,
    bool? liveEnabled,
    int? minUserQuota,
    int? customizations,
    String? randomSortSeed,
    String? filterTag,
  }) = _PlatformParams;

  factory PlatformParams.defaultParams() {
    var buildTypeString = Environment.instance.buildType;
    final filterTag = (buildTypeString == BuildType.playstore ||
            buildTypeString == BuildType.appstore)
        ? buildTypeString.toShortString()
        : null;
    return PlatformParams(
      sort: PlatformSortCriteria.customizationsDesc,
      filterTag: filterTag,
    );
  }

  factory PlatformParams.fromJson(Map<String, dynamic> json) =>
      _$PlatformParamsFromJson(json);
}

enum PlatformSortCriteria {
  @JsonValue('id')
  idAsc,

  @JsonValue('-id')
  idDesc,

  @JsonValue('host')
  hostAsc,

  @JsonValue('-host')
  hostDesc,

  @JsonValue('createdAt')
  createdAtAsc,

  @JsonValue('-createdAt')
  createdAtDesc,

  @JsonValue('name')
  nameAsc,

  @JsonValue('-name')
  nameDesc,

  @JsonValue('health')
  healthAsc,

  @JsonValue('-health')
  healthDesc,

  @JsonValue('totalUsers')
  totalUsersAsc,

  @JsonValue('-totalUsers')
  totalUsersDesc,

  @JsonValue('totalVideos')
  totalVideosAsc,

  @JsonValue('-totalVideos')
  totalVideosDesc,

  @JsonValue('totalLocalVideos')
  totalLocalVideosAsc,

  @JsonValue('-totalLocalVideos')
  totalLocalVideosDesc,

  @JsonValue('totalInstanceFollowers')
  totalInstanceFollowersAsc,

  @JsonValue('-totalInstanceFollowers')
  totalInstanceFollowersDesc,

  @JsonValue('totalInstanceFollowing')
  totalInstanceFollowingAsc,

  @JsonValue('-totalInstanceFollowing')
  totalInstanceFollowingDesc,

  @JsonValue('signupAllowed')
  signupAllowedAsc,

  @JsonValue('-signupAllowed')
  signupAllowedDesc,

  @JsonValue('liveEnabled')
  liveEnabledAsc,

  @JsonValue('-liveEnabled')
  liveEnabledDesc,

  @JsonValue('version')
  versionAsc,

  @JsonValue('-version')
  versionDesc,

  @JsonValue('country')
  countryAsc,

  @JsonValue('-country')
  countryDesc,

  @JsonValue('customizations')
  customizationsAsc,

  @JsonValue('-customizations')
  customizationsDesc,
}

String getPlatformSortCriteriaString(
  BuildContext context,
  PlatformSortCriteria criteria,
) {
  switch (criteria) {
    case PlatformSortCriteria.idAsc:
      return 'ID';
    case PlatformSortCriteria.idDesc:
      return 'ID (Descending)';
    case PlatformSortCriteria.hostAsc:
      return 'Host';
    case PlatformSortCriteria.hostDesc:
      return 'Host (Descending)';
    case PlatformSortCriteria.createdAtAsc:
      return 'Creation Date';
    case PlatformSortCriteria.createdAtDesc:
      return 'Creation Date (Descending)';
    case PlatformSortCriteria.nameAsc:
      return 'Name';
    case PlatformSortCriteria.nameDesc:
      return 'Name (Descending)';
    case PlatformSortCriteria.healthAsc:
      return 'Health';
    case PlatformSortCriteria.healthDesc:
      return 'Health (Descending)';
    case PlatformSortCriteria.totalUsersAsc:
      return 'Fewest Users';
    case PlatformSortCriteria.totalUsersDesc:
      return 'Most Users';
    case PlatformSortCriteria.totalVideosAsc:
      return 'Fewest Videos';
    case PlatformSortCriteria.totalVideosDesc:
      return 'Most Videos';
    case PlatformSortCriteria.totalLocalVideosAsc:
      return 'Fewest Local Videos';
    case PlatformSortCriteria.totalLocalVideosDesc:
      return 'Most Local Videos';
    case PlatformSortCriteria.totalInstanceFollowersAsc:
      return 'Fewest Followers';
    case PlatformSortCriteria.totalInstanceFollowersDesc:
      return 'Most Followers';
    case PlatformSortCriteria.totalInstanceFollowingAsc:
      return 'Fewest Following';
    case PlatformSortCriteria.totalInstanceFollowingDesc:
      return 'Most Following';
    case PlatformSortCriteria.signupAllowedAsc:
      return 'Signup Not Allowed';
    case PlatformSortCriteria.signupAllowedDesc:
      return 'Signup Allowed';
    case PlatformSortCriteria.liveEnabledAsc:
      return 'Live Streaming Not Enabled';
    case PlatformSortCriteria.liveEnabledDesc:
      return 'Live Streaming Enabled';
    case PlatformSortCriteria.versionAsc:
      return 'Version';
    case PlatformSortCriteria.versionDesc:
      return 'Version (Descending)';
    case PlatformSortCriteria.countryAsc:
      return 'Country';
    case PlatformSortCriteria.countryDesc:
      return 'Country (Descending)';
    case PlatformSortCriteria.customizationsAsc:
      return 'Customizations';
    case PlatformSortCriteria.customizationsDesc:
      return 'Customizations (Descending)';
  }
}
