import 'package:flutter_riverpod/flutter_riverpod.dart';

import 'package:peertube_mobile/features/filters/filters_providers.dart';
import 'package:peertube_mobile/shared/filters/platform/platform_params_model.dart';
import 'package:peertube_mobile/shared/preferences/user_preferences.dart';

class PlatformParamsNotifier extends AutoDisposeNotifier<PlatformParams> {
  @override
  PlatformParams build() {
    if (ref.watch(filterByMyInterestsSwitchProvider)) {
      return interestsFilters();
    } else {
      return PlatformParams.defaultParams();
    }
  }

  void update({
    String? search,
    List<String>? categoriesOr,
    bool? isLive,
    PlatformSortCriteria? sort,
    List<String>? languagesOr,
  }) =>
      state = state.copyWith(
        search: search ?? state.search,
        categoriesOr: categoriesOr ?? state.categoriesOr,
        sort: sort ?? state.sort,
        languagesOr: languagesOr ?? state.languagesOr,
      );

  PlatformParams interestsFilters() {
    final sharedUtility = ref.read(sharedUtilityProvider);
    return PlatformParams.defaultParams().copyWith(
      search: '',
      categoriesOr: sharedUtility.selectedCategories.toList(),
      languagesOr: sharedUtility.selectedLanguages.toList(),
    );
  }

  void applyInterests() => state = interestsFilters();

  void reset() => state = PlatformParams.defaultParams();
}
