import 'package:flutter/material.dart';

import 'package:freezed_annotation/freezed_annotation.dart';

import 'package:peertube_mobile/shared/filters/nsfw_filter_enum.dart';
import 'package:peertube_mobile/shared/utils/translate.dart';

part 'search_video_params_model.freezed.dart';
part 'search_video_params_model.g.dart';

@freezed
class SearchVideosParams with _$SearchVideosParams {
  // ignore: invalid_annotation_target
  @JsonSerializable(includeIfNull: false)
  const factory SearchVideosParams({
    required String search,
    List<String>? categoryOneOf,
    bool? isLive,
    List<String>? tagsOneOf,
    List<String>? tagsAllOf,
    List<String>? licenceOneOf,
    List<String>? languageOneOf,
    NsfwFilter? nsfw,
    bool? isLocal,
    String? privacy,
    List<String>? uuids,
    bool? hasHLSFiles,
    bool? hasWebVideoFiles,
    bool? skipCount,
    int? start,
    int? count,
    String? searchTarget,
    VideoSearchSortCriteria? sort,
    bool? excludeAlreadyWatched,
    String? host,
    DateTime? startDate,
    DateTime? endDate,
    DateTime? originallyPublishedStartDate,
    DateTime? originallyPublishedEndDate,
    int? durationMin,
    int? durationMax,
    String? filterTag,
    List<String>? filterTagAdditionalHosts,
  }) = _SearchVideosParams;

  factory SearchVideosParams.defaultParams() {
    return const SearchVideosParams(
      search: '',
      nsfw: NsfwFilter.hide,
    );
  }

  factory SearchVideosParams.fromJson(Map<String, dynamic> json) =>
      _$SearchVideosParamsFromJson(json);
}

extension SearchVideosParamsExtension on SearchVideosParams {
  bool isDefault() {
    return this == SearchVideosParams.defaultParams();
  }
}

@JsonEnum(alwaysCreate: true)
enum VideoSearchSortCriteria {
  @JsonValue('name')
  nameAsc,

  @JsonValue('-name')
  nameDesc,

  @JsonValue('duration')
  durationAsc,

  @JsonValue('-duration')
  durationDesc,

  @JsonValue('createdAt')
  createdAtAsc,

  @JsonValue('-createdAt')
  createdAtDesc,

  @JsonValue('publishedAt')
  publishedAtAsc,

  @JsonValue('-publishedAt')
  publishedAtDesc,

  @JsonValue('views')
  viewsAsc,

  @JsonValue('-views')
  viewsDesc,

  @JsonValue('likes')
  likesAsc,

  @JsonValue('-likes')
  likesDesc,

  @JsonValue('match')
  matchAsc,

  @JsonValue('-match')
  matchDesc,
}

String getVideoSearchSortCriteriaString(
  BuildContext context,
  VideoSearchSortCriteria type,
) {
  switch (type) {
    case VideoSearchSortCriteria.nameAsc:
      return t(context)!.nameAZ;
    case VideoSearchSortCriteria.nameDesc:
      return t(context)!.nameZA;
    case VideoSearchSortCriteria.durationAsc:
      return t(context)!.shortestDuration;
    case VideoSearchSortCriteria.durationDesc:
      return t(context)!.longestDuration;
    case VideoSearchSortCriteria.createdAtAsc:
      return t(context)!.oldest;
    case VideoSearchSortCriteria.createdAtDesc:
      return t(context)!.newest;
    case VideoSearchSortCriteria.publishedAtAsc:
      return t(context)!.leastRecent;
    case VideoSearchSortCriteria.publishedAtDesc:
      return t(context)!.mostRecent;
    case VideoSearchSortCriteria.viewsAsc:
      return t(context)!.fewestViews;
    case VideoSearchSortCriteria.viewsDesc:
      return t(context)!.mostViews;
    case VideoSearchSortCriteria.likesAsc:
      return t(context)!.fewestLikes;
    case VideoSearchSortCriteria.likesDesc:
      return t(context)!.mostLikes;
    case VideoSearchSortCriteria.matchAsc:
      return t(context)!.bestMatch;
    case VideoSearchSortCriteria.matchDesc:
      return t(context)!.worstMatch;
  }
}
