import 'package:flutter_riverpod/flutter_riverpod.dart';

import 'package:peertube_mobile/features/filters/filters_providers.dart';
import 'package:peertube_mobile/routes/explore/explore_screen.dart';
import 'package:peertube_mobile/shared/filters/nsfw_filter_enum.dart';
import 'package:peertube_mobile/shared/filters/search/search_video_params_model.dart';
import 'package:peertube_mobile/shared/preferences/user_preferences.dart';

class SearchVideosParamsNotifier extends Notifier<SearchVideosParams> {
  @override
  SearchVideosParams build() {
    if (ref.watch(filterByMyInterestsSwitchProvider)) {
      return interestsFilters();
    } else {
      return const SearchVideosParams(
        search: '',
        categoryOneOf: [],
        sort: VideoSearchSortCriteria.viewsDesc,
      );
    }
  }

  void update({
    String? search,
    List<String>? categoryOneOf,
    bool? isLive,
    List<String>? tagsOneOf,
    VideoSearchSortCriteria? sort,
    NsfwFilter? nsfw,
    List<String>? languageOneOf,
  }) {
    state = state.copyWith(
      search: search ?? state.search,
      categoryOneOf: categoryOneOf ?? state.categoryOneOf,
      isLive: isLive ?? state.isLive,
      tagsOneOf: tagsOneOf ?? state.tagsOneOf,
      sort: sort ?? state.sort,
      nsfw: nsfw ?? state.nsfw,
      languageOneOf: languageOneOf ?? state.languageOneOf,
    );

    ref.read(exploreRefreshTriggerProvider.notifier).state = true;
  }

  SearchVideosParams interestsFilters() {
    final sharedUtility = ref.read(sharedUtilityProvider);
    return SearchVideosParams(
      search: '',
      categoryOneOf: sharedUtility.selectedCategories.toList(),
      nsfw: NsfwFilter.hide,
      languageOneOf: sharedUtility.selectedLanguages.toList(),
      sort: VideoSearchSortCriteria.viewsDesc,
    );
  }

  void applyInterests() {
    state = interestsFilters();
    ref.read(exploreRefreshTriggerProvider.notifier).state = true;
  }

  void reset() {
    state = SearchVideosParams.defaultParams();
    ref.read(exploreRefreshTriggerProvider.notifier).state = true;
  }
}
