import 'package:flutter/material.dart';

import 'package:json_annotation/json_annotation.dart';

import 'package:peertube_mobile/shared/filters/nsfw_filter_enum.dart';

part 'video_params_model.g.dart';

@immutable
@JsonSerializable(includeIfNull: false)
class VideoParams {
  final List<int>? categoryOneOf;
  final int? count;
  final bool? excludeAlreadyWatched;
  final bool? hasHLSFiles;
  final bool? hasWebVideoFiles;
  final dynamic include;
  final bool? isLive;
  final bool? isLocal;
  final List<String>? languageOneOf;
  final List<int>? licenceOneOf;
  final NsfwFilter? nsfw;
  final List<int>? privacyOneOf;
  final String? skipCount;
  final VideoSortCriteria? sort;
  final int? start;
  final List<String>? tagsAllOf;
  final List<String>? tagsOneOf;

  const VideoParams({
    this.categoryOneOf,
    this.count,
    this.excludeAlreadyWatched,
    this.hasHLSFiles,
    this.hasWebVideoFiles,
    this.include,
    this.isLive,
    this.isLocal,
    this.languageOneOf,
    this.licenceOneOf,
    this.nsfw,
    this.privacyOneOf,
    this.skipCount,
    this.sort,
    this.start,
    this.tagsAllOf,
    this.tagsOneOf,
  });

  VideoParams copyWith({int? start, int? count, NsfwFilter? nsfw}) {
    return VideoParams(
      categoryOneOf: categoryOneOf,
      count: count ?? this.count,
      excludeAlreadyWatched: excludeAlreadyWatched,
      hasHLSFiles: hasHLSFiles,
      hasWebVideoFiles: hasWebVideoFiles,
      include: include,
      isLive: isLive,
      isLocal: isLocal,
      languageOneOf: languageOneOf,
      licenceOneOf: licenceOneOf,
      nsfw: nsfw ?? this.nsfw,
      privacyOneOf: privacyOneOf,
      skipCount: skipCount,
      sort: sort,
      start: start ?? this.start,
      tagsAllOf: tagsAllOf,
      tagsOneOf: tagsOneOf,
    );
  }

  factory VideoParams.fromJson(Map<String, dynamic> json) =>
      _$VideoParamsFromJson(json);
  Map<String, dynamic> toJson() => _$VideoParamsToJson(this);
}

@JsonEnum(alwaysCreate: true)
enum VideoSortCriteria {
  @JsonValue('name')
  nameAsc,

  @JsonValue('-name')
  nameDesc,

  @JsonValue('duration')
  durationAsc,

  @JsonValue('-duration')
  durationDesc,

  @JsonValue('createdAt')
  createdAtAsc,

  @JsonValue('-createdAt')
  createdAtDesc,

  @JsonValue('publishedAt')
  publishedAtAsc,

  @JsonValue('-publishedAt')
  publishedAtDesc,

  @JsonValue('views')
  viewsAsc,

  @JsonValue('-views')
  viewsDesc,

  @JsonValue('likes')
  likesAsc,

  @JsonValue('-likes')
  likesDesc,

  @JsonValue('hot')
  hotAsc,

  @JsonValue('-hot')
  hotDesc,

  @JsonValue('trending')
  trendingAsc,

  @JsonValue('-trending')
  trendingDesc,

  @JsonValue('best')
  bestAsc,

  @JsonValue('-best')
  bestDesc,
}

String getVideoSortCriteriaString(
  BuildContext context,
  VideoSortCriteria type,
) {
  switch (type) {
    case VideoSortCriteria.nameAsc:
      return 'Name (A-Z)';
    case VideoSortCriteria.nameDesc:
      return 'Name (Z-A)';
    case VideoSortCriteria.durationAsc:
      return 'Shortest Duration';
    case VideoSortCriteria.durationDesc:
      return 'Longest Duration';
    case VideoSortCriteria.createdAtAsc:
      return 'Oldest';
    case VideoSortCriteria.createdAtDesc:
      return 'Newest';
    case VideoSortCriteria.publishedAtAsc:
      return 'Least Recent';
    case VideoSortCriteria.publishedAtDesc:
      return 'Most Recent';
    case VideoSortCriteria.viewsAsc:
      return 'Fewest Views';
    case VideoSortCriteria.viewsDesc:
      return 'Most Views';
    case VideoSortCriteria.likesAsc:
      return 'Fewest Likes';
    case VideoSortCriteria.likesDesc:
      return 'Most Likes';
    case VideoSortCriteria.hotAsc:
      return 'Least hot';
    case VideoSortCriteria.hotDesc:
      return 'Hottest';
    case VideoSortCriteria.trendingAsc:
      return 'Least trendy';
    case VideoSortCriteria.trendingDesc:
      return 'Trendiest';
    case VideoSortCriteria.bestAsc:
      return 'Least best for you';
    case VideoSortCriteria.bestDesc:
      return 'Best for you';
  }
}
