import 'dart:io';

import 'package:dio/dio.dart';

import 'package:peertube_mobile/shared/auth/auth_service.dart';
import 'package:peertube_mobile/shared/auth/token_model.dart';
import 'package:peertube_mobile/shared/current_platform/current_platform_models.dart';

class DioAuthenticationInterceptor extends Interceptor {
  static const String bearerPrefix = 'Bearer';

  DioAuthenticationInterceptor({
    required this.currentPlaform,
    required this.auth,
    required this.errorHandlerDio,
  });

  final CurrentPlatform? currentPlaform;
  final AuthService auth;
  final Dio errorHandlerDio;

  @override
  void onRequest(
    RequestOptions options,
    RequestInterceptorHandler handler,
  ) {
    try {
      if (currentPlaform == null) {
        super.onRequest(options, handler);
        return;
      }
      auth.getAccessToken(currentPlaform!).then(
        (token) {
          handler.next(
            options.copyWith(
              headers: <String, dynamic>{
                ...options.headers,
                HttpHeaders.contentTypeHeader: Headers.jsonContentType,
                if (token != null)
                  HttpHeaders.authorizationHeader: '$bearerPrefix $token',
              },
            ),
          );
        },
      );
    } catch (e) {
      handler.reject(
        DioException(
          requestOptions: options,
          type: DioExceptionType.cancel,
          error: e,
        ),
      );
    }
  }

  @override
  void onError(DioException err, ErrorInterceptorHandler handler) async {
    if (currentPlaform != null &&
        err.response?.statusCode == HttpStatus.unauthorized) {
      Token? newToken = await auth.refreshToken(currentPlaform!);
      if (newToken != null) {
        err.requestOptions.headers['Authorization'] =
            'Bearer ${newToken.accessToken}';

        try {
          return handler
              .resolve(await errorHandlerDio.fetch(err.requestOptions));
        } on DioException catch (e) {
          return handler.next(e);
        }
      }
    }
    return handler.next(err);
  }
}
