import 'dart:io';

import 'package:dio/dio.dart';

class HttpService {
  final Dio peertubeClient;

  HttpService({required this.peertubeClient});

  Future<Response> get({
    required String path,
    Map<String, dynamic>? queryParameters,
    Map<String, dynamic>? headers,
    int? expectedStatusCode,
  }) async =>
      _request(
        method: 'GET',
        path: path,
        queryParameters: queryParameters,
        headers: headers,
        expectedStatusCode: expectedStatusCode,
      );

  Future<Response> post({
    required String path,
    FormData? body,
    Map<String, dynamic>? headers,
    int? expectedStatusCode,
  }) async =>
      _request(
        method: 'POST',
        path: path,
        body: body,
        headers: headers,
        expectedStatusCode: expectedStatusCode,
      );

  Future<Response> put({
    required String path,
    FormData? body,
    Map<String, dynamic>? headers,
    int? expectedStatusCode,
  }) async =>
      _request(
        method: 'PUT',
        path: path,
        body: body,
        headers: headers,
        expectedStatusCode: expectedStatusCode,
      );

  Future<Response> delete({
    required String path,
    Map<String, dynamic>? queryParameters,
    Map<String, dynamic>? headers,
    int? expectedStatusCode,
  }) async =>
      _request(
        method: 'DELETE',
        path: path,
        queryParameters: queryParameters,
        headers: headers,
        expectedStatusCode: expectedStatusCode,
      );

  Future<Response> _request({
    required String method,
    required String path,
    Map<String, dynamic>? queryParameters,
    FormData? body,
    Map<String, dynamic>? headers,
    int? expectedStatusCode = HttpStatus.ok,
  }) async {
    try {
      final response = await peertubeClient.request(
        path,
        options: Options(
          method: method,
          headers: headers,
        ),
        queryParameters: queryParameters,
        data: body,
      );

      if (response.statusCode == expectedStatusCode) {
        return response;
      } else {
        throw Exception('Request failed: ${response.statusCode}');
      }
    } on DioException catch (e) {
      throw Exception('Dio error: ${e.message}');
    } catch (e) {
      throw Exception('An error has occurred: $e');
    }
  }
}
