import 'package:dio/dio.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';

import 'package:peertube_mobile/shared/auth/auth_providers.dart';
import 'package:peertube_mobile/shared/current_platform/current_platform_providers.dart';
import 'package:peertube_mobile/shared/network/dio_authentication_interceptor.dart';
import 'package:peertube_mobile/shared/network/http_service.dart';

final Provider<Dio> httpClientProvider = Provider<Dio>(
  (Ref<Dio> ref) => Dio(),
  name: 'httpClientProvider',
);

final authenticationInterceptorProvider =
    Provider.autoDispose<DioAuthenticationInterceptor>(
  (ref) => DioAuthenticationInterceptor(
    currentPlaform: ref.watch(currentPlatformProvider),
    auth: ref.watch(authServiceProvider),
    errorHandlerDio: Dio(),
  ),
  name: 'authenticationInterceptorProvider',
);

final peertubeClientProvider = Provider.autoDispose<Dio>(
  (ref) => Dio()
    ..transformer = BackgroundTransformer()
    ..interceptors.add(
      ref.watch(authenticationInterceptorProvider),
    ),
  name: 'peertubeClientProvider',
);

final httpServiceProvider = Provider.autoDispose<HttpService>(
  (ref) => HttpService(peertubeClient: ref.watch(peertubeClientProvider)),
  name: 'httpServiceProvider',
);
