import 'package:flutter/material.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:shared_preferences/shared_preferences.dart';

final sharedPreferencesProvider = Provider<SharedPreferences>(
  (ref) => throw UnimplementedError(),
  name: 'sharedPreferencesProvider',
);

final sharedUtilityProvider = Provider<SharedUtility>(
  (ref) {
    final sharedPrefs = ref.watch(sharedPreferencesProvider);
    return SharedUtility(sharedPreferences: sharedPrefs);
  },
  name: 'sharedUtilityProvider',
);

class SharedUtility {
  SharedUtility({
    required SharedPreferences sharedPreferences,
  }) : _sharedPreferences = sharedPreferences;

  final SharedPreferences _sharedPreferences;

  // Constants keys
  static const String _TAG_CURRENT_THEME_MODE_INDEX = 'currentThemeModeIndex';
  static const String _TAG_USER_COUNTRY_CODE = 'userCountry';
  static const String _TAG_ONBOARDING_COMPLETED = 'onboardingCompleted';
  static const String _TAG_AUTO_PLAY_VIDEO = 'autoPlayVideo';
  static const String _TAG_AUTO_PLAY_NEXT_VIDEO = 'autoPlayNextVideo';
  static const String _TAG_SELECTED_CATEGORIES = 'selectedCategories';
  static const String _TAG_SELECTED_LANGUAGES = 'selectedLanguages';
  static const String _TAG_SELECTED_TAGS = 'selectedTags';
  static const String _TAG_SHOW_DIALOG_GO_PLATROM = 'showDialogGoPlatform';
  static const String _TAG_SHOW_DIALOG_REMOVE_PLATFORM =
      'showDialogRemovePlatform';
  // static const String _TAG_SHOW_DIALOG_ = 'showDialog';
  // static const String _TAG_SHOW_DIALOG_ = 'showDialog';

  Future<void> setTheme(final ThemeMode theme) async {
    await _sharedPreferences.setInt(_TAG_CURRENT_THEME_MODE_INDEX, theme.index);
  }

  int get currentThemeIndex =>
      _sharedPreferences.getInt(_TAG_CURRENT_THEME_MODE_INDEX) ?? 0;

  Future<void> setUserCountryCode(final String countryCode) async {
    await _sharedPreferences.setString(_TAG_USER_COUNTRY_CODE, countryCode);
  }

  String? get userCountryCode =>
      _sharedPreferences.getString(_TAG_USER_COUNTRY_CODE);

  Future<void> setOnboardingCompleted(final bool onboardingCompleted) async {
    await _sharedPreferences.setBool(
      _TAG_ONBOARDING_COMPLETED,
      onboardingCompleted,
    );
  }

  bool? get onboardingCompleted =>
      _sharedPreferences.getBool(_TAG_ONBOARDING_COMPLETED);

  Future<void> setAutoPlayVideo(final bool autoPlayVideo) async {
    await _sharedPreferences.setBool(
      _TAG_AUTO_PLAY_VIDEO,
      autoPlayVideo,
    );
  }

  bool? get autoPlayVideo => _sharedPreferences.getBool(_TAG_AUTO_PLAY_VIDEO);

  Future<void> setAutoPlayNextVideo(final bool autoPlayNextVideo) async {
    await _sharedPreferences.setBool(
      _TAG_AUTO_PLAY_NEXT_VIDEO,
      autoPlayNextVideo,
    );
  }

  bool? get autoPlayNextVideo =>
      _sharedPreferences.getBool(_TAG_AUTO_PLAY_NEXT_VIDEO);

  Future<void> setSelectedCategories(
    final List<String> selectedCategories,
  ) async {
    await _sharedPreferences.setStringList(
      _TAG_SELECTED_CATEGORIES,
      selectedCategories,
    );
  }

  List<String> get selectedCategories =>
      _sharedPreferences.getStringList(_TAG_SELECTED_CATEGORIES) ?? [];

  Future<void> setSelectedTags(final List<String> selectedTags) async {
    await _sharedPreferences.setStringList(
      _TAG_SELECTED_TAGS,
      selectedTags,
    );
  }

  List<String> get selectedTags =>
      _sharedPreferences.getStringList(_TAG_SELECTED_TAGS) ?? [];

  Future<void> setSelectedLanguages(
    final List<String> selectedLanguages,
  ) async {
    await _sharedPreferences.setStringList(
      _TAG_SELECTED_LANGUAGES,
      selectedLanguages,
    );
  }

  List<String> get selectedLanguages =>
      _sharedPreferences.getStringList(_TAG_SELECTED_LANGUAGES) ?? [];

  Future<void> setShowDialogGoPlatform(final bool showDialogGoPlatform) async {
    await _sharedPreferences.setBool(
      _TAG_SHOW_DIALOG_GO_PLATROM,
      showDialogGoPlatform,
    );
  }

  bool? get showDialogGoPlatform =>
      _sharedPreferences.getBool(_TAG_SHOW_DIALOG_GO_PLATROM);

  Future<void> setShowDialogRemovePlatform(
    final bool showDialogRemovePlatform,
  ) async {
    await _sharedPreferences.setBool(
      _TAG_SHOW_DIALOG_REMOVE_PLATFORM,
      showDialogRemovePlatform,
    );
  }

  bool? get showDialogRemovePlatform =>
      _sharedPreferences.getBool(_TAG_SHOW_DIALOG_REMOVE_PLATFORM);
}
