import 'dart:io';

import 'package:flutter/material.dart';

import 'package:flutter_gen/gen_l10n/app_localizations.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';

import 'package:peertube_mobile/shared/preferences/user_preferences.dart';

final StateProvider<Locale> localeProvider =
    StateProvider<Locale>((Ref<Locale> ref) {
  SharedUtility sharedUtility = ref.watch(sharedUtilityProvider);

  final Locale userLocale = Locale(
    sharedUtility.userCountryCode ?? Platform.localeName.split('_').first,
  );

  ref.listenSelf((Locale? prev, Locale curr) {
    sharedUtility.setUserCountryCode(curr.toString());
  });

  if (AppLocalizations.supportedLocales.contains(userLocale)) {
    return userLocale;
  } else {
    return const Locale('en');
  }
});

final StateProvider<bool> onboardingProvider =
    StateProvider<bool>((Ref<bool> ref) {
  SharedUtility sharedUtility = ref.watch(sharedUtilityProvider);

  final bool onboardingCompleted = sharedUtility.onboardingCompleted ?? false;

  ref.listenSelf((bool? prev, bool curr) {
    sharedUtility.setOnboardingCompleted(curr);
  });

  return onboardingCompleted;
});
