import 'package:flutter/widgets.dart';

import 'package:flutter_secure_storage/flutter_secure_storage.dart';

interface class SecureStorageService {
  Future<void> setToken(String key, String token) {
    throw UnimplementedError();
  }

  Future<String?> getToken(String key) {
    throw UnimplementedError();
  }

  Future<void> removeToken(String key) {
    throw UnimplementedError();
  }
}

@immutable
class FlutterSecureStorageService implements SecureStorageService {
  final FlutterSecureStorage _secureStorage;

  const FlutterSecureStorageService(this._secureStorage);

  @override
  Future<void> setToken(String key, String token) async {
    await _secureStorage.write(key: key, value: token);
  }

  @override
  Future<String?> getToken(String key) async {
    return await _secureStorage.read(key: key);
  }

  @override
  Future<void> removeToken(String key) async {
    return await _secureStorage.delete(key: key);
  }
}
