import 'package:flutter/material.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';

class AsyncValueWidget<T> extends StatelessWidget {
  final AsyncValue<T> value;
  final Widget Function(T data) dataBuilder;
  final Widget loadingWidget;
  final Widget Function(Object error, StackTrace stackTrace) errorBuilder;

  const AsyncValueWidget({
    super.key,
    required this.value,
    required this.dataBuilder,
    this.loadingWidget = const CircularProgressIndicator(),
    this.errorBuilder = _defaultErrorBuilder,
  });

  static Widget _defaultErrorBuilder(Object error, StackTrace stackTrace) {
    return Center(child: Text('Error : $error'));
  }

  @override
  Widget build(BuildContext context) {
    return value.when(
      data: (data) => dataBuilder(data),
      loading: () => Center(child: loadingWidget),
      error: (error, stackTrace) =>
          Center(child: errorBuilder(error, stackTrace)),
    );
  }
}
