import 'package:flutter/material.dart';

class CustomElevatedButton extends StatelessWidget {
  final VoidCallback onPressed;
  final Widget child;

  const CustomElevatedButton({
    super.key,
    required this.onPressed,
    required this.child,
  });

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      width: MediaQuery.of(context).size.width * 0.95,
      height: 60,
      child: ElevatedButton(
        onPressed: onPressed,
        child: child,
      ),
    );
  }
}

class UnderlinedTextButton extends StatelessWidget {
  final VoidCallback onPressed;
  final String text;
  final TextStyle textStyle;
  final Alignment alignment;

  const UnderlinedTextButton({
    super.key,
    required this.onPressed,
    required this.text,
    required this.textStyle,
    this.alignment = Alignment.topLeft,
  });

  @override
  Widget build(BuildContext context) {
    final colorScheme = Theme.of(context).colorScheme;
    return GestureDetector(
      onTap: onPressed,
      child: Container(
        alignment: alignment,
        constraints: const BoxConstraints(minHeight: 48, minWidth: 48),
        child: Text(
          text,
          style: textStyle.copyWith(
            shadows: [
              Shadow(
                color: colorScheme.onSurfaceVariant,
                offset: const Offset(0, -4),
              ),
            ],
            color: Colors.transparent,
            decoration: TextDecoration.underline,
          ),
        ),
      ),
    );
  }
}
