import 'package:flutter/material.dart';

import 'package:lucide_icons/lucide_icons.dart';

import 'package:peertube_mobile/shared/utils/translate.dart';
import 'package:peertube_mobile/shared/widgets/checkbox_list_tile.dart';

class CustomAlertDialog extends StatelessWidget {
  final String title;
  final String content;
  final String? cancelText;
  final String? confirmText;
  final VoidCallback? onConfirm;
  final bool? showAgain;
  final ValueChanged<bool?>? onShowAgain;

  const CustomAlertDialog({
    super.key,
    required this.title,
    required this.content,
    this.onConfirm,
    this.cancelText,
    this.confirmText,
    this.showAgain,
    this.onShowAgain,
  });

  @override
  Widget build(BuildContext context) {
    final initialShowAgain = showAgain;
    return AlertDialog(
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(24),
      ),
      contentPadding: EdgeInsets.zero,
      titlePadding: const EdgeInsets.only(top: 8.0, right: 8.0),
      insetPadding: const EdgeInsets.all(20),
      title: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          const Spacer(),
          IconButton(
            icon: Icon(
              LucideIcons.x,
              semanticLabel: cancelText,
            ),
            onPressed: () {
              Navigator.of(context).pop(false);
            },
          ),
        ],
      ),
      content: Container(
        width: double.infinity,
        padding: const EdgeInsets.symmetric(horizontal: 20),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Text(
              title,
              style: Theme.of(context).textTheme.headlineMedium,
            ),
            const SizedBox(
              height: 8,
            ),
            Text(content),
            const SizedBox(
              height: 8,
            ),
          ],
        ),
      ),
      actions: [
        if (showAgain != null && onShowAgain != null)
          CustomCheckboxListTile(
            value: showAgain!,
            onChanged: onShowAgain!,
            title: 'Show me this again',
          ),
        Padding(
          padding: const EdgeInsets.all(4.0),
          child: Semantics(
            label: cancelText,
            child: TextButton(
              onPressed: () {
                if (showAgain != null && onShowAgain != null) {
                  onShowAgain!(initialShowAgain);
                }
                Navigator.of(context).pop(false);
              },
              child: Padding(
                padding: const EdgeInsets.all(8.0),
                child: Text(cancelText ?? t(context)!.cancel),
              ),
            ),
          ),
        ),
        Padding(
          padding: const EdgeInsets.all(4.0),
          child: Semantics(
            label: confirmText,
            child: TextButton(
              onPressed: () {
                if (onConfirm != null) onConfirm!();
                Navigator.of(context).pop(true);
              },
              child: Padding(
                padding: const EdgeInsets.all(8.0),
                child: Text(confirmText ?? t(context)!.confirm),
              ),
            ),
          ),
        ),
      ],
    );
  }
}

class CustomDialog extends StatelessWidget {
  final Widget content;

  const CustomDialog({
    super.key,
    required this.content,
  });

  @override
  Widget build(BuildContext context) {
    return Dialog(
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(24),
      ),
      insetPadding: const EdgeInsets.all(20),
      child: Stack(
        children: <Widget>[
          Container(
            width: double.infinity,
            padding: const EdgeInsets.all(20.0),
            child: content,
          ),
          Positioned(
            top: 5,
            right: 5,
            child: IconButton(
              icon: const Icon(LucideIcons.x),
              onPressed: () {
                Navigator.of(context).pop();
              },
            ),
          ),
        ],
      ),
    );
  }
}

class TitleContentDialog extends StatelessWidget {
  final String title;
  final String content;
  final String? secondContent;

  const TitleContentDialog({
    super.key,
    required this.title,
    required this.content,
    this.secondContent,
  });

  @override
  Widget build(BuildContext context) {
    return CustomDialog(
      content: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(
            title,
            style: Theme.of(context).textTheme.headlineMedium,
          ),
          const SizedBox(height: 10),
          Text(content),
          if (secondContent != null) ...{
            const SizedBox(height: 10),
            Text(secondContent!),
          },
        ],
      ),
    );
  }
}
