import 'package:flutter/material.dart';

class CustomFutureBuilder<T> extends StatelessWidget {
  final Future<T> future;
  final Widget Function(T data) onData;
  final Widget? onLoading;
  final Widget Function(Object? error)? onError;

  const CustomFutureBuilder({
    super.key,
    required this.future,
    required this.onData,
    this.onLoading,
    this.onError,
  });

  @override
  Widget build(BuildContext context) {
    return FutureBuilder<T>(
      future: future,
      builder: (context, snapshot) {
        if (snapshot.connectionState == ConnectionState.waiting) {
          return onLoading ?? const Center(child: CircularProgressIndicator());
        }

        if (snapshot.hasError) {
          return onError != null
              ? onError!(snapshot.error)
              : Center(child: Text('Error: ${snapshot.error}'));
        }

        if (snapshot.hasData) {
          return onData(snapshot.data as T);
        }

        return Center(child: const Text('No data available.'));
      },
    );
  }
}
