import 'package:flutter/material.dart';

import 'package:flutter_widget_from_html_core/flutter_widget_from_html_core.dart';
import 'package:url_launcher/url_launcher_string.dart';

class CustomHtmlWidget extends StatelessWidget {
  final String rawHtml;

  const CustomHtmlWidget({
    super.key,
    required this.rawHtml,
  });

  String processHtml(String html) {
    final urlRegex = RegExp(
      r'(?<!<a\s+href=")(https?:\/\/[^\s]+)(?![^<]*<\/a>)',
      caseSensitive: false,
    );

    return html.replaceAllMapped(urlRegex, (match) {
      final url = match.group(0)!;
      return '<a href="$url">$url</a>';
    });
  }

  @override
  Widget build(BuildContext context) {
    final processedHtml = processHtml(rawHtml);

    return HtmlWidget(
      processedHtml,
      customStylesBuilder: (element) {
        if (element.localName == 'p') {
          return {'margin': '0', 'line-height': '1.5'};
        }
        return null;
      },
      onTapUrl: (url) async {
        try {
          await launchUrlString(
            url,
            mode: LaunchMode.externalApplication,
          );
          return true;
        } catch (_) {
          return false;
        }
      },
      textStyle: const TextStyle(
        fontSize: 14,
        height: 1.5,
      ),
    );
  }
}
