import 'package:flutter/material.dart';

class TabbedPageScaffold extends StatelessWidget {
  final PreferredSizeWidget appBar;
  final Widget headerContent;
  final List<String> tabTitles;
  final List<Widget> tabViews;

  const TabbedPageScaffold({
    super.key,
    required this.appBar,
    required this.headerContent,
    required this.tabTitles,
    required this.tabViews,
  }) : assert(
          tabTitles.length == tabViews.length,
          'The number of titles should match the number of views.',
        );

  @override
  Widget build(BuildContext context) {
    return DefaultTabController(
      length: tabTitles.length,
      child: Scaffold(
        appBar: appBar,
        body: NestedScrollView(
          headerSliverBuilder: (BuildContext context, bool innerBoxIsScrolled) {
            return <Widget>[
              SliverToBoxAdapter(
                child: headerContent,
              ),
              SliverPersistentHeader(
                delegate: _SliverAppBarDelegate(
                  TabBar(
                    isScrollable: true,
                    padding: const EdgeInsets.only(left: 18.0),
                    tabs: tabTitles
                        .map(
                          (title) => Tab(
                            height: 48.0,
                            child: Container(
                              alignment: Alignment.bottomCenter,
                              padding: const EdgeInsets.only(bottom: 4.0),
                              child: Text(title),
                            ),
                          ),
                        )
                        .toList(),
                  ),
                ),
                pinned: true,
              ),
            ];
          },
          body: TabBarView(
            children: tabViews,
          ),
        ),
      ),
    );
  }
}

class _SliverAppBarDelegate extends SliverPersistentHeaderDelegate {
  _SliverAppBarDelegate(this._tabBar);

  final TabBar _tabBar;

  @override
  double get minExtent => _tabBar.preferredSize.height;
  @override
  double get maxExtent => _tabBar.preferredSize.height;

  @override
  Widget build(
    BuildContext context,
    double shrinkOffset,
    bool overlapsContent,
  ) {
    return Container(
      color: Theme.of(context).scaffoldBackgroundColor,
      child: _tabBar,
    );
  }

  @override
  bool shouldRebuild(_SliverAppBarDelegate oldDelegate) {
    return false;
  }
}
