import 'package:flutter/material.dart';

import 'package:lucide_icons/lucide_icons.dart';

import 'package:peertube_mobile/shared/utils/translate.dart';

class CustomTextFormField extends StatelessWidget {
  final TextEditingController? controller;
  final String? labelText;
  final String? hintText;
  final String? helperText;
  final String? errorText;
  final int? maxLines;
  final TextInputType? keyboardType;
  final bool searchTheme;
  final bool obscureText;
  final bool isRequired;
  final String? Function(String?)? validator;

  const CustomTextFormField({
    super.key,
    this.controller,
    this.labelText,
    this.hintText,
    this.helperText,
    this.errorText,
    this.maxLines,
    this.keyboardType,
    this.validator,
    this.searchTheme = false,
    this.obscureText = false,
    this.isRequired = false,
  });

  @override
  Widget build(BuildContext context) {
    final colorScheme = Theme.of(context).colorScheme;

    return TextFormField(
      controller: controller,
      obscureText: obscureText,
      maxLines: maxLines,
      onTapOutside: (event) {
        FocusManager.instance.primaryFocus?.unfocus();
      },
      validator: (value) {
        if (isRequired && (value == null || value.isEmpty)) {
          return t(context)!.fieldRequired;
        }
        if (validator != null) {
          return validator!(value);
        }
        return null;
      },
      keyboardType: keyboardType,
      style: TextStyle(
        color: searchTheme
            ? colorScheme.onSecondary
            : colorScheme.onSurfaceVariant,
      ),
      cursorColor: colorScheme.onSurfaceVariant,
      decoration: InputDecoration(
        prefixIcon: searchTheme
            ? const Icon(
                LucideIcons.search,
                size: 16,
              )
            : null,
        labelText: labelText,
        helperText: helperText,
        hintText: hintText,
        errorText: errorText,
        labelStyle: Theme.of(context).textTheme.displayLarge!.copyWith(
              color: colorScheme.onSurfaceVariant,
              fontWeight: searchTheme ? FontWeight.normal : FontWeight.bold,
            ),
        hintStyle: Theme.of(context).textTheme.displayMedium!.copyWith(
              color: colorScheme.onSurfaceVariant,
            ),
        focusedBorder: OutlineInputBorder(
          borderSide: BorderSide(color: colorScheme.primary, width: 2.0),
          borderRadius: BorderRadius.circular(4.0),
        ),
        errorBorder: OutlineInputBorder(
          borderSide: BorderSide(color: colorScheme.error, width: 1.0),
          borderRadius: BorderRadius.circular(4.0),
        ),
        focusedErrorBorder: OutlineInputBorder(
          borderSide: BorderSide(color: colorScheme.error, width: 2.0),
          borderRadius: BorderRadius.circular(4.0),
        ),
        enabledBorder: OutlineInputBorder(
          borderSide: BorderSide(
            color: searchTheme ? Colors.transparent : colorScheme.onSecondary,
            width: 1.0,
          ),
          borderRadius: BorderRadius.circular(4.0),
        ),
        contentPadding: const EdgeInsets.symmetric(horizontal: 16.0),
        fillColor: searchTheme
            ? colorScheme.surfaceContainerHigh
            : colorScheme.surface,
        filled: true,
      ),
    );
  }
}
