import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/annotations.dart';
import 'package:mockito/mockito.dart';

import 'package:peertube_mobile/features/video/video_datasource.dart';
import 'package:peertube_mobile/features/video/video_providers.dart';
import '../../test_utils.dart';
import 'selected_video_notifier_test.mocks.dart';

@GenerateNiceMocks([
  MockSpec<VideoDatasource>(),
])
void main() {
  group('SelectedVideoNotifier', () {
    late MockVideoDatasource videoDatasource;
    late ProviderContainer container;

    setUp(() {
      videoDatasource = MockVideoDatasource();
      container = ProviderContainer(
        overrides: [
          videoDatasourceProvider.overrideWithValue(videoDatasource),
        ],
      );
    });

    tearDown(() {
      container.dispose();
    });

    group('loadSelectedVideo', () {
      test('should load the selected video correctly', () async {
        final expectedVideo = MockedObjects.generateMockVideoDetails();
        final selectedVideoNotifier =
            container.read(selectedVideoProvider.notifier);
        when(videoDatasource.fetchVideo(expectedVideo.uuid))
            .thenAnswer((_) async => expectedVideo);
        await selectedVideoNotifier.loadSelectedVideo(expectedVideo.uuid);

        expect(selectedVideoNotifier.state, equals(expectedVideo));
      });

      test('should handle error when loading video fails', () async {
        const videoUUID = 'test_uuid';
        final selectedVideoNotifier =
            container.read(selectedVideoProvider.notifier);

        when(videoDatasource.fetchVideo(videoUUID)).thenThrow(Exception());
        await selectedVideoNotifier.loadSelectedVideo(videoUUID);

        expect(selectedVideoNotifier.state, isNull);
      });
    });
  });
}
