import 'package:dio/dio.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:http_mock_adapter/http_mock_adapter.dart';

import 'package:peertube_mobile/features/platform/history/platform_history_model.dart';
import 'package:peertube_mobile/shared/config/config_datasource.dart';
import '../../test_utils.dart';

void main() {
  group('ConfigDatasource', () {
    late Dio httpClient;
    late DioAdapter dioAdapter;
    late ConfigDatasource configDatasource;

    setUp(() {
      httpClient = Dio();
      dioAdapter = DioAdapter(dio: httpClient);
      configDatasource = ConfigDatasource(httpClient: httpClient);
    });

    group('about', () {
      final mockAboutPath = Uri.parse(mockPeertubeInstance.domain)
          .resolve('api/v1${ConfigDatasource.aboutPath}')
          .toString();

      test('should throw an Exception when request fails', () async {
        const statusCode = 500;
        final requestOptions = RequestOptions(path: mockAboutPath);

        final dioException = MockDioException(
          requestOptions: requestOptions,
          error: 'mock error message',
          type: DioExceptionType.badResponse,
        );

        dioAdapter.onGet(
          mockAboutPath,
          (server) => server.throws(statusCode, dioException),
        );

        expect(
          () => configDatasource.about(Uri.parse(mockPeertubeInstance.domain)),
          throwsA(
            isA<Exception>().having(
              (e) => e.toString(),
              'toString',
              contains('Platform unreachable'),
            ),
          ),
        );
      });

      test('should return instance config when request succeeds', () async {
        final mockInstanceAPI = MockedObjects.generateMockInstanceAPI();

        dioAdapter.onGet(
          mockAboutPath,
          (server) => server.reply(200, {'instance': mockInstanceAPI.toJson()}),
        );

        expect(
          (await configDatasource.about(Uri.parse(mockPeertubeInstance.domain)))
              .name,
          equals(mockInstanceAPI.name),
        );
      });
    });
  });
}

final mockPeertubeInstance = PlatformHistoryElementSQL(
  domain: 'https://peertube2.cpy.re/',
  name: 'peertube2',
  avatarUrl: 'https://example.com/avatar.png',
  bookmarked: true,
  lastAccess: DateTime.now(),
  accountId: 123,
);
