import 'package:flutter/services.dart';

import 'package:flutter_secure_storage/flutter_secure_storage.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/annotations.dart';
import 'package:mockito/mockito.dart';

import 'package:peertube_mobile/shared/storage/secure_storage_service.dart';
import 'secure_storage_service_test.mocks.dart';

@GenerateNiceMocks([MockSpec<FlutterSecureStorage>()])
void main() {
  group('FlutterSecureStorageService', () {
    late MockFlutterSecureStorage flutterSecureStorage;
    late FlutterSecureStorageService service;

    setUp(() {
      flutterSecureStorage = MockFlutterSecureStorage();
      service = FlutterSecureStorageService(flutterSecureStorage);
    });

    group('setToken', () {
      test(
        'should throw when flutter secure storage throws',
        () async {
          when(flutterSecureStorage.write(key: mockKey, value: mockValue))
              .thenThrow(
            PlatformException(code: 'mock_code'),
          );

          expect(
            service.setToken(mockKey, mockValue),
            throwsA(isA<PlatformException>()),
          );
        },
      );

      test('should set token', () async {
        await service.setToken(mockKey, mockValue);

        verify(
          flutterSecureStorage.write(key: mockKey, value: mockValue),
        ).called(1);
      });
    });

    group('getToken', () {
      test('should throw when flutter secure storage throws', () async {
        when(flutterSecureStorage.read(key: mockKey)).thenThrow(
          PlatformException(code: 'mock_code'),
        );

        expect(
          service.getToken(mockKey),
          throwsA(isA<PlatformException>()),
        );
      });

      test('should get token', () async {
        when(flutterSecureStorage.read(key: mockKey)).thenAnswer(
          (realInvocation) async => mockValue,
        );

        expectLater(
          service.getToken(mockKey),
          completion(mockValue),
        );
      });
    });
  });
}

const mockKey = 'mock_key';
const mockValue = 'mock_value';
